@@ -17,6 +17,10 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
+
+#include "config.h"
+#include "compat.h" // Must precede all FL includes
+
 #include <iostream>
 #include "gettext.h"
 #include "rigpanel.h"
@@ -74,6 +78,7 @@ Fl_Box *labelMEMORY = (Fl_Box *)0;
 
 Fl_Output *txt_encA=(Fl_Output *)0;
 
+Fl_Group *sm_grp1 = (Fl_Group *)0;
 Fl_Group *grpMeters = (Fl_Group *)0;
 Fl_Box *scaleSmeter=(Fl_Box *)0;
 
@@ -255,9 +260,17 @@ Fl_Box *bx_row0_expander=(Fl_Box *)0;
 Fl_Button *btn_show_controls = (Fl_Button *)0;
 Fl_Group *grp_row1 = (Fl_Group *)0;
 Fl_Group *grp_row1a = (Fl_Group *)0;
+
 Fl_ComboBox *opBW = (Fl_ComboBox *)0;
 Fl_ComboBox *opDSP_lo = (Fl_ComboBox *)0;
 Fl_ComboBox *opCENTER = (Fl_ComboBox *)0;
+
+Fl_Counter *opBW_A = (Fl_Counter *)0;
+Fl_Counter *opBW_B = (Fl_Counter *)0;
+
+Fl_Counter *opFilterInner = (Fl_Counter *)0;
+Fl_Counter *opFilterOuter = (Fl_Counter *)0;
+
 Fl_Button *btnDSP = (Fl_Button *)0;
 Fl_ComboBox *opDSP_hi = (Fl_ComboBox *)0;
 Fl_Button *btnFILT= (Fl_Button*)0;
@@ -267,6 +280,9 @@ Fl_Group *grp_row1b = (Fl_Group *)0;
 Fl_Group *grp_row1b1 = (Fl_Group *)0;
 Fl_Light_Button *btnAttenuator = (Fl_Light_Button *)0;
 
+Fl_ComboBox *cbo_attenuator = (Fl_ComboBox *)0;
+Fl_ComboBox *cbo_preamp = (Fl_ComboBox *)0;
+
 Fl_Check_Button *btn_use_bpf_center = (Fl_Check_Button *)0;
 Fl_Group *genericMisc = (Fl_Group *)0;
 Hspinner *spnr_vfo_adj = (Hspinner *)0;
@@ -596,16 +612,7 @@ static void cb_btnA(Fl_Light_Button*, void*) {
 	} else {
 		if (selrig->inuse == onB) {
 			cb_selectA();
-		} else {
-			if (FreqDispA->is_reversed_colors()) {
-				FreqDispA->restore_colors();
-				Fl::focus(btnA);
-			} else {
-				FreqDispA->reverse_colors();
-				Fl::focus(FreqDispA);
-			}
 		}
-
 		btnA->value(1);
 		btnB->value(0);
 		if (progStatus.UIsize == touch_ui) {
@@ -636,14 +643,6 @@ static void cb_btnB(Fl_Light_Button*, void*) {
 	} else {
 		if (selrig->inuse == onA) {
 			cb_selectB();
-		} else { 
-			if (FreqDispB->is_reversed_colors()) {
-				FreqDispB->restore_colors();
-				Fl::focus(btnB);
-			} else {
-				FreqDispB->reverse_colors();
-				Fl::focus(FreqDispB);
-			}
 		}
 		btnB->value(1);
 		btnA->value(0);
@@ -675,10 +674,10 @@ static void cb_btnCENTER(Fl_Button *, void *) {
 }
 
 static void cb_opCENTER(Fl_ComboBox*, void*) {
-	progStatus.tci_center = tci_center = opCENTER->index();
+	progStatus.tci_center = opCENTER->index();
 	tci_adjust_widths();
-	if (onA) selrig->set_bwA(vfoA.iBW);
-	else     selrig->set_bwB(vfoB.iBW);
+	if (selrig->inuse == onA) selrig->set_bwA(vfoA.iBW);
+	else                      selrig->set_bwB(vfoB.iBW);
 }
 
 static void cb_opBW(Fl_ComboBox*, void*) {
@@ -1031,6 +1030,18 @@ static void cb_ic7610_att(Fl_ComboBox *o, void *d) {
 	index_att();
 }
 
+//static void cb_cbo_attenuator(Fl_ComboBox *o, void *d) {
+//	progStatus.attenuator = o->index();
+//	guard_lock serial(&mutex_serial);
+//	selrig->set_attenuator(progStatus.attenuator);
+//}
+
+static void cb_cbo_preamp(Fl_ComboBox *o, void *d) {
+	progStatus.preamp = o->index();
+	guard_lock serial(&mutex_serial);
+	selrig->set_preamp(progStatus.preamp);
+}
+
 static void cb_cntRIT(Hspinner*, void*) {
 	cbRIT();
 }
