@@ -79,13 +79,11 @@ Fl_Group *small_main_group(int X, int Y, int W, int H)
 
 	FreqDispA = new cFreqControl(1, 24, 210, 35, _("10"));
 	FreqDispA->when(FL_WHEN_CHANGED);
-	FreqDispA->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-	FreqDispA->setCallBack(movFreqA);
+	FreqDispA->callback((Fl_Callback*)movFreqA);
 
 	FreqDispB = new cFreqControl(213, 24, 210, 35, _("10"));
 	FreqDispB->when(FL_WHEN_CHANGED);
-	FreqDispB->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-	FreqDispB->setCallBack(movFreqB);
+	FreqDispB->callback((Fl_Callback*)movFreqB);
 
 	btnVol = new Fl_Light_Button(2, 125, 50, 18, _("Vol"));
 	btnVol->tooltip(_("Speaker on/off"));
@@ -483,6 +481,42 @@ CTRL  click: FreqB -> FreqA\
 	opDSP_hi->hide();
 	opDSP_hi->end();
 
+	opFilterInner = new Fl_Counter(231, 84, 86, 18, "");
+	opFilterInner->minimum(-4000);
+	opFilterInner->maximum(4000);
+	opFilterInner->step(10);
+	opFilterInner->lstep(100);
+	opFilterInner->align(Fl_Align(FL_ALIGN_INSIDE));
+	opFilterInner->tooltip("Inner cutoff");
+	opFilterInner->hide();
+
+	opFilterOuter = new Fl_Counter(231, 84, 86, 18, "");
+	opFilterOuter->minimum(-4000);
+	opFilterOuter->maximum(4000);
+	opFilterOuter->step(10);
+	opFilterOuter->lstep(100);
+	opFilterOuter->align(Fl_Align(FL_ALIGN_INSIDE));
+	opFilterOuter->tooltip("Outer cutoff");
+	opFilterOuter->hide();
+
+	opBW_A = new Fl_Counter(231, 84, 86, 18, "");
+	opBW_A->minimum(0);
+	opBW_A->maximum(9990);
+	opBW_A->step(10);
+	opBW_A->lstep(100);
+	opBW_A->align(Fl_Align(FL_ALIGN_INSIDE));
+	opBW_A->tooltip("BW vfoA");
+	opBW_A->hide();
+
+	opBW_B = new Fl_Counter(231, 84, 86, 18, "");
+	opBW_B->minimum(0);
+	opBW_B->maximum(9990);
+	opBW_B->step(10);
+	opBW_B->lstep(100);
+	opBW_B->align(Fl_Align(FL_ALIGN_INSIDE));
+	opBW_B->tooltip("BW vfoB");
+	opBW_B->hide();
+
 	opMODE = new Fl_ComboBox(318, 84, 105, 18, _("Mode"));
 	opMODE->tooltip(_("Select transceiver operating mode"));
 	opMODE->box(FL_NO_BOX);
@@ -508,6 +542,18 @@ CTRL  click: FreqB -> FreqA\
 	btnAttenuator->labelsize(12);
 	btnAttenuator->callback((Fl_Callback*)cb_btnAttenuator);
 
+	cbo_preamp = new Fl_ComboBox(26, 325, 80, 18, "");
+	cbo_preamp->tooltip(_("Preamp in dB"));
+	cbo_preamp->labelsize(12);
+	cbo_preamp->add("-10 dB|0 dB|10 dB|20 dB|30 dB");
+	cbo_preamp->color(FL_BACKGROUND2_COLOR);
+	cbo_preamp->selection_color(FL_BACKGROUND_COLOR);
+	cbo_preamp->align(FL_ALIGN_LEFT);
+	cbo_preamp->index(progStatus.preamp);
+	cbo_preamp->readonly();
+	cbo_preamp->callback((Fl_Callback*)cb_cbo_preamp);
+	cbo_preamp->hide();
+
 	btnPreamp = new Fl_Light_Button(93, 325, 60, 18, _("PRE"));
 	btnPreamp->tooltip(_("Preamp On/Off"));
 	btnPreamp->down_box(FL_THIN_DOWN_BOX);
@@ -543,18 +589,18 @@ CTRL  click: FreqB -> FreqA\
 	btnPTT->tooltip(_("Xmt On/Off"));
 	btnPTT->callback((Fl_Callback*)cb_btnPTT);
 
-	Fl_Group* sm_grp1 = new Fl_Group(1, 62, 210, 60);
+	sm_grp1 = new Fl_Group(1, 62, 210, 60);
 		sm_grp1->box(FL_DOWN_BOX);
 
-		grpMeters = new Fl_Group(3, 63, 206, 57);
+		grpMeters = new Fl_Group(sm_grp1->x() + 2, sm_grp1->y() + 2, sm_grp1->w() - 4, sm_grp1->h() - 4);
 		grpMeters->box(FL_FLAT_BOX);
 
-			scaleSmeter = new Fl_Box(3, 63, 206, 20);
+			scaleSmeter = new Fl_Box(grpMeters->x(), grpMeters->y(), grpMeters->w(), 20);
 			scaleSmeter->box(FL_FLAT_BOX);
 			scaleSmeter->image(image_S60);
 			scaleSmeter->tooltip(_("S units meter"));
 
-			btnALC_IDD_SWR = new Fl_Button(3, 63, 206, 20);
+			btnALC_IDD_SWR = new Fl_Button(grpMeters->x(), grpMeters->y(), grpMeters->w(), 20);
 			btnALC_IDD_SWR->tooltip(_("Press SWR / ALC"));
 			btnALC_IDD_SWR->box(FL_FLAT_BOX);
 			btnALC_IDD_SWR->down_box(FL_FLAT_BOX);
@@ -669,37 +715,6 @@ CTRL  click: FreqB -> FreqA\
 
 	sm_grp1->end();
 
-	cntRIT = new Hspinner(213, 104, 54, 18, _("R"));
-	cntRIT->tooltip(_("RIT"));
-	cntRIT->type(FL_INT_INPUT);
-	cntRIT->labelsize(12);
-	cntRIT->minimum(-1000);
-	cntRIT->maximum(1000);
-	cntRIT->step(10);
-	cntRIT->callback((Fl_Callback*)cb_cntRIT);
-	cntRIT->align(Fl_Align(FL_ALIGN_RIGHT));
-
-	cntXIT = new Hspinner(283, 104, 54, 18, _("X"));
-	cntXIT->tooltip(_("XIT"));
-	cntXIT->type(FL_INT_INPUT);
-	cntXIT->labelsize(12);
-	cntXIT->minimum(-1000);
-	cntXIT->maximum(1000);
-	cntXIT->step(10);
-	cntXIT->callback((Fl_Callback*)cb_cntXIT);
-	cntXIT->align(Fl_Align(FL_ALIGN_RIGHT));
-
-	cntBFO = new Hspinner(355, 104, 54, 18, _("B"));
-	cntBFO->tooltip(_("BFO"));
-	cntBFO->type(FL_INT_INPUT);
-	cntBFO->labelsize(12);
-	cntBFO->minimum(0);
-	cntBFO->maximum(1000);
-	cntBFO->step(10);
-	cntBFO->value(600);
-	cntBFO->callback((Fl_Callback*)cb_cntBFO);
-	cntBFO->align(Fl_Align(FL_ALIGN_RIGHT));
-
 	g->end();
 
 	return g;
@@ -1869,6 +1884,48 @@ Fl_Double_Window *tabs_window()
 
 		tab7610->end();
 }
+
+		genericRXB = new Fl_Group(0, 24, small_mainW, gph - 24, _("RIT/XIT/BFO"));
+{
+			cntRIT = new Hspinner(5, genericRXB->y() + 10, 100, 24, _("Rit"));
+			cntRIT->tooltip(_("RIT"));
+			cntRIT->type(FL_INT_INPUT);
+			cntRIT->labelsize(12);
+			cntRIT->minimum(-1000);
+			cntRIT->maximum(1000);
+			cntRIT->step(10);
+			cntRIT->callback((Fl_Callback*)cb_cntRIT);
+			cntRIT->align(Fl_Align(FL_ALIGN_RIGHT));
+
+			cntXIT = new Hspinner(
+				cntRIT->x() + cntRIT->w() + 15,
+				cntRIT->y(), 100, 24, _("Xit"));
+			cntXIT->tooltip(_("XIT"));
+			cntXIT->type(FL_INT_INPUT);
+			cntXIT->labelsize(12);
+			cntXIT->minimum(-1000);
+			cntXIT->maximum(1000);
+			cntXIT->step(10);
+			cntXIT->callback((Fl_Callback*)cb_cntXIT);
+			cntXIT->align(Fl_Align(FL_ALIGN_RIGHT));
+
+			cntBFO = new Hspinner(
+				cntXIT->x() + cntXIT->w() + 15,
+				cntXIT->y(), 100, 24, _("Bfo"));
+			cntBFO->tooltip(_("BFO"));
+			cntBFO->type(FL_INT_INPUT);
+			cntBFO->labelsize(12);
+			cntBFO->minimum(0);
+			cntBFO->maximum(1000);
+			cntBFO->step(10);
+			cntBFO->value(600);
+			cntBFO->callback((Fl_Callback*)cb_cntBFO);
+			cntBFO->align(Fl_Align(FL_ALIGN_RIGHT));
+
+		genericRXB->end();
+		genericRXB->hide();
+}
+
 		genericAux = new Fl_Group(0, 24, small_mainW, gph - 24, _("Aux"));
 {
 			btnAuxRTS = new Fl_Light_Button(5, genericAux->y() + 10, 60, 18, _("RTS"));
