@@ -405,6 +405,42 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		opDSP_hi->hide();
 		opDSP_hi->end();
 
+		opFilterInner = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("Inner cutoff"));
+		opFilterInner->minimum(-4000);
+		opFilterInner->maximum(4000);
+		opFilterInner->step(10);
+		opFilterInner->lstep(100);
+		opFilterInner->align(Fl_Align(FL_ALIGN_LEFT));
+		opFilterInner->tooltip("Inner cutoff");
+		opFilterInner->hide();
+
+		opFilterOuter = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("Inner cutoff"));
+		opFilterOuter->minimum(-4000);
+		opFilterOuter->maximum(4000);
+		opFilterOuter->step(10);
+		opFilterOuter->lstep(100);
+		opFilterOuter->align(Fl_Align(FL_ALIGN_LEFT));
+		opFilterOuter->tooltip("Outer cutoff");
+		opFilterOuter->hide();
+
+		opBW_A = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoA"));
+		opBW_A->minimum(0);
+		opBW_A->maximum(9990);
+		opBW_A->step(10);
+		opBW_A->lstep(100);
+		opBW_A->align(Fl_Align(FL_ALIGN_LEFT));
+		opBW_A->tooltip("BW vfoA");
+		opBW_A->hide();
+
+		opBW_B = new Fl_Counter(xpos+30, ypos, opBW->w() - 30, 35, _("BW vfoB"));
+		opBW_B->minimum(0);
+		opBW_B->maximum(9990);
+		opBW_B->step(10);
+		opBW_B->lstep(100);
+		opBW_B->align(Fl_Align(FL_ALIGN_LEFT));
+		opBW_B->tooltip("Bw vfoB");
+		opBW_B->hide();
+
 		grpcombos->end();
 // end of bw / mode selector group
 
@@ -414,14 +450,12 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		FreqDispA = new cFreqControl(xpos, ypos, 480, 100, _("10"));
 		FreqDispA->labeltype(FL_NORMAL_LABEL);
 		FreqDispA->when(FL_WHEN_CHANGED);
-		FreqDispA->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-		FreqDispA->setCallBack(movFreqA);
+		FreqDispA->callback((Fl_Callback*)movFreqA);
 
 // FreqDispB hides behind FreqDispA
 		FreqDispB = new cFreqControl(xpos, ypos, 480, 100, _("10"));
 		FreqDispB->when(FL_WHEN_CHANGED);
-		FreqDispB->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-		FreqDispB->setCallBack(movFreqB);
+		FreqDispB->callback((Fl_Callback*)movFreqB);
 		FreqDispB->hide();
 
 		xpos += FreqDispA->w() + 2;
@@ -818,6 +852,18 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		btnAttenuator->labelsize(16);
 		btnAttenuator->callback((Fl_Callback*)cb_btnAttenuator);
 
+		cbo_preamp = new Fl_ComboBox(xpos, ypos, 140, bh, "");
+		cbo_preamp->tooltip(_("Preamp in dB"));
+		cbo_preamp->labelsize(12);
+		cbo_preamp->add("-10 dB|0 dB|10 dB|20 dB|30 dB");
+		cbo_preamp->color(FL_BACKGROUND2_COLOR);
+		cbo_preamp->selection_color(FL_BACKGROUND_COLOR);
+		cbo_preamp->align(FL_ALIGN_LEFT);
+		cbo_preamp->index(progStatus.preamp);
+		cbo_preamp->readonly();
+		cbo_preamp->callback((Fl_Callback*)cb_cbo_preamp);
+		cbo_preamp->hide();
+
 		xpos += btnAttenuator->w() + 2;
 		btnPreamp = new Fl_Light_Button(xpos, ypos, bw, bh, _("PRE"));
 		btnPreamp->tooltip(_("Preamp On/Off"));
