@@ -227,8 +227,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 		FreqDispA = new cFreqControl(
 			wd_grp1b->x(), wd_grp1b->y(), wd_grp1b->w(), wd_grp1b->h(), "10");
 			FreqDispA->when(FL_WHEN_CHANGED);
-			FreqDispA->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-			FreqDispA->setCallBack(movFreqA);
+			FreqDispA->callback((Fl_Callback*)movFreqA);
 }
 		wd_grp1b->end();
 
@@ -240,8 +239,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			FreqDispB = new cFreqControl(
 				wd_grp1c->x(), wd_grp1->y(), wd_grp1c->w(), 38, "10");
 			FreqDispB->when(FL_WHEN_CHANGED);
-			FreqDispB->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
-			FreqDispB->setCallBack(movFreqB);
+			FreqDispB->callback((Fl_Callback*)movFreqB);
 
 			grp_row0a = new Fl_Group(
 				wd_grp1c->x() + 2, wd_grp1c->y() + FreqDispB->h() + 2, 
@@ -408,6 +406,42 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				opDSP_hi->readonly();
 				opDSP_hi->end();
 
+				opFilterInner = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("Inner cutoff"));
+				opFilterInner->minimum(-4000);
+				opFilterInner->maximum(4000);
+				opFilterInner->step(10);
+				opFilterInner->lstep(100);
+				opFilterInner->align(Fl_Align(FL_ALIGN_LEFT));
+				opFilterInner->tooltip("Inner cutoff");
+				opFilterInner->hide();
+
+				opFilterOuter = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("Inner cutoff"));
+				opFilterOuter->minimum(-4000);
+				opFilterOuter->maximum(4000);
+				opFilterOuter->step(10);
+				opFilterOuter->lstep(100);
+				opFilterOuter->align(Fl_Align(FL_ALIGN_LEFT));
+				opFilterOuter->tooltip("Outer cutoff");
+				opFilterOuter->hide();
+
+				opBW_A = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("BW vfoA"));
+				opBW_A->minimum(0);
+				opBW_A->maximum(9990);
+				opBW_A->step(10);
+				opBW_A->lstep(100);
+				opBW_A->align(Fl_Align(FL_ALIGN_LEFT));
+				opBW_A->tooltip("BW vfoA");
+				opBW_A->hide();
+
+				opBW_B = new Fl_Counter(xpos + 20, ypos, w1a - 20, 20, _("BW vfoB"));
+				opBW_B->minimum(0);
+				opBW_B->maximum(9990);
+				opBW_B->step(10);
+				opBW_B->lstep(100);
+				opBW_B->align(Fl_Align(FL_ALIGN_LEFT));
+				opBW_B->tooltip("BW vfoB");
+				opBW_B->hide();
+
 				opMODE = new Fl_ComboBox(
 					opBW->x() + opBW->w() + 2, ypos, 
 					w1a, 20, _("Mode"));
@@ -448,6 +482,18 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 						btnAttenuator->labelsize(12);
 						btnAttenuator->callback((Fl_Callback*)cb_btnAttenuator);
 
+						cbo_preamp = new Fl_ComboBox(bx_row1b1a->x() + bx_row1b1a->w(), ypos, 140, 20, "");
+						cbo_preamp->tooltip(_("Preamp in dB"));
+						cbo_preamp->labelsize(12);
+						cbo_preamp->add("-10 dB|0 dB|10 dB|20 dB|30 dB");
+						cbo_preamp->color(FL_BACKGROUND2_COLOR);
+						cbo_preamp->selection_color(FL_BACKGROUND_COLOR);
+						cbo_preamp->align(FL_ALIGN_LEFT);
+						cbo_preamp->index(progStatus.preamp);
+						cbo_preamp->readonly();
+						cbo_preamp->callback((Fl_Callback*)cb_cbo_preamp);
+						cbo_preamp->hide();
+
 						btnPreamp = new Fl_Light_Button(
 							btnAttenuator->x() + btnAttenuator->w() + 2, ypos, 
 							70, 20, _("PRE"));
