@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC7100_H
@@ -37,11 +37,11 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA ();
-	void set_vfoA (unsigned long int freq);
+	unsigned long long get_vfoA ();
+	void set_vfoA (unsigned long long freq);
 
-	unsigned long int get_vfoB(void);
-	void set_vfoB(unsigned long int f);
+	unsigned long long get_vfoB(void);
+	void set_vfoB(unsigned long long f);
 
 	void set_modeA(int val);
 	int  get_modeA();
@@ -65,6 +65,9 @@ public:
 	int  next_preamp();
 	int  get_preamp();
 
+	const char * PRE_label();
+	const char * ATT_label();
+
 	void set_mic_gain(int v);
 	int  get_mic_gain();
 	void get_mic_gain_min_max_step(int &min, int &max, int &step);
@@ -147,10 +150,6 @@ public:
 	void set_notch(bool on, int val);
 	void get_notch_min_max_step(int &min, int &max, int &step);
 
-	void set_if_shift(int val);
-	bool get_if_shift(int &val);
-	void get_if_min_max_step(int &min, int &max, int &step);
-
 	void set_pbt_inner(int val);
 	void set_pbt_outer(int val);
 
