@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC7300_H
@@ -39,11 +39,11 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA ();
-	void set_vfoA (unsigned long int freq);
+	unsigned long long get_vfoA ();
+	void set_vfoA (unsigned long long freq);
 
-	unsigned long int get_vfoB(void);
-	void set_vfoB(unsigned long int f);
+	unsigned long long get_vfoB(void);
+	void set_vfoB(unsigned long long f);
 
 	void set_modeA(int val);
 	int  get_modeA();
@@ -67,10 +67,6 @@ public:
 	int  adjust_bandwidth(int m);
 	int  def_bandwidth(int m);
 
-	void set_if_shift(int val);
-	void get_if_min_max_step(int &min, int &max, int &step);
-	bool get_if_shift(int &val);
-
 	void set_pbt_inner(int val);
 	void set_pbt_outer(int val);
 
@@ -149,10 +145,12 @@ public:
 	void set_preamp(int val);
 	int  get_preamp();
 	int  next_preamp();
+	const char * PRE_label();
 
 	void set_attenuator(int val);
 	int  get_attenuator();
 	int  next_attenuator();
+	const char * ATT_label();
 
 	void set_noise(bool val);
 	int  get_noise();
