@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC746_H
@@ -34,10 +34,10 @@ public:
 
 	bool check();
 
-	virtual unsigned long int get_vfoA(void);
-	virtual void set_vfoA(unsigned long int f);
-	virtual unsigned long int get_vfoB(void);
-	virtual void set_vfoB(unsigned long int f);
+	virtual unsigned long long get_vfoA(void);
+	virtual void set_vfoA(unsigned long long f);
+	virtual unsigned long long get_vfoB(void);
+	virtual void set_vfoB(unsigned long long f);
 
 	virtual int  get_smeter();
 	virtual void set_volume_control(int val);
@@ -51,12 +51,16 @@ public:
 	virtual int  get_noise_reduction();
 	virtual void set_noise_reduction_val(int val);
 	virtual int  get_noise_reduction_val();
+
 	virtual void set_attenuator(int val);
 	virtual int  get_attenuator();
 	virtual int  next_preamp();
 	virtual void set_preamp(int val);
 	virtual int  get_preamp();
 
+	virtual const char * PRE_label();
+	virtual const char * ATT_label();
+
 	virtual int  get_modetype(int n);
 	virtual void set_modeA(int val);
 	virtual int  get_modeA();
@@ -126,6 +130,9 @@ public:
 	virtual void set_preamp(int val);
 	virtual int  get_preamp();
 
+	virtual const char * PRE_label();
+	virtual const char * ATT_label();
+
 	virtual void set_mic_gain(int val);
 	virtual int  get_mic_gain();
 	virtual void get_mic_gain_min_max_step(int &min, int &max, int &step);
