@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC7610_H
@@ -35,11 +35,11 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA ();
-	void set_vfoA (unsigned long int freq);
+	unsigned long long get_vfoA ();
+	void set_vfoA (unsigned long long freq);
 
-	unsigned long int get_vfoB(void);
-	void set_vfoB(unsigned long int f);
+	unsigned long long get_vfoB(void);
+	void set_vfoB(unsigned long long f);
 
 	bool twovfos() { return true; }
 
@@ -154,6 +154,9 @@ public:
 	int  get_attenuator();
 	int  next_attenuator(){return 0;}
 
+	const char * PRE_label();
+	const char * ATT_label();
+
 	void set_noise(bool val);
 	int  get_noise();
 	void set_nb_level(int val);
