@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _ICF8101_H
@@ -38,11 +38,11 @@ public:
 	void selectA();
 	void selectB();
 
-	unsigned long int get_vfoA ();
-	void set_vfoA (unsigned long int freq);
+	unsigned long long get_vfoA ();
+	void set_vfoA (unsigned long long freq);
 
-	unsigned long int get_vfoB(void);
-	void set_vfoB(unsigned long int f);
+	unsigned long long get_vfoB(void);
+	void set_vfoB(unsigned long long f);
 
 	int  get_modetype(int n);
 	void set_modeA(int val);
@@ -111,6 +111,9 @@ public:
 	int  next_preamp();
 	int  get_preamp();
 
+	const char * PRE_label();
+//	const char * ATT_label();
+
 //	void set_attenuator(int val);
 //	int  next_attenuator();
 //	int  get_attenuator();
