@@ -16,7 +16,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _FLEX1500_H
@@ -25,6 +25,10 @@
 #include "kenwood/KENWOOD.h"
 
 class RIG_FLEX1500 : public KENWOOD {
+private:
+	int FilterInner;
+	int FilterOuter;
+
 public:
 
 enum FLEX1500MODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM };
@@ -35,10 +39,10 @@ enum FLEX1500MODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 	void initialize();
 	void shutdown();
 
-//	unsigned long int get_vfoA();
-//	void set_vfoA(unsigned long int);
-//	unsigned long int get_vfoB();
-//	void set_vfoB(unsigned long int);
+//	unsigned long long get_vfoA();
+//	void set_vfoA(unsigned long long);
+//	unsigned long long get_vfoB();
+//	void set_vfoB(unsigned long long);
 
 //	void selectA();
 //	void selectB();
@@ -54,25 +58,33 @@ enum FLEX1500MODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 	void set_modeA(int val);
 	int  get_modeA();
 
+	int  get_bw(int);
+
 	void set_bwA(int val);
 	int  get_bwA();
 
 	void set_modeB(int val);
 	int  get_modeB();
+
 	void set_bwB(int val);
 	int  get_bwB();
+
 	int  def_bandwidth(int);
 
+	int  get_pbt_inner();
+	int  get_pbt_outer();
+	void set_pbt(int inner, int outer);
+
 	int  get_modetype(int n);
 	int  adjust_bandwidth(int val);
 	int  set_widths(int val);
 
 	int  get_smeter();
-//	int  get_swr();
-//	int  get_alc();
+	int  get_swr();
+	int  get_alc();
+	int  get_power_out();
 //	void select_swr();
 //	void select_alc();
-//	int  get_power_out();
 
 	double get_power_control();
 //	void set_volume_control(int val);
@@ -82,10 +94,13 @@ enum FLEX1500MODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 		min = 5; max =  100; step = 1; }
 
 	void tune_rig(int val);
-    int get_tune();
-//	void set_preamp(int val);
-//	int  get_preamp();
-//  int next_preamp();
+	int get_tune();
+
+	int  get_preamp();
+	void set_preamp(int);
+
+//	int next_preamp();
+//	const char * PRE_label();
 
 //	void set_if_shift(int val);
 //	bool get_if_shift(int &val);
