@@ -16,7 +16,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _PowerSDR_H
@@ -35,10 +35,10 @@ enum PowerSDRMODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 	void initialize();
 	void shutdown();
 
-//	unsigned long int get_vfoA();
-//	void set_vfoA(unsigned long int);
-//	unsigned long int get_vfoB();
-//	void set_vfoB(unsigned long int);
+//	unsigned long long get_vfoA();
+//	void set_vfoA(unsigned long long);
+//	unsigned long long get_vfoB();
+//	void set_vfoB(unsigned long long);
 
 //	void selectA();
 //	void selectB();
@@ -81,10 +81,17 @@ enum PowerSDRMODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 		min = 5; max =  100; step = 1; }
 
 	void tune_rig(int val);
-    int get_tune();
+	int get_tune();
+
 //	void set_preamp(int val);
 //	int  get_preamp();
-//  int next_preamp();
+//	int next_preamp();
+//	const char * PRE_label();
+
+	int  get_agc();
+	int  incr_agc();
+	int  agc_val();
+	const char *agc_label();
 
 //	void set_if_shift(int val);
 //	bool get_if_shift(int &val);
@@ -120,6 +127,9 @@ enum PowerSDRMODES { LSB, USB, DSB, CWL, CWU, FM, AM, DIGU, SPEC, DIGL, SAM, DRM
 	int  get_squelch();
 	void get_squelch_min_max_step(int &min, int &max, int &step);
 
+    double get_voltmeter();
+    double get_idd();
+
 	bool tuning();
 
 //	bool sendTScommand(string, int, bool);
