@@ -15,12 +15,15 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _RIG_BASE_H
 #define _RIG_BASE_H
 
+#include "config.h"
+#include "compat.h" // Must precede all FL includes
+
 #include <string>
 #include <cmath>
 #include <cstdlib>
@@ -39,9 +42,12 @@ enum {DT_BINARY, DT_STRING};
 enum {SERIAL, TCPIP, TCI};
 
 struct XCVR_STATE {
-	unsigned long int freq;
+	unsigned long long freq;
 	int  imode;
 	int  iBW;
+	int  bw_val;
+	int  FilterInner;
+	int  FilterOuter;
 	int  filter;
 	int  src;
 
@@ -70,6 +76,8 @@ struct XCVR_STATE {
 		freq = 0;
 		imode = 0;
 		iBW = 0;
+		FilterInner = 0;
+		FilterOuter = 0;
 		filter = 0;
 		src = UI;
 
@@ -93,8 +101,9 @@ struct XCVR_STATE {
 		squelch = 0;
 		compression = 0;
 		compON = 0;
+		bw_val = 0;
 	}
-	XCVR_STATE(int a, int b, int c, int d) {
+	XCVR_STATE(unsigned long long a, int b, int c, int d) {
 		XCVR_STATE();
 		freq = a;
 		imode = b;
@@ -158,19 +167,22 @@ public:
 	GUI *widgets;
 
 	int  io_class;
-	int  comm_baudrate;
+	int  serial_baudrate;
 	int  stopbits;
-	int  comm_retries;
-	int  comm_wait;
-	int  comm_timeout;
-	bool comm_echo;
-	bool comm_rtscts;
-	bool comm_rtsplus;
-	bool comm_dtrplus;
-	bool comm_catptt;
-	bool comm_rtsptt;
-	bool comm_dtrptt;
+	bool serial_echo;
+	bool serial_rtscts;
+	bool serial_rtsplus;
+	bool serial_dtrplus;
+	bool serial_catptt;
+	bool serial_rtsptt;
+	bool serial_dtrptt;
+	int  serial_retries;
+
+	int  serial_write_delay;
+	int  serial_post_write_delay;
+	int  serial_timeout;
 	int  serloop_timing;
+
 	int  CIV;
 	int  defaultCIV;
 	bool USBaudio;
@@ -181,10 +193,12 @@ public:
 
 	int  modeA;
 	int  bwA;
-	unsigned long int freqA;
+	int  bwA_val;
+	unsigned long long freqA;
 	int  modeB;
 	int  bwB;
-	unsigned long int freqB;
+	int  bwB_val;
+	unsigned long long freqB;
 	int  precision;
 	int  ndigits;
 	bool can_change_alt_vfo;
@@ -192,7 +206,7 @@ public:
 
 	int  def_mode;
 	int  def_bw;
-	unsigned long int def_freq;
+	unsigned long long def_freq;
 	int  max_power;
 	int  last_bw;
 	int  bpf_center;
@@ -317,18 +331,18 @@ protected:
 	std::string cmd; // command string
 	std::string rsp; // expected response string (header etc)
 
-	std::string to_bcd_be(unsigned long int freq, int len);
-	std::string to_bcd(unsigned long int freq, int len);
-	unsigned long int fm_bcd (std::string bcd, int len);
-	unsigned long int fm_bcd_be(std::string bcd, int len);
-	std::string to_binary_be(unsigned long int freq, int len);
-	std::string to_binary(unsigned long int freq, int len);
-	unsigned long int fm_binary(std::string binary, int len);
-	unsigned long int fm_binary_be(std::string binary_be, int len);
-	std::string to_decimal_be(unsigned long int d, int len);
-	std::string to_decimal(unsigned long int d, int len);
-	unsigned long int fm_decimal(std::string decimal, int len);
-	unsigned long int fm_decimal_be(std::string decimal_be, int len);
+	std::string to_bcd_be(unsigned long long val, int len);
+	std::string to_bcd(unsigned long long val, int len);
+	unsigned long long fm_bcd (std::string bcd, int len);
+	unsigned long long fm_bcd_be(std::string bcd, int len);
+	std::string to_binary_be(unsigned long long val, int len);
+	std::string to_binary(unsigned long long val, int len);
+	unsigned long long fm_binary(std::string binary, int len);
+	unsigned long long fm_binary_be(std::string binary_be, int len);
+	std::string to_decimal_be(unsigned long long d, int len);
+	std::string to_decimal(unsigned long long d, int len);
+	unsigned long long fm_decimal(std::string decimal, int len);
+	unsigned long long fm_decimal_be(std::string decimal_be, int len);
 
 public:
 	rigbase();
@@ -343,10 +357,10 @@ public:
 	virtual void set_data_port() {}
 
 	virtual bool get_info(void) {return false;}
-	virtual unsigned long int get_vfoA(void) {return A.freq;}
-	virtual void set_vfoA(unsigned long int f) {A.freq = f;}
-	virtual unsigned long int get_vfoB(void) {return B.freq;}
-	virtual void set_vfoB(unsigned long int f) {B.freq = f; set_vfoA(f);}
+	virtual unsigned long long get_vfoA(void) {return A.freq;}
+	virtual void set_vfoA(unsigned long long f) {A.freq = f;}
+	virtual unsigned long long get_vfoB(void) {return B.freq;}
+	virtual void set_vfoB(unsigned long long f) {B.freq = f; set_vfoA(f);}
 
 	virtual void set_modeA(int val) {A.imode = val;}
 	virtual int  get_modeA() {return A.imode;}
@@ -365,8 +379,10 @@ public:
 
 	virtual void set_bwA(int val) {A.iBW = val;}
 	virtual int  get_bwA() {return A.iBW;}
+	virtual int  get_bwA_val() { return bwA_val; }
 	virtual void set_bwB(int val) {B.iBW = val; set_bwA(val);}
 	virtual int  get_bwB() {return B.iBW;}
+	virtual int  get_bwB_val() { return bwB_val; }
 	virtual int  adjust_bandwidth(int m) {return 0;}
 	virtual int  def_bandwidth(int m) {return 0;}
 	virtual const char **bwtable(int m) {return bandwidths_;}
@@ -437,6 +453,7 @@ int tune_;
 		return atten_level;
 	}
 	virtual int  get_attenuator() {return atten_level;}
+	virtual const char *ATT_label() { return "ATT"; }
 
 	virtual void set_preamp(int val) {preamp_level = val;}
 	virtual int  next_preamp() { 
@@ -445,6 +462,7 @@ int tune_;
 		return preamp_level;
 	}
 	virtual int  get_preamp() {return preamp_level;}
+	virtual const char *PRE_label() { return "PRE"; }
 
 // CTCSS tones / offset
 	virtual void set_tones(int tx_tone, int rx_tone) { return; }
@@ -483,6 +501,7 @@ int nr_, nrval_;
 
 	virtual void set_pbt_inner(int val) {}
 	virtual void set_pbt_outer(int val) {}
+	virtual void set_pbt(int inner, int outer) {}
 	virtual int  get_pbt_inner() {return 0;}
 	virtual int  get_pbt_outer() {return 0;}
 
@@ -632,8 +651,9 @@ double vfo_;
 	virtual int  parse_alc(std::string){return 0;}
 	virtual int  parse_split(std::string){return 0;}
 
-	int waitN(size_t n, int timeout, const char *, int pr = HEX);
-	int wait_char(int ch, size_t n, int timeout, const char *, int pr = HEX);
+	int waitN(int n, int timeout, const char *, int pr = HEX);
+	int wait_char(int ch, int n, int timeout, const char *, int pr = HEX);
+	int wait_crlf(std::string, std::string, int nr = 20, int timeout = 100, int pr = ASC);
 
 // IC-7610
 	virtual void set_digi_sel(bool) {}
