@@ -45,12 +45,13 @@
 #include <FL/Fl_Browser.H>
 #include <FL/Fl_Input.H>
 #include <FL/Fl_Int_Input.H>
-#include <FL/Fl_Value_Input.H>
+#include <FL/Fl_Counter.H>
 #include <FL/Fl_Check_Button.H>
 #include <FL/Fl_Counter.H>
 #include <FL/Fl_Simple_Counter.H>
 #include <FL/Fl_Progress.H>
 #include <FL/Fl_Input_Choice.H>
+#include <FL/Fl_Counter.H>
 
 #include "flinput2.h"
 #include "flbrowser2.h"
@@ -76,8 +77,9 @@ extern void select_power_meter_scales();
 
 extern Fl_Output *txt_encA;
 
+extern Fl_Group *sm_grp1;
 extern Fl_Group *grpMeters;
-extern Fl_Box *scaleSmeter;
+extern Fl_Box   *scaleSmeter;
 
 extern Fl_Button *btnALC_IDD_SWR;
 
@@ -112,11 +114,17 @@ extern Fl_Group *grp_row1a;
 
 extern Fl_ComboBox *opCENTER;
 extern Fl_ComboBox *opBW;
+extern Fl_Counter *opBW_A;
+extern Fl_Counter *opBW_B;
+
 extern Fl_Button *btnDSP;
 extern Fl_ComboBox *opDSP_lo;
 extern Fl_ComboBox *opDSP_hi;
+extern Fl_Counter *opFilterInner;
+extern Fl_Counter *opFilterOuter;
 extern Fl_Button *btnFILT;
 extern Fl_Button *btnCENTER;
+
 extern Fl_ComboBox *opMODE;
 extern Fl_Group *grp_row1b;
 extern Fl_Group *grp_row1b1;
@@ -132,6 +140,9 @@ extern Fl_Box *bx_row1_expander2;
 extern Fl_Group *grp_row2;
 extern Fl_Group *grp_row2a;
 
+extern Fl_ComboBox *cbo_attenuator;
+extern Fl_ComboBox *cbo_preamp;
+
 extern Fl_Wheel_Value_Slider *sldrSQUELCH;
 extern Fl_Wheel_Value_Slider *sldrMICGAIN;
 extern Fl_Box *bx_sep2a;
@@ -496,9 +507,9 @@ extern Fl_Input2 * cmdtext16;
 
 extern Fl_Counter *cntRigCatRetries;
 extern Fl_Counter *cntRigCatTimeout;
-extern Fl_Counter *cntRigCatWait;
+extern Fl_Counter *cntWriteDelay;;
+extern Fl_Counter *cntPostWriteDelay;
 extern Fl_Counter *query_interval;
-extern Fl_Counter *byte_interval;
 
 extern Fl_ComboBox *selectCommPort;
 extern Fl_ComboBox *mnuBaudrate;
@@ -550,6 +561,7 @@ extern Fl_Check_Button *poll_micgain;
 extern Fl_Check_Button *poll_rfgain;
 extern Fl_Check_Button *poll_power_control;
 extern Fl_Check_Button *poll_ifshift;
+extern Fl_Check_Button *poll_pbt;
 extern Fl_Check_Button *poll_notch;
 extern Fl_Check_Button *poll_auto_notch;
 extern Fl_Check_Button *poll_pre_att;
