@@ -44,15 +44,6 @@
 #include <vector>
 #include <queue>
 
-#include <FL/Fl.H>
-#include <FL/Enumerations.H>
-#include <FL/Fl_Tree.H>
-#include <FL/Fl_Text_Display.H>
-#include <FL/Fl_Text_Buffer.H>
-#include <FL/fl_draw.H>
-#include <FL/fl_show_colormap.H>
-#include <FL/fl_ask.H>
-
 #include "rig.h"
 #include "rigbase.h"
 #include "rig_io.h"
@@ -84,6 +75,17 @@
 #include "cmedia.h"
 #include "tmate2.h"
 
+#include <FL/Fl.H>
+#include <FL/Enumerations.H>
+#include <FL/Fl_Tree.H>
+#include <FL/Fl_Text_Display.H>
+#include <FL/Fl_Text_Buffer.H>
+#include <FL/Fl_Widget.H>
+#include <FL/fl_draw.H>
+#include <FL/fl_show_colormap.H>
+#include <FL/fl_ask.H>
+
+
 #define LISTSIZE 200
 #define ATAGSIZE 128 //21
 
@@ -131,6 +133,8 @@ extern void set_bandwidth_control();
 extern void updateBandwidthControl(void *d = NULL);
 extern void updateUI(void *);
 extern void update_split(void *);
+extern void updateTCI(void *);
+extern void updateFLEX1500(void *);
 extern void setBWControl(void *);
 extern void setNotchControl(void *);
 extern void adjust_if_shift_control(void *);
@@ -159,8 +163,8 @@ extern void clearList();
 extern void saveFreqList();
 extern void readList();
 extern void selectFreq();
-extern int  movFreqA();
-extern int  movFreqB();
+extern void movFreqA(Fl_Widget *, void *);
+extern void movFreqB(Fl_Widget *, void *);
 extern void adjustFreqs();
 extern void cbABactive();
 extern void cbA2B();
@@ -296,13 +300,11 @@ extern void open_tmate2_tab();
 
 extern void cb_close_TT550_setup();
 extern void cbUseRepeatButtons(bool on);
+
 extern void nr_label(const char *, int on = 0);
 extern void nb_label(const char *, int on = 0);
-extern void preamp_label(const char *, int on = 0);
-extern void atten_label(const char *, int on = 0);
 extern void auto_notch_label(const char *, int on = 0);
 extern void enable_yaesu_bandselect(int btn_num, bool enable = true);
-
 extern void break_in_label(const char *);
 
 extern void synchronize_now();
