@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _FT2000_H
@@ -39,10 +39,10 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA();
-	void set_vfoA(unsigned long int);
-	unsigned long int get_vfoB();
-	void set_vfoB(unsigned long int);
+	unsigned long long get_vfoA();
+	void set_vfoA(unsigned long long);
+	unsigned long long get_vfoB();
+	void set_vfoB(unsigned long long);
 
 	int  get_smeter();
 	int  get_swr();
@@ -55,12 +55,17 @@ public:
 	int  get_PTT();
 	void tune_rig(int);
 	int  get_tune();
+
 	int  next_attenuator();
 	void set_attenuator(int val);
 	int  get_attenuator();
 	int  next_preamp();
 	void set_preamp(int val);
 	int  get_preamp();
+
+	const char * ATT_label();
+	const char * PRE_label();
+
 	void set_modeA(int val);
 	int  get_modeA();
 	void set_modeB(int val);
