@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _FTdx10_H
@@ -35,11 +35,11 @@ public:
 
 	virtual bool check();
 
-	virtual unsigned long int get_vfoA();
-	virtual void set_vfoA(unsigned long int);
+	virtual unsigned long long get_vfoA();
+	virtual void set_vfoA(unsigned long long);
 
-	virtual unsigned long int get_vfoB();
-	virtual void set_vfoB(unsigned long int);
+	virtual unsigned long long get_vfoB();
+	virtual void set_vfoB(unsigned long long);
 
 	virtual int get_vfoAorB();
 
@@ -88,6 +88,7 @@ public:
 	virtual int  get_PTT();
 	virtual void tune_rig(int);
 	virtual int  get_tune();
+
 	virtual int  next_attenuator();
 	virtual void set_attenuator(int val);
 	virtual int  get_attenuator();
@@ -95,6 +96,9 @@ public:
 	virtual void set_preamp(int val);
 	virtual int  get_preamp();
 
+	const char * ATT_label();
+	const char * PRE_label();
+
 	virtual void set_if_shift(int val);
 	virtual bool get_if_shift(int &val);
 	virtual void get_if_min_max_step(int &min, int &max, int &step);
