@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _FTdx3000_H
@@ -36,11 +36,11 @@ public:
 
 	bool check();
 
-	unsigned long int get_vfoA();
-	void set_vfoA(unsigned long int);
+	unsigned long long get_vfoA();
+	void set_vfoA(unsigned long long);
 
-	unsigned long int get_vfoB();
-	void set_vfoB(unsigned long int);
+	unsigned long long get_vfoB();
+	void set_vfoB(unsigned long long);
 
 	bool twovfos();
 	void selectA();
@@ -88,6 +88,7 @@ public:
 	int  get_PTT();
 	void tune_rig(int);
 	int  get_tune();
+
 	int  next_attenuator();
 	void set_attenuator(int val);
 	int  get_attenuator();
@@ -95,6 +96,9 @@ public:
 	void set_preamp(int val);
 	int  get_preamp();
 
+	const char * ATT_label();
+	const char * PRE_label();
+
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
 	void get_if_min_max_step(int &min, int &max, int &step);
