@@ -18,7 +18,9 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+
 #include "config.h"
+#include "compat.h"
 
 #include <stdlib.h>
 #include <iostream>
@@ -47,7 +49,6 @@
 
 #ifdef WIN32
 #  include "flrigrc.h"
-#  include "compat.h"
 #  define dirent fl_dirent_no_thanks
 #endif
 
@@ -134,6 +135,11 @@ bool EXPAND_CONTROLS = false;
 int xmlport = 12345;
 
 bool testmode = false;
+#if defined(__RESIZE_UI__)
+  void set_platform_ui(void);
+#endif
+
+bool iconified = false;
 
 //----------------------------------------------------------------------
 void about()
@@ -149,7 +155,7 @@ Developer:  Dave,  W1HKJ";
 void visit_URL(void* arg)
 {
 	const char* url = reinterpret_cast<const char *>(arg);
-#ifndef __WOE32__
+#ifndef __WIN32__
 	const char* browsers[] = {
 #  ifdef __APPLE__
 		getenv("FLDIGI_BROWSER"), // valid for any OS - set by user
@@ -193,6 +199,43 @@ void visit_URL(void* arg)
 }
 
 //----------------------------------------------------------------------
+// set __RESIZE_UI__ as a configuration parameter for compile
+// Fl::screen_dpi(...)
+// Fl::screen_scale(...)
+//   are new functionality in fltk 1.4x
+//----------------------------------------------------------------------
+
+#if defined(__RESIZE_UI__)
+void set_platform_ui(void)
+{
+
+#if defined(__APPLE__)
+	   FL_NORMAL_SIZE = 12;
+	   progdefaults.WaterfallFontsize = 12;
+	   progdefaults.RxFontsize = 12;
+	   progdefaults.TxFontsize = 12;
+#elif defined(__WOE32__)
+	   Fl::set_font(FL_HELVETICA, "Tahoma");
+	   FL_NORMAL_SIZE = 11;
+	   progdefaults.WaterfallFontnbr = FL_HELVETICA;
+	   progdefaults.WaterfallFontsize = 12;
+	   progdefaults.RxFontsize = 12;
+	   progdefaults.TxFontsize = 12;
+#else
+	   FL_NORMAL_SIZE = 12;
+#endif
+
+float dpx, dpy;
+    Fl::screen_dpi ( dpx, dpy );
+
+// std::cout << "current screen scale factor: " << Fl::screen_scale(0) << std::endl;
+
+float scrn_scale = dpx / 90.0;
+
+// std::cout << "new screen scale factor: " << scrn_scale << std::endl;
+    Fl::screen_scale(0, scrn_scale);
+}
+#endif
 
 extern void saveFreqList();
 
@@ -301,6 +344,10 @@ void startup(void*)
 {
 	initStatusConfigDialog();
 
+	if (iconified)
+		for (Fl_Window* w = Fl::first_window(); w; w = Fl::next_window(w))
+			w->iconize();
+
 	switch (progStatus.UIsize) {
 		case touch_ui :
 			mainwindow->size(progStatus.mainW, TOUCH_MAINH);
@@ -319,6 +366,7 @@ void startup(void*)
 			break;
 	}
 	start_server(xmlport);
+
 }
 
 void rotate_log(std::string filename)
@@ -432,6 +480,9 @@ int main (int argc, char *argv[])
 		exit(1);
 	}
 
+#if defined(__RESIZE_UI__)
+	set_platform_ui();
+#endif
 	progStatus.loadLastState();
 
 	if (use_trace) progStatus.trace = true;
@@ -457,6 +508,10 @@ int main (int argc, char *argv[])
 
 	progStatus.UI_laststate();
 
+	meters_dialog->resize(progStatus.metersX, progStatus.metersY, 210, 190);
+	if (progStatus.meters_dialog_visible)
+		meters_dialog->show();
+
 	cwio_keyer_dialog = new_cwio_dialog();
 	cwio_editor = new_message_editor();
 	cwio_configure = new_cwio_config_dialog();
@@ -557,16 +612,30 @@ int main (int argc, char *argv[])
 	}
 	mainwindow->xclass(KNAME);
 
-#if defined(__WOE32__)
+#if defined(__WIN32__)
 #  ifndef IDI_ICON
 #    define IDI_ICON 101
 #  endif
 	mainwindow->icon((char*)LoadIcon(fl_display, MAKEINTRESOURCE(IDI_ICON)));
 	mainwindow->show (argc, argv);
 #elif !defined(__APPLE__)
+	// The fltk icon code doesn't handle XPM transparency well, work around that here...
+	//   See https://groups.google.com/g/fltkgeneral/c/hcjV-rgjHWM
+
+	// load the XPM and prepare the mask
 	make_pixmap(&Rig_icon_pixmap, flrig_icon);
+	// so we fix that AFTER the window is shown (see below)
 	mainwindow->icon((char *)Rig_icon_pixmap);
 	mainwindow->show(argc, argv);
+
+	{
+	// read in the current window hints, then modify them to allow icon transparency
+		XWMHints* hints = XGetWMHints(fl_display, fl_xid(mainwindow));
+		hints->flags |= IconMaskHint; // ensure transparency mask is enabled for the XPM icon
+		hints->icon_mask |= IconPixmapHint;
+		XSetWMHints(fl_display, fl_xid(mainwindow), hints);
+		XFree(hints);
+	}
 #else
 	mainwindow->show(argc, argv);
 #endif
@@ -609,18 +678,22 @@ void cb_xml_help(Fl_Menu_*, void*)
 	cl_print(print_xmlhelp());
 }
 
+bool PRIORITY = false;
 int parse_args(int argc, char **argv, int& idx)
 {
 	std::string helpstr =
 "Usage: \n\
   --help this help text\n\
-  --version\n\
+  --version {-v}\n\
   --config-dir [fully qualified pathname to <DIR>]\n\
   --debug-level N (0..4)\n\
+  --serial-debug \n\
   --trace\n\
   --xml-help\n\
   --xml-trace\n\
   --exp (expand menu tab controls)\n\
+  --iconify {-i}\n\
+  --priority {-p}\n\
   --test\n";
 
 	if (strcasecmp("--help", argv[idx]) == 0) {
@@ -631,7 +704,7 @@ int parse_args(int argc, char **argv, int& idx)
 #endif
 		exit(0);
 	}
-	if (strcasecmp("--version", argv[idx]) == 0) {
+	if (!strcasecmp(argv[idx], "--version") || !strcasecmp(argv[idx], "-v")) {
 		std::string ver = "Version: ";
 		ver.append(VERSION).append("\n");
 		std::cout << ver;
@@ -652,6 +725,17 @@ int parse_args(int argc, char **argv, int& idx)
 		idx++;
 		return 1;
 	}
+	if (!strcasecmp(argv[idx], "-i") || !strcasecmp(argv[idx], "--iconify")) {
+		iconified = true;
+		idx++;
+		return 1;
+	}
+	if (!strcasecmp(argv[idx], "-p") || !strcasecmp(argv[idx], "--priority")) {
+		PRIORITY = true;
+		idx++;
+		return 1;
+	}
+
 	if (strcasecmp("--debug-level", argv[idx]) == 0) {
 		std::string level = argv[idx + 1];
 		switch (level[0]) {
@@ -665,6 +749,11 @@ int parse_args(int argc, char **argv, int& idx)
 		idx += 2;
 		return 1;
 	}
+	if (strcasecmp("--serial-debug", argv[idx]) == 0) {
+		SERIALDEBUG = 1;
+		idx++;
+		return 1;
+	}
 	if (strcasecmp("--config-dir", argv[idx]) == 0) {
 		RigHomeDir = argv[idx + 1];
 		if (RigHomeDir[RigHomeDir.length()-1] != '/')
