@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 
@@ -70,22 +70,25 @@ RIG_KX3::RIG_KX3() {
 	modes_ = KX3modes_;
 	bandwidths_ = KX3_widths;
 	bw_vals_ = KX3_bw_vals;
-	comm_baudrate = BR38400;
+	serial_baudrate = BR38400;
 
 	widgets = k3_widgets;
 
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	def_freq = freqA = freqB = 14070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	def_freq = freqA = freqB = 14070000ULL;
 	def_mode = modeA = modeB = 1;
 	def_bw = bwA = bwB = 34;
 
@@ -281,7 +284,7 @@ bool RIG_KX3::check ()
 
 }
 
-unsigned long int RIG_KX3::get_vfoA ()
+unsigned long long RIG_KX3::get_vfoA ()
 {
 	cmd = "FA;";
 
@@ -294,7 +297,7 @@ unsigned long int RIG_KX3::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return freqA;
 
-	unsigned long int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqA = f;
@@ -302,7 +305,7 @@ unsigned long int RIG_KX3::get_vfoA ()
 	return freqA;
 }
 
-void RIG_KX3::set_vfoA (unsigned long int freq)
+void RIG_KX3::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000000;";
@@ -317,7 +320,7 @@ void RIG_KX3::set_vfoA (unsigned long int freq)
 	check();
 }
 
-unsigned long int RIG_KX3::get_vfoB ()
+unsigned long long RIG_KX3::get_vfoB ()
 {
 	cmd = "FB;";
 	get_trace(1, "get vfoB");
@@ -328,14 +331,14 @@ unsigned long int RIG_KX3::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return freqB;
 
-	unsigned long int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqB = f;
 	return freqB;
 }
 
-void RIG_KX3::set_vfoB (unsigned long int freq)
+void RIG_KX3::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000000;";
@@ -423,7 +426,7 @@ int RIG_KX3::get_volume_control()
  *     1 (AFSK A),
  *     2 (FSK D),
  *     3 (PSK D). See MD for data normal/reverse considerations.
- *   In Diversity Mode (K3 only, accessed by sending DV1 or via a unsigned long int hold
+ *   In Diversity Mode (K3 only, accessed by sending DV1 or via a long hold
  *   of SUB), sending DTn matches the sub receiver’s mode to the main receiver’s.
  *   Notes:
  *     (1) Use DT only when the transceiver is in DATA mode; otherwise,
@@ -925,67 +928,110 @@ static std::string KX3_bws = "\
 
 void RIG_KX3::set_bwA(int val)
 {
-	cmd.assign("BW0").append(KX3_bws.substr(val*4, 4));
+    char command[10];
+    cmd = "BW";
+    bwA = val;
+    if (val < (int)(sizeof(KX3_widths)/sizeof(char*)-2)) // then it's an index
+    {
+      std::cout << "val==" <<  val << std::endl;
+      std::string w = KX3_widths[val];
+      w.erase(w.length() - 1);
+      while (w.length() < 4) w.insert(0, "0");
+      cmd.append(w).append(";");
+    }
+    else // otherwise it's s real width
+    {
+      short bw = val;
+      if (bw > 4000) bw = 4000;
+      snprintf(command, sizeof(command), "BW%04d;", (bw/10));
+      cmd = command;
+      std::cout << command << std::endl;
+    }
+    std::cout << command << std::endl;
 
-	set_trace(2, "set bwA", KX3_widths[val]);
-	sendCommand(cmd, 0, 50);
-	sett("");
-	showresp(INFO, ASC, "set bw A", cmd, replystr);
+    set_trace(1, "set bwA");
+    sendCommand(cmd);
+    sett("");
+    //set_pbt_values(val);
 }
 
 int RIG_KX3::get_bwA()
 {
 	cmd = "BW;";
+	get_trace(1, "get bwA val");
+	wait_char(';', 7, KX3_WAIT_TIME, "get bwA val", ASC);
+	gett("");
 
+	size_t p = replystr.rfind("BW");
+	if (p != std::string::npos) {
+		bwA_val = atoi(&replystr[2]) * 10;
+    }
+
+	cmd = "FW;";
 	get_trace(1, "get bwA");
 	int ret = wait_char(';', 7, KX3_WAIT_TIME, "get bandwidth A", ASC);
 	gett("");
-
+ 
 	if (ret < 7) return bwA;
-	std::string bw = replystr.substr( replystr.length() - 4, 4 );
-
-	size_t p = 0;
-	while (p < KX3_bws.length()) {
-		if (bw <= KX3_bws.substr(p, 4)) break;
-		p += 4;
-	}
-	if ((bw < KX3_bws.substr(p,4)) && bw[2] < '5') p -= 4;
-	if (p < 0) p = 0;
-	if (p < KX3_bws.length()) bwA = p / 4;
-
+	p = replystr.rfind("FW");
+	if (p == std::string::npos) return bwA;
+	int bw = atoi(&replystr[3]) * 10;
+	for (bwA = 0; bwA < 36; bwA++)
+		if (bw <= atoi(KX3_widths[bwA])) break;
 	return bwA;
 }
 
 void RIG_KX3::set_bwB(int val)
 {
-	cmd.assign("BW0").append(KX3_bws.substr(val*4, 4));
+    char command[10];
+    cmd = "BW$";
+    bwA = val;
+    if (val < (int)(sizeof(KX3_widths)/sizeof(char*)-2)) // then it's an index
+    {
+      std::cout << "val==" <<  val << std::endl;
+      std::string w = KX3_widths[val];
+      w.erase(w.length() - 1);
+      while (w.length() < 4) w.insert(0, "0");
+      cmd.append(w).append(";");
+    }
+    else // otherwise it's s real width
+    {
+      short bw = val;
+      if (bw > 4000) bw = 4000;
+      snprintf(command, sizeof(command), "BW$%04d;", (bw/10));
+      cmd = command;
+      std::cout << command << std::endl;
+    }
+    std::cout << command << std::endl;
 
-	set_trace(2, "set bwB", KX3_widths[val]);
-	sendCommand(cmd, 0, 50);
-	sett("");
-	showresp(INFO, ASC, "set bw B", cmd, replystr);
+    set_trace(1, "set bwB");
+    sendCommand(cmd);
+    sett("");
+    //set_pbt_values(val);
 }
 
 int RIG_KX3::get_bwB()
 {
-	cmd = "BW;";
-
-	get_trace(1, "get bwA");
-	int ret = wait_char(';', 7, KX3_WAIT_TIME, "get bandwidth B", ASC);
+	cmd = "BW$;";
+	get_trace(1, "get bwB val");
+	wait_char(';', 8, KX3_WAIT_TIME, "get bwB val", ASC);
 	gett("");
 
-	if (ret < 7) return bwB;
-	std::string bw = replystr.substr( replystr.length() - 4, 4 );
-
-	size_t p = 0;
-	while (p < KX3_bws.length()) {
-		if (bw <= KX3_bws.substr(p, 4)) break;
-		p += 4;
-	}
-	if ((bw < KX3_bws.substr(p,4)) && bw[2] < '5') p -= 4;
-	if (p < 0) p = 0;
-	if (p < KX3_bws.length()) bwB = p / 4;
+	size_t p = replystr.rfind("BW$");
+	if (p != std::string::npos) {
+		bwB_val = atoi(&replystr[3]) * 10;
+    }
 
+	cmd = "FW$;";
+	get_trace(1, "get bwB");
+	wait_char(';', 8, KX3_WAIT_TIME, "get bandwidth B", ASC);
+	gett("");
+ 
+	p = replystr.rfind("FW$");
+	if (p == std::string::npos) return bwB;
+	int bw = atoi(&replystr[3]) * 10;
+	for (bwB = 0; bwB < 36; bwB++)
+		if (bw <= atoi(KX3_widths[bwB])) break;
 	return bwB;
 }
 
