@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <stdio.h>
@@ -156,13 +156,16 @@ RIG_IC7000::RIG_IC7000() {
 	bandwidths_ = IC7000_SSB_CWwidths;
 	bw_vals_ = IC7000_bw_vals_SSB;
 
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
 	_mode_type = IC7000_mode_type;
 	widgets = IC7000_widgets;
 
-	def_freq = A.freq = 432399230;
+	def_freq = A.freq = 432399230ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 28;
-	B.freq = 432399230;
+	B.freq = 432399230ULL;
 	B.imode = 1;
 	B.iBW = 28;
 
@@ -170,8 +173,6 @@ RIG_IC7000::RIG_IC7000() {
 
 	restore_mbw = false;
 
-	has_ifshift_control = false;
-
 	has_extras =
 	has_compON =
 	has_compression =
@@ -243,7 +244,7 @@ bool RIG_IC7000::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC7000::get_vfoA ()
+unsigned long long RIG_IC7000::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -266,7 +267,7 @@ unsigned long int RIG_IC7000::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7000::set_vfoA (unsigned long int freq)
+void RIG_IC7000::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -277,7 +278,7 @@ void RIG_IC7000::set_vfoA (unsigned long int freq)
 	isett("set_vfoA()");
 }
 
-unsigned long int RIG_IC7000::get_vfoB ()
+unsigned long long RIG_IC7000::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -300,7 +301,7 @@ unsigned long int RIG_IC7000::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7000::set_vfoB (unsigned long int freq)
+void RIG_IC7000::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -1147,7 +1148,7 @@ void RIG_IC7000::get_band_selection(int v)
 	if (ret) {
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			if (inuse == onB) {
@@ -1165,7 +1166,7 @@ void RIG_IC7000::get_band_selection(int v)
 
 void RIG_IC7000::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
