@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC703.h"
@@ -73,18 +73,19 @@ RIG_IC703::RIG_IC703() {
  	_mode_type = IC703_mode_type;
 	bandwidths_ = IC703_widths;
 	bw_vals_ = IC703_bw_vals;
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeA = 1;
 	bwA = 0;
 
@@ -101,7 +102,6 @@ RIG_IC703::RIG_IC703() {
 	has_noise_reduction =
 	has_noise_reduction_control =
 	has_noise_control =
-	has_ifshift_control =
 	has_pbt_controls =
 	has_micgain_control =
 	has_power_control =
@@ -150,7 +150,7 @@ bool RIG_IC703::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC703::get_vfoA ()
+unsigned long long RIG_IC703::get_vfoA ()
 {
 	cmd = pre_to;
 	cmd += '\x03';
@@ -169,7 +169,7 @@ unsigned long int RIG_IC703::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC703::set_vfoA (unsigned long int freq)
+void RIG_IC703::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -287,12 +287,6 @@ int  RIG_IC703::next_preamp()
 void RIG_IC703::set_preamp(int val)
 {
 	preamp_level = val;
-	if (preamp_level == 1)
-		preamp_label("Pre 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Pre 2", true);
-	else if (preamp_level == 0)
-		preamp_label("Pre", false);
 
 	cmd = pre_to;
 	cmd += '\x16';
@@ -314,21 +308,31 @@ int RIG_IC703::get_preamp()
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
-				preamp_level = 1;
-			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
-				preamp_level = 2;
-			} else {
-				preamp_label("Pre", false);
-				preamp_level = 0;
-			}
+			preamp_level = replystr[p+6];
 		}
 	}
 	return preamp_level;
 }
 
+const char *RIG_IC703::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC703::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
 int RIG_IC703::get_smeter()
 {
 	cmd = pre_to;
@@ -544,37 +548,6 @@ void RIG_IC703::get_mic_gain_min_max_step(int &min, int &max, int &step)
 	step = 1;
 }
 
-void RIG_IC703::set_if_shift(int val)
-{
-	int shift = (int)((val + 50) * 2.55 );
-	cmd.assign(pre_to).append("\x14\x04").append(to_bcd(shift, 3)).append(post);
-	waitFB("set if-shift");
-}
-
-bool  RIG_IC703::get_if_shift(int &val)
-{
-	std::string cstr = "\x14\x07";
-	std::string resp = pre_fm;
-	resp.append(cstr);
-	cmd = pre_to;
-	cmd.append(cstr);
-	cmd.append(post);
-	val = progStatus.shift_val;
-	if (waitFOR(9, "get if-shift")) {
-		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos)
-			val = (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55 - 50);
-	}
-	return (progStatus.shift = (val != 0));
-}
-
-void RIG_IC703::get_if_min_max_step(int &min, int &max, int &step)
-{
-	min = -50;
-	max = +50;
-	step = 1;
-}
-
 void RIG_IC703::set_squelch(int val)
 {
 	int IC703sql = (int)(val * 2.55);
