@@ -19,7 +19,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <string>
@@ -167,26 +167,27 @@ RIG_IC705::RIG_IC705() {
 
 	_mode_type = IC705_mode_type;
 
-	comm_baudrate = BR19200;
+	serial_baudrate = BR19200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = IC705_widgets;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 9;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 9;
 	B.iBW = 34;
 
@@ -250,7 +251,7 @@ RIG_IC705::RIG_IC705() {
 	has_xcvr_auto_on_off = true;
 
 	precision = 1;
-	ndigits = 8;
+	ndigits = 9;
 
 	has_vfo_adj = true;
 
@@ -313,8 +314,8 @@ void RIG_IC705::set_xcvr_auto_on()
 	if (waitFOR(8, "get ID") == false) {
 		cmd.clear();
 		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		if (progStatus.serial_baudrate >= 0 && progStatus.serial_baudrate <= 11) {
+			cmd.append( fes[progStatus.serial_baudrate], '\xFE');
 		}
 		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
@@ -369,7 +370,7 @@ bool RIG_IC705::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC705::get_vfoA ()
+unsigned long long RIG_IC705::get_vfoA ()
 {
 	std::string resp;
 
@@ -400,7 +401,7 @@ unsigned long int RIG_IC705::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC705::set_vfoA (unsigned long int freq)
+void RIG_IC705::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 
@@ -416,7 +417,7 @@ void RIG_IC705::set_vfoA (unsigned long int freq)
 
 }
 
-unsigned long int RIG_IC705::get_vfoB ()
+unsigned long long RIG_IC705::get_vfoB ()
 {
 	std::string resp;
 
@@ -447,7 +448,7 @@ unsigned long int RIG_IC705::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC705::set_vfoB (unsigned long int freq)
+void RIG_IC705::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 
@@ -1523,27 +1524,11 @@ int RIG_IC705::next_preamp()
 
 void RIG_IC705::set_preamp(int val)
 {
-	if (val) {
-		atten_level = 0;
-		atten_label("ATT", false);
-	}
-
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
 
 	preamp_level = val;
-	switch (val) {
-		case 1:
-			preamp_label("Amp 1", true);
-			break;
-		case 2:
-			preamp_label("Amp 2", true);
-			break;
-		case 0:
-		default:
-			preamp_label("PRE", false);
-	}
 
 	cmd += (unsigned char)preamp_level;
 	cmd.append( post );
@@ -1564,14 +1549,6 @@ int RIG_IC705::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
-			if (preamp_level == 1) {
-				preamp_label("Amp 1", true);
-			} else if (preamp_level == 2) {
-				preamp_label("Amp 2", true);
-			} else {
-				preamp_label("PRE", false);
-				preamp_level = 0;
-			}
 		}
 	}
 	return preamp_level;
@@ -1580,12 +1557,9 @@ int RIG_IC705::get_preamp()
 void RIG_IC705::set_attenuator(int val)
 {
 	if (val) {
-		atten_label("20 dB", true);
 		atten_level = 1;
-		preamp_label("PRE", false);
 	} else {
 		atten_level = 0;
-		atten_label("ATT", false);
 	}
 
 	cmd = pre_to;
@@ -1612,11 +1586,9 @@ int RIG_IC705::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x20) {
-				atten_label("20 dB", true);
 				atten_level = 1;
 				return 1;
 			} else {
-				atten_label("ATT", false);
 				atten_level = 0;
 				return 0;
 			}
@@ -1625,6 +1597,25 @@ int RIG_IC705::get_attenuator()
 	return 0;
 }
 
+const char *RIG_IC705::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC705::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
 void RIG_IC705::set_noise(bool val)
 {
 	cmd = pre_to;
@@ -2225,7 +2216,7 @@ void RIG_IC705::set_band_selection(int v)
 		case 12: v = 14; break;
 		default: break;
 	}
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? B.filter : A.filter);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
