@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC7100.h"
@@ -187,16 +187,17 @@ RIG_IC7100::RIG_IC7100() {
 	_mode_type = IC7100_mode_type;
 	adjustCIV(defaultCIV);
 
-	comm_retries = 2;
-	comm_wait = 20;
-	comm_timeout = 2;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 2;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = IC7100_widgets;
 
@@ -216,7 +217,6 @@ RIG_IC7100::RIG_IC7100() {
 	has_bandwidth_control = true;
 
 	has_micgain_control = true;
-	has_ifshift_control = true;
 	has_pbt_controls = true;
 	has_FILTER = true;
 	has_power_control = true;
@@ -268,11 +268,11 @@ RIG_IC7100::RIG_IC7100() {
 	ndigits = 9;
 	A.filter = B.filter = 1;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 34;
 
@@ -302,10 +302,10 @@ static bool xcvr_is_on = false;
 
 void RIG_IC7100::set_xcvr_auto_on()
 {
-	int nr = progStatus.comm_baudrate == 6 ? 25 :
-			 progStatus.comm_baudrate == 5 ? 13 :
-			 progStatus.comm_baudrate == 4 ? 7 :
-			 progStatus.comm_baudrate == 3 ? 3 : 2;
+	int nr = progStatus.serial_baudrate == 6 ? 25 :
+			 progStatus.serial_baudrate == 5 ? 13 :
+			 progStatus.serial_baudrate == 4 ? 7 :
+			 progStatus.serial_baudrate == 3 ? 3 : 2;
 
 	cmd.assign(pre_to);
 	cmd += '\x19'; cmd += '\x00';
@@ -397,7 +397,7 @@ void RIG_IC7100::selectB()
 	inuse = onB;
 }
 
-unsigned long int RIG_IC7100::get_vfoA ()
+unsigned long long RIG_IC7100::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -422,7 +422,7 @@ unsigned long int RIG_IC7100::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7100::set_vfoA (unsigned long int freq)
+void RIG_IC7100::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -434,7 +434,7 @@ void RIG_IC7100::set_vfoA (unsigned long int freq)
 	seth();
 }
 
-unsigned long int RIG_IC7100::get_vfoB ()
+unsigned long long RIG_IC7100::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -459,7 +459,7 @@ unsigned long int RIG_IC7100::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7100::set_vfoB (unsigned long int freq)
+void RIG_IC7100::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -977,12 +977,9 @@ void RIG_IC7100::get_mic_gain_min_max_step(int &min, int &max, int &step)
 void RIG_IC7100::set_attenuator(int val)
 {
    if (val) {
-		atten_label("12 dB", true);
 		atten_level = 1;
-		preamp_label("PRE", false);
 	} else {
 		atten_level = 0;
-		atten_label("ATT", false);
 	}
 
 	cmd = pre_to;
@@ -1010,10 +1007,8 @@ int RIG_IC7100::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+5] == 0x12) {
 			atten_level = 1;
-			atten_label("12 dB", true);
 		} else {
 			atten_level = 0;
-			atten_label("ATT", false);
 		}
 	}
 	return atten_level;
@@ -1049,11 +1044,6 @@ int RIG_IC7100::next_preamp()
 
 void RIG_IC7100::set_preamp(int val)
 {
-	if (val) {
-		atten_level = 0;
-		atten_label("ATT", false);
-	}
-
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
@@ -1061,17 +1051,6 @@ void RIG_IC7100::set_preamp(int val)
 	preamp_level = val;
 	if (inuse == onA && A.freq > 100000000 && val > 1) val = 1;
 	if (inuse == onB && B.freq > 100000000 && val > 1) val = 1;
-	switch (val) {
-		case 1: 
-			preamp_label("Pre 1", true);
-			break;
-		case 2:
-			preamp_label("Pre 2", true);
-			break;
-		case 0:
-		default:
-			preamp_label("Pre", false);
-	}
 
 	cmd += (unsigned char)preamp_level;
 	cmd.append( post );
@@ -1099,18 +1078,29 @@ int RIG_IC7100::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos)
 			preamp_level = replystr[p+6];
-		if (preamp_level == 1) {
-			preamp_label("Pre 1", true);
-		} else if (preamp_level == 2) {
-			preamp_label("Pre 2", true);
-		} else {
-			preamp_label("Pre", false);
-			preamp_level = 0;
-		}
 	}
 	return preamp_level;
 }
 
+const char *RIG_IC7100::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC7100::ATT_label()
+{
+	if (atten_level == 1) return "12 dB";
+	return "ATT";
+}
+
 void RIG_IC7100::set_compression(int on, int val)
 {
 	if (on) {
@@ -1764,36 +1754,6 @@ int RIG_IC7100::get_auto_notch()
 	return progStatus.auto_notch;
 }
 
-void RIG_IC7100::set_if_shift(int val)
-{
-	int shift;
-	sh_ = val;
-	if (val == 0) sh_on_ = false;
-	else sh_on_ = true;
-
-	shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
-	cmd = pre_to;
-	cmd.append("\x14\x07");
-	cmd.append(to_bcd(shift, 3));
-	cmd.append(post);
-	waitFB("set IF inner");
-
-	cmd = pre_to;
-	cmd.append("\x14\x08");
-	cmd.append(to_bcd(shift, 3));
-	cmd.append(post);
-	waitFB("set IF outer");
-}
-
-bool RIG_IC7100::get_if_shift(int &val)
-{
-	val = sh_;
-	return sh_on_;
-}
-
 void RIG_IC7100::set_pbt_inner(int val)
 {
 	int shift = 128 + val * 128 / 50;
@@ -1868,13 +1828,6 @@ int RIG_IC7100::get_pbt_outer()
 	return val;
 }
 
-void RIG_IC7100::get_if_min_max_step(int &min, int &max, int &step)
-{
-	min = -50;
-	max = +50;
-	step = 1;
-}
-
 void RIG_IC7100::set_noise(bool val)
 {  
    cmd = pre_to;
@@ -2046,7 +1999,7 @@ void RIG_IC7100::get_band_selection(int v)
 	if (ret) {
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p + 8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p + 8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -2085,7 +2038,7 @@ void RIG_IC7100::get_band_selection(int v)
 
 void RIG_IC7100::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? B.filter : A.filter);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
