@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 #include <sstream>
@@ -157,25 +157,26 @@ RIG_IC7200::RIG_IC7200() {
 	bw_vals_ = IC7200_bw_vals_SSB;
 	widgets = IC7200_widgets;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 32;
 	A.filter = 1;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 32;
 	B.filter = 1;
@@ -297,7 +298,7 @@ bool RIG_IC7200::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC7200::get_vfoA ()
+unsigned long long RIG_IC7200::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -321,7 +322,7 @@ unsigned long int RIG_IC7200::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7200::set_vfoA (unsigned long int freq)
+void RIG_IC7200::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -333,7 +334,7 @@ void RIG_IC7200::set_vfoA (unsigned long int freq)
 	seth();
 }
 
-unsigned long int RIG_IC7200::get_vfoB ()
+unsigned long long RIG_IC7200::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -357,7 +358,7 @@ unsigned long int RIG_IC7200::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7200::set_vfoB (unsigned long int freq)
+void RIG_IC7200::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -719,11 +720,8 @@ int RIG_IC7200::get_noise_reduction_val()
 void RIG_IC7200::set_attenuator(int val)
 {
 	if (val) {
-		atten_label("20 dB", true);
 		atten_level = 1;
-		set_preamp(0);
 	} else {
-		atten_label("ATT", false);
 		atten_level = 0;
 	}
 
@@ -738,8 +736,9 @@ void RIG_IC7200::set_attenuator(int val)
 
 int RIG_IC7200::next_attenuator()
 {
-	if (atten_level) return 0;
-	return 1;
+	if (atten_level)
+		atten_level = 0;
+	return atten_level;
 }
 
 int RIG_IC7200::get_attenuator()
@@ -756,20 +755,14 @@ int RIG_IC7200::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
-				atten_label("ATT", false);
 				atten_level = 0;
-				geth();
-				return 0;
 			} else {
-				atten_label("20 dB", true);
 				atten_level = 1;
-				geth();
-				return 1;
 			}
 		}
+		geth();
 	}
-	geth();
-	return 0;
+	return atten_level;
 }
 
 int RIG_IC7200::next_preamp()
@@ -782,14 +775,8 @@ int RIG_IC7200::next_preamp()
 void RIG_IC7200::set_preamp(int val)
 {
 	if (val) {
-		preamp_label("Pre ON", true);
 		preamp_level = 1;
-		if (atten_level == 1) {
-			atten_label("ATT", false);
-			atten_level = 0;
-		}
 	} else {
-		preamp_label("Pre", false);
 		preamp_level = 0;
 	}
 
@@ -817,11 +804,7 @@ int RIG_IC7200::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre ON", true);
-				preamp_level = 1;
-			} else {
-				preamp_label("Pre", false);
-				preamp_level = 0;
+				preamp_level = replystr[p+6];
 			}
 		}
 	}
@@ -829,6 +812,23 @@ int RIG_IC7200::get_preamp()
 	return preamp_level; //progStatus.preamp;
 }
 
+const char *RIG_IC7200::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "P ON"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC7200::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
 void RIG_IC7200::set_rf_gain(int val)
 {
 	cmd = pre_to;
@@ -1949,7 +1949,7 @@ void RIG_IC7200::get_band_selection(int v)
 		std::string ans = replystr;
 		size_t p = ans.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(ans.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(ans.substr(p+8, 5), 10);
 			int bandmode = ans[p+13];
 			int bandfilter = ans[p+14];
 			int banddata = ans[p+15] & 0x10;
@@ -1970,7 +1970,7 @@ void RIG_IC7200::get_band_selection(int v)
 
 void RIG_IC7200::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int mode = (inuse == onB ? B.imode : A.imode);
 	int fil = (inuse == onB ? B.filter : A.filter);
 
