@@ -19,7 +19,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <string>
@@ -167,26 +167,27 @@ RIG_IC7300::RIG_IC7300() {
 
 	_mode_type = IC7300_mode_type;
 
-	comm_baudrate = BR115200;
+	serial_baudrate = BR115200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = IC7300_widgets;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 9;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 9;
 	B.iBW = 34;
 
@@ -315,7 +316,7 @@ void RIG_IC7300::selectB()
 
 bool RIG_IC7300::canswap()
 {
-	return false;//true;
+	return true;
 }
 
 void RIG_IC7300::swapAB()
@@ -348,8 +349,8 @@ void RIG_IC7300::set_xcvr_auto_on()
 	if (waitFOR(8, "get ID") == false) {
 		cmd.clear();
 		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		if (progStatus.serial_baudrate >= 0 && progStatus.serial_baudrate <= 11) {
+			cmd.append( fes[progStatus.serial_baudrate], '\xFE');
 		}
 		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
@@ -456,7 +457,7 @@ bool RIG_IC7300::check ()
 	return (xcvr_is_on = waitFOR(8, "get ID"));
 }
 
-unsigned long int RIG_IC7300::get_vfoA ()
+unsigned long long RIG_IC7300::get_vfoA ()
 {
 	std::string resp;
 
@@ -489,7 +490,7 @@ unsigned long int RIG_IC7300::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7300::set_vfoA (unsigned long int freq)
+void RIG_IC7300::set_vfoA (unsigned long long freq)
 {
 //	set_trace(1, "set_vfoA()");
 	A.freq = freq;
@@ -506,7 +507,7 @@ void RIG_IC7300::set_vfoA (unsigned long int freq)
 	seth();
 }
 
-unsigned long int RIG_IC7300::get_vfoB ()
+unsigned long long RIG_IC7300::get_vfoB ()
 {
 	std::string resp;
 
@@ -539,7 +540,7 @@ unsigned long int RIG_IC7300::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7300::set_vfoB (unsigned long int freq)
+void RIG_IC7300::set_vfoB (unsigned long long freq)
 {
 //	set_trace(1, "set_vfoB()");
 	B.freq = freq;
@@ -974,6 +975,9 @@ void RIG_IC7300::set_bwA(int val)
 
 	mode_bwA[A.imode] = val;
 
+	set_pbt_inner(progStatus.pbt_inner);
+	set_pbt_outer(progStatus.pbt_outer);
+
 	if (current_vfo == onB) selectB();
 }
 
@@ -1028,6 +1032,9 @@ void RIG_IC7300::set_bwB(int val)
 
 	mode_bwB[B.imode] = val;
 
+	set_pbt_inner(progStatus.pbt_inner);
+	set_pbt_outer(progStatus.pbt_outer);
+
 	if (current_vfo == onA) selectA();
 }
 
@@ -1748,6 +1755,19 @@ void RIG_IC7300::get_rf_min_max_step(double &min, double &max, double &step)
 	min = 0; max = 100; step = 1;
 }
 
+const char *RIG_IC7300::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Amp 1"; break;
+		case 2:
+			return "Amp 2"; break;
+	}
+	return "PRE";
+}
+
 int RIG_IC7300::next_preamp()
 {
 	if (atten_level == 1)
@@ -1755,6 +1775,7 @@ int RIG_IC7300::next_preamp()
 	switch (preamp_level) {
 		case 0: return 1;
 		case 1: return 2;
+		
 		case 2: return 0;
 	}
 	return 0;
@@ -1764,33 +1785,24 @@ void RIG_IC7300::set_preamp(int val)
 {
 	if (val) {
 		atten_level = 0;
-		atten_label("ATT", false);
 	}
 
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
 
-	preamp_level = val;
-	switch (val) {
-		case 1: 
-			preamp_label("Amp 1", true);
-			break;
-		case 2:
-			preamp_label("Amp 2", true);
-			break;
-		case 0:
-		default:
-			preamp_label("PRE", false);
-	}
-
-	cmd += (unsigned char)preamp_level;
+	cmd += (unsigned char)val;
 	cmd.append( post );
 	set_trace(1, "set_preamp");
 	waitFB(	(preamp_level == 0) ? "set Preamp OFF" :
 			(preamp_level == 1) ? "set Preamp Level 1" :
 			"set Preamp Level 2");
 	seth();
+	int tries = 50;
+	while (get_preamp() != val && tries) {
+		MilliSleep(1);
+		tries--;
+	}
 }
 
 int RIG_IC7300::get_preamp()
@@ -1810,29 +1822,24 @@ int RIG_IC7300::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
-			if (preamp_level == 1) {
-				preamp_label("Amp 1", preamp_level);
-			} else if (preamp_level == 2) {
-				preamp_label("Amp 2", preamp_level);
-			} else {
-				preamp_level = 0;
-				preamp_label("PRE", preamp_level);
-			}
 		}
 	}
 	return preamp_level;
 }
 
+const char *RIG_IC7300::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
 void RIG_IC7300::set_attenuator(int val)
 {
 	if (val) {
 		atten_level = 1;
-		atten_label("20 dB", atten_level);
 		preamp_level = 0;
-		preamp_label("PRE", 0);
 	} else {
 		atten_level = 0;
-		atten_label("ATT", atten_level);
 	}
 
 	cmd = pre_to;
@@ -1867,10 +1874,8 @@ int RIG_IC7300::get_attenuator()
 		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x20) {
 				atten_level = 1;
-				atten_label("20 dB", atten_level);
 			} else {
 				atten_level = 0;
-				atten_label("ATT", atten_level);
 			}
 		}
 	}
@@ -2280,56 +2285,11 @@ int  RIG_IC7300::agc_val()
 	return (agcval);
 }
 
-void RIG_IC7300::set_if_shift(int val)
-{
-	int shift;
-	sh_ = val;
-	if (val == 0) sh_on_ = false;
-	else sh_on_ = true;
-
-	shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
-	cmd = pre_to;
-	cmd.append("\x14\x07");
-	cmd.append(to_bcd(shift, 3));
-	cmd.append(post);
-	set_trace(1, "set IF on/off");
-	waitFB("set IF on/off");
-	seth();
-
-	cmd = pre_to;
-	cmd.append("\x14\x08");
-	cmd.append(to_bcd(shift, 3));
-	cmd.append(post);
-	set_trace(1, "set IF val");
-	waitFB("set IF val");
-	seth();
-}
-
-bool RIG_IC7300::get_if_shift(int &val) {
-	val = sh_;
-	return sh_on_;
-}
-
-void RIG_IC7300::get_if_min_max_step(int &min, int &max, int &step)
-{
-	min = -50;
-	max = +50;
-	step = 1;
-}
-
 void RIG_IC7300::set_pbt_inner(int val)
 {
-//	set_trace(1, "set_pbt_inner()");
-	int shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
 	cmd = pre_to;
 	cmd.append("\x14\x07");
-	cmd.append(to_bcd(shift, 3));
+	cmd.append(bcd255(val + 50));
 	cmd.append(post);
 	set_trace(1, "set_pbt_inner()");
 	waitFB("set PBT inner");
@@ -2338,14 +2298,9 @@ void RIG_IC7300::set_pbt_inner(int val)
 
 void RIG_IC7300::set_pbt_outer(int val)
 {
-//	set_trace(1, "set_pbt_outer()");
-	int shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
 	cmd = pre_to;
 	cmd.append("\x14\x08");
-	cmd.append(to_bcd(shift, 3));
+	cmd.append(bcd255(val + 50));
 	cmd.append(post);
 	set_trace(1, "set_pbt_outer()");
 	waitFB("set PBT outer");
@@ -2369,10 +2324,10 @@ int RIG_IC7300::get_pbt_inner()
 	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			val = num100(replystr.substr(p+6));
-			val -= 50;
+			val = num100(replystr.substr(p+6)) - 50;
 		}
 	}
+
 	return val;
 }
 
@@ -2393,8 +2348,7 @@ int RIG_IC7300::get_pbt_outer()
 	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			val = num100(replystr.substr(p+6));
-			val -= 50;
+			val = num100(replystr.substr(p+6)) - 50;
 		}
 	}
 	return val;
@@ -2491,7 +2445,7 @@ void RIG_IC7300::get_band_selection(int v)
 	if (ret) {
 		size_t p = replystr.rfind(retstr);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -2521,7 +2475,7 @@ void RIG_IC7300::get_band_selection(int v)
 void RIG_IC7300::set_band_selection(int v)
 {
 //	set_trace(1, "set_band_selection()");
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? B.filter : A.filter);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
