@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC735.h"
@@ -31,18 +31,19 @@ RIG_IC735::RIG_IC735() {
 	name_ = IC735name_;
 	modes_ = IC735modes_;
 	_mode_type = IC735_mode_type;
-	comm_baudrate = BR1200;
+	serial_baudrate = BR1200;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 10;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = false;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = false;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeA = 1;
 	bwA = 0;
 
@@ -88,7 +89,7 @@ bool RIG_IC735::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC735::get_vfoA ()
+unsigned long long RIG_IC735::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string cstr = "\x03";
@@ -109,7 +110,7 @@ unsigned long int RIG_IC735::get_vfoA ()
 	return freqA;
 }
 
-void RIG_IC735::set_vfoA (unsigned long int freq)
+void RIG_IC735::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = pre_to;
@@ -119,7 +120,7 @@ void RIG_IC735::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_IC735::get_vfoB ()
+unsigned long long RIG_IC735::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string cstr = "\x03";
@@ -140,7 +141,7 @@ unsigned long int RIG_IC735::get_vfoB ()
 	return freqB;
 }
 
-void RIG_IC735::set_vfoB (unsigned long int freq)
+void RIG_IC735::set_vfoB (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = pre_to;
