@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC746.h"
@@ -85,20 +85,21 @@ RIG_IC746::RIG_IC746() {
 
 	widgets = IC746_widgetsdgets;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
-	def_freq = freqB = freqA = B.freq = A.freq = 14070000L;
+	def_freq = freqB = freqA = B.freq = A.freq = 14070000ULL;
 	def_mode = modeB = modeA = B.imode = A.imode = 1;
 	def_bw = bwB = bwA = B.iBW = A.iBW = 0;
 	filter_nbr = 0;
@@ -165,7 +166,7 @@ bool RIG_IC746::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC746::get_vfoA ()
+unsigned long long RIG_IC746::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string cstr = "\x03";
@@ -186,7 +187,7 @@ unsigned long int RIG_IC746::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC746::set_vfoA (unsigned long int freq)
+void RIG_IC746::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -196,7 +197,7 @@ void RIG_IC746::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_IC746::get_vfoB ()
+unsigned long long RIG_IC746::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string cstr = "\x03";
@@ -217,7 +218,7 @@ unsigned long int RIG_IC746::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC746::set_vfoB (unsigned long int freq)
+void RIG_IC746::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -310,11 +311,6 @@ void RIG_IC746::set_attenuator(int val)
 	cmd += val ? 0x20 : 0x00;
 	cmd.append( post );
 	waitFB("set att");
-	if (!val) {
-		preamp_level--;
-		if (preamp_level < 0) preamp_level = 2;
-		set_preamp(1);
-	}
 }
 
 int RIG_IC746::get_attenuator()
@@ -346,12 +342,6 @@ int  RIG_IC746::next_preamp()
 void RIG_IC746::set_preamp(int val)
 {
 	preamp_level = val;
-	if (preamp_level == 1)
-		preamp_label("Pre 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Pre 2", true);
-	else if (preamp_level == 0)
-		preamp_label("Pre", false);
 
 	cmd = pre_to;
 	cmd += '\x16';
@@ -371,22 +361,31 @@ int RIG_IC746::get_preamp()
 	cmd.append(post);
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
-				preamp_level = 1;
-			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
-				preamp_level = 2;
-			} else {
-				preamp_label("Pre", false);
-				preamp_level = 0;
-			}
-		}
+		if (p != std::string::npos)
+			preamp_level = replystr[p+6];
 	}
 	return preamp_level;
 }
 
+const char *RIG_IC746::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC746::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
 // changed noise blanker to noise reduction
 void RIG_IC746::set_noise(bool val)
 {
@@ -1289,13 +1288,10 @@ void RIG_IC746PRO::set_preamp(int val)
 {
 	if (preamp_level == 0) {
 		preamp_level = 1;
-		preamp_label("Pre 1", true);
 	} else if (preamp_level == 1) {
 		preamp_level = 2;
-		preamp_label("Pre 2", true);
 	} else if (preamp_level == 2) {
 		preamp_level = 0;
-		preamp_label("Pre", false);
 	}
 	cmd = pre_to;
 	cmd += '\x16';
@@ -1317,13 +1313,10 @@ int RIG_IC746PRO::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
 				preamp_level = 1;
 			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
 				preamp_level = 2;
 			} else {
-				preamp_label("Pre", false);
 				preamp_level = 0;
 			}
 		}
@@ -1331,6 +1324,26 @@ int RIG_IC746PRO::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_IC746PRO::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC746PRO::ATT_label()
+{
+	if (atten_level == 1) return "20 dB";
+	return "ATT";
+}
+
+
 int RIG_IC746PRO::get_mic_gain()
 {
 	std::string cstr = "\x14\x0B";
@@ -1512,7 +1525,7 @@ void RIG_IC746PRO::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1542,7 +1555,7 @@ void RIG_IC746PRO::get_band_selection(int v)
 
 void RIG_IC746PRO::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
