@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ---------------------------------------------------------------------
 
 #include <string>
@@ -96,20 +96,21 @@ RIG_IC756::RIG_IC756() {
 
 	widgets = IC756_widgets;
 
-	comm_baudrate = BR19200;
+	serial_baudrate = BR19200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = false;
-	comm_rtsptt = true;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = false;
+	serial_rtsptt = true;
+	serial_dtrptt = false;
 
-	def_freq = freqB = freqA = B.freq = A.freq = 14070000L;
+	def_freq = freqB = freqA = B.freq = A.freq = 14070000ULL;
 	def_mode = B.imode = A.imode = 1;
 	def_bw = B.iBW = A.iBW = 0;
 	filter_nbr = 0;
@@ -412,7 +413,7 @@ bool RIG_IC756PRO::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC756PRO::get_vfoA ()
+unsigned long long RIG_IC756PRO::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string cstr = "\x03";
@@ -433,7 +434,7 @@ unsigned long int RIG_IC756PRO::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC756PRO::set_vfoA (unsigned long int freq)
+void RIG_IC756PRO::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -443,7 +444,7 @@ void RIG_IC756PRO::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_IC756PRO::get_vfoB ()
+unsigned long long RIG_IC756PRO::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string cstr = "\x03";
@@ -464,7 +465,7 @@ unsigned long int RIG_IC756PRO::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC756PRO::set_vfoB (unsigned long int freq)
+void RIG_IC756PRO::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -1079,16 +1080,12 @@ void RIG_IC756PRO::set_attenuator(int val)
 	atten_level = val;
 	int cmdval = 0;
 	if (atten_level == 1) {
-		atten_label("6 dB", true);
 		cmdval = 0x06;
 	} else if (atten_level == 2) {
-		atten_label("12 dB", true);
 		cmdval = 0x12;
 	} else if (atten_level == 3) {
-		atten_label("18 dB", true);
 		cmdval = 0x18;
 	} else if (atten_level == 0) {
-		atten_label("Att", false);
 		cmdval = 0x00;
 	}
 	cmd = pre_to;
@@ -1111,16 +1108,12 @@ int RIG_IC756PRO::get_attenuator()
 		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x06) {
 				atten_level = 1;
-				atten_label("6 dB", true);
 			} else if (replystr[p+5] == 0x12) {
 				atten_level = 2;
-				atten_label("12 dB", true);
 			} else if (replystr[p+5] == 0x18) {
 				atten_level = 3;
-				atten_label("18 dB", true);
 			} else if (replystr[p+5] == 0x00) {
 				atten_level = 0;
-				atten_label("Att", false);
 			}
 		}
 	}
@@ -1140,12 +1133,6 @@ int  RIG_IC756PRO::next_preamp()
 void RIG_IC756PRO::set_preamp(int val)
 {
 	preamp_level = val;
-	if (preamp_level == 1)
-		preamp_label("Pre 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Pre 2", true);
-	else if (preamp_level == 0)
-		preamp_label("Pre", false);
 
 	cmd = pre_to;
 	cmd += '\x16';
@@ -1166,21 +1153,38 @@ int RIG_IC756PRO::get_preamp()
 	if (waitFOR(8, "get preamp")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
-				preamp_level = 1;
-			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
-				preamp_level = 2;
-			} else {
-				preamp_label("Pre", false);
-				preamp_level = 0;
-			}
+			preamp_level = replystr[p+6];
 		}
 	}
 	return preamp_level;
 }
 
+const char *RIG_IC756PRO::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC756PRO::ATT_label()
+{
+	switch (atten_level) {
+		default:
+		case 0: break;
+		case 1: return "6 dB"; break;
+		case 2: return "12 dB"; break;
+		case 3: return "18 dB"; break;
+		case 4: return "20 dB"; break;
+	}
+	return "ATT";
+}
+
 const char *RIG_IC756PRO::FILT(int val)
 {
 	if (val < 1) val = 1;
@@ -1464,7 +1468,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int tone = fm_bcd(replystr.substr(p+16, 3), 6);
@@ -1492,7 +1496,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 
 void RIG_IC756PRO::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
