@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC756PRO3.h"
@@ -118,13 +118,16 @@ RIG_IC756PRO3::RIG_IC756PRO3() {
 	bandwidths_ = IC756PRO3_SSBwidths;
 	bw_vals_ = IC756PRO3_bw_vals_SSB;
 
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
 	_mode_type = IC756PRO3_mode_type;
 	atten_level = 3; // will force initializing to 0 dB
 	preamp_level = 2; // will force initializaing to 0 dB
 
 	widgets = IC756PRO3_widgets;
 
-	def_freq = freqA = freqB = A.freq = 14070000;
+	def_freq = freqA = freqB = A.freq = 14070000ULL;
 	def_mode = modeA = modeB = B.imode = 1;
 	def_bw = bwA = bwB = A.iBW = B.iBW = 32;
 
@@ -220,7 +223,7 @@ bool RIG_IC756PRO3::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC756PRO3::get_vfoA ()
+unsigned long long RIG_IC756PRO3::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string cstr = "\x03";
@@ -241,7 +244,7 @@ unsigned long int RIG_IC756PRO3::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC756PRO3::set_vfoA (unsigned long int freq)
+void RIG_IC756PRO3::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -251,7 +254,7 @@ void RIG_IC756PRO3::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_IC756PRO3::get_vfoB ()
+unsigned long long RIG_IC756PRO3::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string cstr = "\x03";
@@ -272,7 +275,7 @@ unsigned long int RIG_IC756PRO3::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC756PRO3::set_vfoB (unsigned long int freq)
+void RIG_IC756PRO3::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -903,16 +906,12 @@ void RIG_IC756PRO3::set_attenuator(int val)
 	atten_level = val;
 	int cmdval = 0;
 	if (atten_level == 1) {
-		atten_label("6 dB", true);
 		cmdval = 0x06;
 	} else if (atten_level == 2) {
-		atten_label("12 dB", true);
 		cmdval = 0x12;
 	} else if (atten_level == 3) {
-		atten_label("18 dB", true);
 		cmdval = 0x18;
 	} else if (atten_level == 0) {
-		atten_label("Att", false);
 		cmdval = 0x00;
 	}
 	cmd = pre_to;
@@ -935,16 +934,12 @@ int RIG_IC756PRO3::get_attenuator()
 		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x06) {
 				atten_level = 1;
-				atten_label("6 dB", true);
 			} else if (replystr[p+5] == 0x12) {
 				atten_level = 2;
-				atten_label("12 dB", true);
 			} else if (replystr[p+5] == 0x18) {
 				atten_level = 3;
-				atten_label("18 dB", true);
 			} else if (replystr[p+5] == 0x00) {
 				atten_level = 0;
-				atten_label("Att", false);
 			}
 		}
 	}
@@ -964,13 +959,7 @@ int  RIG_IC756PRO3::next_preamp()
 void RIG_IC756PRO3::set_preamp(int val)
 {
 	preamp_level = val;
-	if (preamp_level == 1) {
-		preamp_label("Pre 1", true);
-	} else if (preamp_level == 2) {
-		preamp_label("Pre 2", true);
-	} else if (preamp_level == 0) {
-		preamp_label("Pre", false);
-	}
+
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
@@ -991,13 +980,10 @@ int RIG_IC756PRO3::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
 				preamp_level = 1;
 			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
 				preamp_level = 2;
 			} else {
-				preamp_label("Pre", false);
 				preamp_level = 0;
 			}
 		}
@@ -1005,6 +991,30 @@ int RIG_IC756PRO3::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_IC756PRO3::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Pre 1"; break;
+		case 2:
+			return "Pre 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC756PRO3::ATT_label()
+{
+	switch (atten_level) {
+		default:
+		case 0: break;
+		case 1: return "6 dB"; break;
+		case 2: return "12 dB"; break;
+		case 3: return "18 dB"; break;
+	}
+	return "ATT";
+}
 
 void RIG_IC756PRO3::set_modeA(int val)
 {
@@ -1242,7 +1252,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1272,7 +1282,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 
 void RIG_IC756PRO3::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
