@@ -16,7 +16,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC7600.h"
@@ -140,15 +140,18 @@ RIG_IC7600::RIG_IC7600() {
 	bandwidths_ = IC7600_ssb_bws;
 	bw_vals_ = IC7600_bw_vals_SSB;
 
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
 	_mode_type = IC7600_mode_type;
 
 	widgets = IC7600_widgets;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 13;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 13;
 	B.iBW = 34;
 
@@ -254,7 +257,7 @@ bool RIG_IC7600::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC7600::get_vfoA ()
+unsigned long long RIG_IC7600::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp;
@@ -273,7 +276,7 @@ unsigned long int RIG_IC7600::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7600::set_vfoA (unsigned long int freq)
+void RIG_IC7600::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd.assign(pre_to).append("\x05");
@@ -283,7 +286,7 @@ void RIG_IC7600::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_IC7600::get_vfoB ()
+unsigned long long RIG_IC7600::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -302,7 +305,7 @@ unsigned long int RIG_IC7600::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7600::set_vfoB (unsigned long int freq)
+void RIG_IC7600::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd.assign(pre_to).append("\x05");
@@ -1069,17 +1072,6 @@ void RIG_IC7600::set_preamp(int val)
 	cmd += '\x02';
 
 	preamp_level = val;
-	switch (val) { 
-		case 1: 
-		preamp_label("Amp 1", true);
-			break;
-		case 2:
-		preamp_label("Amp 2", true);
-			break;
-		case 0:
-		default:
-			preamp_label("Pre", false);
-	}
 
 	cmd += (unsigned char)preamp_level;
 	cmd.append( post );
@@ -1101,14 +1093,6 @@ int RIG_IC7600::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
-			if (preamp_level == 1) {
-				preamp_label("Amp 1", true);
-			} else if (preamp_level == 2) {
-				preamp_label("Amp 2", true);
-			} else {
-				preamp_label("OFF", false);
-				preamp_level = 0;
-			}
 		}
 	}
 	get_trace(2, "get_preamp() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1129,15 +1113,7 @@ int  RIG_IC7600::next_attenuator()
 void RIG_IC7600::set_attenuator(int val)
 {
 	atten_level = val;
-	if (atten_level == 0x06) {
-		atten_label("6 dB", true);
-	} else if (atten_level == 0x12) {
-		atten_label("12 dB", true);
-	} else if (atten_level == 0x18) {
-		atten_label("18 dB", true);
-	} else if (atten_level == 0x00) {
-		atten_label("ATT", false);
-	}
+
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd += atten_level;
@@ -1159,20 +1135,33 @@ int RIG_IC7600::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos)
 			atten_level = replystr[p+5];
-		if (atten_level == 0x06) {
-			atten_label("6 dB", true);
-		} else if (atten_level == 0x12) {
-			atten_label("12 dB", true);
-		} else if (atten_level == 0x18) {
-			atten_label("18 dB", true);
-		} else {
-			atten_level = 0x00;
-			atten_label("ATT", false);
-		}
 	}
 	return atten_level;
 }
 
+const char *RIG_IC7600::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Amp 1"; break;
+		case 2:
+			return "Amp 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC7600::ATT_label()
+{
+	if (atten_level == 0x06)
+		return("6 dB");
+	if (atten_level == 0x12)
+		return("12 dB");
+	if (atten_level == 0x18)
+		return("18 dB");
+	return "ATT";
+}
 
 void RIG_IC7600::set_noise(bool val)
 {
@@ -1537,7 +1526,7 @@ void RIG_IC7600::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1574,7 +1563,7 @@ void RIG_IC7600::get_band_selection(int v)
 
 void RIG_IC7600::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
