@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <string>
@@ -136,6 +136,34 @@ static int IC7610_bw_vals_AM[] = {
 40,41,42,43,44,45,46,47,48,49
 WVALS_LIMIT};
 
+const char *IC7610_bcd_vals[] = {
+"0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
+"10", "11", "12", "13", "14", "15", "16", "17", "18", "19",
+"20", "21", "22", "23", "24", "25", "26", "27", "28", "29",
+"30", "31", "32", "33", "34", "35", "36", "37", "38", "39",
+"40", "41", "42", "43", "44", "45", "46", "47", "48", "49",
+"50", "51", "52", "53", "54", "55", "56", "57", "58", "59",
+"60", "61", "62", "63", "64", "65", "66", "67", "68", "69",
+"70", "71", "72", "73", "74", "75", "76", "77", "78", "79",
+"80", "81", "82", "83", "84", "85", "86", "87", "88", "89",
+"90", "91", "92", "93", "94", "95", "96", "97", "98", "99",
+"100", "101", "102", "103", "104", "105", "106", "107", "108", "109",
+"110", "111", "112", "113", "114", "115", "116", "117", "118", "119",
+"120", "121", "122", "123", "124", "125", "126", "127", "128", "129",
+"130", "131", "132", "133", "134", "135", "136", "137", "138", "139",
+"140", "141", "142", "143", "144", "145", "146", "147", "148", "149",
+"150", "151", "152", "153", "154", "155", "156", "157", "158", "159",
+"160", "161", "162", "163", "164", "165", "166", "167", "168", "169",
+"170", "171", "172", "173", "174", "175", "176", "177", "178", "179",
+"180", "181", "182", "183", "184", "185", "186", "187", "188", "189",
+"190", "191", "192", "193", "194", "195", "196", "197", "198", "199",
+"200", "201", "202", "203", "204", "205", "206", "207", "208", "209",
+"210", "211", "212", "213", "214", "215", "216", "217", "218", "219",
+"220", "221", "222", "223", "224", "225", "226", "227", "228", "229",
+"230", "231", "232", "233", "234", "235", "236", "237", "238", "239",
+"240", "241", "242", "243", "244", "245", "246", "247", "248", "249",
+"250", "251", "252", "253", "254", "255" };
+
 const char *IC7610_fm_bws[] = { "FIXED", NULL };
 static int IC7610_bw_vals_FM[] = { 1, WVALS_LIMIT};
 
@@ -195,26 +223,27 @@ RIG_IC7610::RIG_IC7610() {
 
 	_mode_type = IC7610_mode_type;
 
-	comm_baudrate = BR19200;
+	serial_baudrate = BR19200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = IC7610_widgets;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 11;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 11;
 	B.iBW = 34;
 
@@ -337,8 +366,8 @@ void RIG_IC7610::set_xcvr_auto_on()
 	if (waitFOR(8, "get ID", 100) == false) {
 		cmd.clear();
 		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		if (progStatus.serial_baudrate >= 0 && progStatus.serial_baudrate <= 11) {
+			cmd.append( fes[progStatus.serial_baudrate], '\xFE');
 		}
 		cmd.append(pre_to);
 		cmd += '\x18'; cmd += '\x01';
@@ -384,7 +413,7 @@ bool RIG_IC7610::check ()
 //                   ||_________________ 1   Hz  digit
 //                   |__________________ 10  Hz  digit
 
-unsigned long int RIG_IC7610::get_vfoA ()
+unsigned long long RIG_IC7610::get_vfoA ()
 {
 	std::string resp;
 
@@ -409,7 +438,7 @@ unsigned long int RIG_IC7610::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7610::set_vfoA (unsigned long int freq)
+void RIG_IC7610::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 
@@ -424,7 +453,7 @@ void RIG_IC7610::set_vfoA (unsigned long int freq)
 
 }
 
-unsigned long int RIG_IC7610::get_vfoB ()
+unsigned long long RIG_IC7610::get_vfoB ()
 {
 	std::string resp;
 
@@ -449,7 +478,7 @@ unsigned long int RIG_IC7610::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7610::set_vfoB (unsigned long int freq)
+void RIG_IC7610::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 
@@ -1323,7 +1352,7 @@ double RIG_IC7610::get_power_control()
 
 void RIG_IC7610::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 2; pmax = max = 100; step = 1;
+	min = 0; pmax = max = 100; step = 1;
 }
 
 int RIG_IC7610::get_smeter()
@@ -1556,17 +1585,6 @@ void RIG_IC7610::set_preamp(int val)
 	cmd += '\x02';
 
 	preamp_level = val;
-	switch (val) {
-		case 1: 
-			preamp_label("Amp 1", true);
-			break;
-		case 2:
-			preamp_label("Amp 2", true);
-			break;
-		case 0:
-		default:
-			preamp_label("Pre", false);
-	}
 
 	cmd += (unsigned char)preamp_level;
 	cmd.append( post );
@@ -1588,20 +1606,79 @@ int RIG_IC7610::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
-			if (preamp_level == 1) {
-				preamp_label("Amp 1", true);
-			} else if (preamp_level == 2) {
-				preamp_label("Amp 2", true);
-			} else {
-				preamp_label("Pre", false);
-				preamp_level = 0;
-			}
 		}
 	}
 	get_trace(2, "get_preamp() ", str2hex(replystr.c_str(), replystr.length()));
 	return preamp_level;
 }
 
+static char attval[] = {
+'\x00', '\x03', '\x06', '\x09', '\x12',
+'\x15', '\x18', '\x21', '\x24', '\x27',
+'\x30', '\x33', '\x36', '\x39', '\x42',
+'\x45' };
+
+std::string attstr[] = {
+"OFF","3db","6db","9db","12db","15db","18db","21db",
+"24db","27db","30db","33db","36db","39db","42db","45db"
+};
+
+void RIG_IC7610::set_index_att(int v)
+{
+	if (v < 0) return;
+	if (v >= (int)sizeof(attval)) return;
+	progStatus.index_ic7610att = v;
+
+	cmd.assign(pre_to);
+	cmd += '\x11';
+	cmd += attval[v];
+	cmd.append(post);
+	waitFB("SET attenuator");
+	set_trace(2, "set_index_att()", str2hex(cmd.c_str(), cmd.length()));
+}
+
+int RIG_IC7610::get_attenuator()
+{
+	cmd = pre_to;
+	cmd += '\x11';
+	cmd.append( post );
+	std::string resp = pre_fm;
+	resp += '\x11';
+	if (waitFOR(7, "get ATT")) {
+		size_t p = replystr.rfind(resp);
+		if (p != std::string::npos) {
+			atten_level = replystr[p+5];
+			size_t i = 0;
+			for (i = 0; i < sizeof(attval); i++) {
+				if (attval[i] == atten_level) {
+					progStatus.index_ic7610att = i;
+					break;
+				}
+			}
+		}
+	}
+	get_trace(2, "get_attenuator() ", str2hex(replystr.c_str(), replystr.length()));
+	return progStatus.index_ic7610att;
+}
+
+const char *RIG_IC7610::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Amp 1"; break;
+		case 2:
+			return "Amp 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC7610::ATT_label()
+{
+	return attstr[progStatus.index_ic7610att].c_str();
+}
+
 void RIG_IC7610::set_noise(bool val)
 {
 	cmd = pre_to;
@@ -1952,7 +2029,7 @@ void RIG_IC7610::set_pbt_inner(int val)
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
 	waitFB("set PBT inner");
-	set_trace(4, "set_pbt_inner(", val, ") ", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(4, "set_pbt_inner(", IC7610_bcd_vals[shift], ") ", str2hex(cmd.c_str(), cmd.length()));
 }
 
 void RIG_IC7610::set_pbt_outer(int val)
@@ -1966,7 +2043,7 @@ void RIG_IC7610::set_pbt_outer(int val)
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
 	waitFB("set PBT outer");
-	set_trace(4, "set_pbt_outer(", val, ") ", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(4, "set_pbt_outer(", IC7610_bcd_vals[shift], ") ", str2hex(cmd.c_str(), cmd.length()));
 }
 
 int RIG_IC7610::get_pbt_inner()
@@ -2121,50 +2198,6 @@ int RIG_IC7610::get_dual_watch()
 	return progStatus.dual_watch;
 }
 
-static char attval[] = {
-'\x00', '\x03', '\x06', '\x09', '\x12',
-'\x15', '\x18', '\x21', '\x24', '\x27',
-'\x30', '\x33', '\x36', '\x39', '\x42',
-'\x45' };
-
-void RIG_IC7610::set_index_att(int v)
-{
-	if (v < 0) return;
-	if (v >= (int)sizeof(attval)) return;
-
-	cmd.assign(pre_to);
-	cmd += '\x11';
-	cmd += attval[v];
-	cmd.append(post);
-	waitFB("SET attenuator");
-	set_trace(2, "set_index_att()", str2hex(cmd.c_str(), cmd.length()));
-}
-
-int RIG_IC7610::get_attenuator()
-{
-	cmd = pre_to;
-	cmd += '\x11';
-	cmd.append( post );
-	std::string resp = pre_fm;
-	resp += '\x11';
-	if (waitFOR(7, "get ATT")) {
-		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos) {
-			atten_level = replystr[p+5];
-			size_t i = 0;
-			for (i = 0; i < sizeof(attval); i++) {
-				if (attval[i] == atten_level) {
-					progStatus.index_ic7610att = i;
-					Fl::awake(set_ic7610_index_att);
-					break;
-				}
-			}
-		}
-	}
-	get_trace(2, "get_attenuator() ", str2hex(replystr.c_str(), replystr.length()));
-	return progStatus.index_ic7610att;
-}
-
 // Read/Write band stack registers
 //
 // Read 23 bytes
@@ -2208,10 +2241,10 @@ void RIG_IC7610::get_band_selection(int v)
 		get_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
-			int bandmode = replystr[p+13];
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			int bandmode = fm_bcd(replystr.substr(p+13, 1), 2);
 			int bandfilter = replystr[p+14];
-			int banddata = replystr[p+15] & 0x10;
+			int banddata = replystr[p+15] & 0xF0;
 			int tone = fm_bcd(replystr.substr(p+16, 3), 6);
 			size_t index = 0;
 			for (index = 0; index < sizeof(PL_tones) / sizeof(*PL_tones); index++)
@@ -2236,10 +2269,22 @@ void RIG_IC7610::get_band_selection(int v)
 						(banddata == 0x20) ? m7610AMD2 :
 						(banddata == 0x30) ? m7610AMD3 : m7610AM);
 						break;
-				case 3: bandmode = ((banddata == 0x10) ? m7610FMD1 : 
+				case 3: bandmode = m7610CW;
+						break;
+				case 4: bandmode = m7610RTTY;
+						break;
+				case 5: bandmode = ((banddata == 0x10) ? m7610FMD1 :
 						(banddata == 0x20) ? m7610FMD2 :
 						(banddata == 0x30) ? m7610FMD3 : m7610FM);
 						break;
+				case 7: bandmode = m7610CWR;
+						break;
+				case 8: bandmode = m7610RTTYR;
+						break;
+				case 12: bandmode = m7610PSK;
+						break;
+				case 13: bandmode = m7610PSKR;
+						break;
 				default:
 						break;
 			}
@@ -2259,34 +2304,32 @@ void RIG_IC7610::get_band_selection(int v)
 
 void RIG_IC7610::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
-	int fil = (inuse == onB ? filB : filA);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? B.filter : A.filter);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
 	cmd += to_bcd_be( v, 2 );
-	cmd += '\x01';
+	cmd += '\x01';	// Currently hardcoded to write to Register 1 - there is no UI support yet to specify other Registers
 	cmd.append( to_bcd_be( freq, 10 ) );
-	cmd += mode;
-	cmd += fil;
-	if (mode >= m7610LSBD1 && mode <= m7610FMD3 )
-		cmd += '\x10';
-	else
-		cmd += '\x00';
+	cmd += IC7610_mode_nbr[mode];
+	cmd.append( to_bcd_be( fil, 2 ) );
+
+
+	// No way in current UI for user to enable / disable either the TX tone or the RX squelch
+	// tone, so the second nibble of the next byte is always '0'.  Full capability would be:
+	// 0 = no tone; 1 = Repeater tone; 2 = T-SQL (Tone squelch - open receive on detection) tone
+	if (mode >= m7610LSBD1 && mode <= m7610FMD1 ) cmd += '\x10';
+	else if (mode >= m7610LSBD2 && mode <= m7610FMD2 ) cmd += '\x20';
+	else if (mode >= m7610LSBD3 && mode <= m7610FMD3 ) cmd += '\x30';
+	else cmd += '\x00';
 	cmd.append(to_bcd(PL_tones[tTONE], 6));
 	cmd.append(to_bcd(PL_tones[rTONE], 6));
 	cmd.append(post);
-	waitFB("set_band_selection");
 	set_trace(2, "set_band_selection()", str2hex(cmd.c_str(), cmd.length()));
+	waitFB("set_band_selection");
 
-	cmd.assign(pre_to);
-	cmd.append("\x1A\x01");
-	cmd += to_bcd_be( v, 2 );
-	cmd += '\x01';
-	cmd.append( post );
-
-	waitFOR(23, "get band stack");
 }
 
 // ---------------------------------------------------------------------
