@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC7700.h"
@@ -139,16 +139,17 @@ RIG_IC7700::RIG_IC7700() {
 	_mode_type = IC7700_mode_type;
 	adjustCIV(defaultCIV);
 
-	comm_retries = 2;
-	comm_wait = 20;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = IC7700_widgets;
 
@@ -185,11 +186,11 @@ RIG_IC7700::RIG_IC7700() {
 
 	filA = filB = 1;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 34;
 
@@ -472,11 +473,9 @@ void RIG_IC7700::set_attenuator(int val)
 	int cmdval = 0;
 	if (atten_level == 0) {
 		atten_level = 1;
-		atten_label("20 dB", true);
 		cmdval = 0x20;
 	} else if (atten_level == 1) {
 		atten_level = 0;
-		atten_label("Att", false);
 		cmdval = 0x00;
 	}
 	cmd = pre_to;
@@ -499,15 +498,19 @@ int RIG_IC7700::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+6] == 0x20) {
 			atten_level = 1;
-			atten_label("20 dB", true);
 		} else {
 			atten_level = 0;
-			atten_label("Att", false);
 		}
 	}
 	return atten_level;
 }
 
+const char *RIG_IC7700::ATT_label()
+{
+	if (atten_level == 1) return "12 dB";
+	return "ATT";
+}
+
 void RIG_IC7700::set_compression(int on, int val)
 {
 	if (on) {
@@ -789,7 +792,7 @@ void RIG_IC7700::get_band_selection(int v)
 		igett("get band stack");
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -822,7 +825,7 @@ void RIG_IC7700::get_band_selection(int v)
 
 void RIG_IC7700::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
