@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "icom/IC7800.h"
@@ -144,6 +144,9 @@ RIG_IC7800::RIG_IC7800() {
 	_mode_type = IC7800_mode_type;
 	adjustCIV(defaultCIV);
 
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
 	widgets = IC7800_widgets;
 
 	has_extras =
@@ -172,7 +175,6 @@ RIG_IC7800::RIG_IC7800() {
 	has_notch_control =
 	has_attenuator_control =
 	has_preamp_control =
-	has_ifshift_control =
 	has_pbt_controls =
 	has_FILTER = 
 	has_ptt_control =
@@ -195,11 +197,11 @@ RIG_IC7800::RIG_IC7800() {
 	ndigits = 8;
 	filA = filB = 1;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 34;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 34;
 
@@ -551,7 +553,6 @@ void RIG_IC7800::set_attenuator(int val)
 	atten_level = val;
 
 	int cmdval = atten_level;
-	atten_label(atten_labels[atten_level], true);
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd += cmdval;
@@ -566,15 +567,19 @@ int RIG_IC7800::get_attenuator()
 	cmd += '\x11';
 	cmd.append( post );
 	if (sendICcommand(cmd,7)) {
-		if (replystr[4] == 0x06) {
+		if (replystr[4] == 0x06)
 			atten_level = replystr[5];
-			if (atten_level >= 0 && atten_level <= 7)
-				atten_label(atten_labels[atten_level], true);
-		}
 	}
 	return atten_level;
 }
 
+const char *RIG_IC7800::ATT_label()
+{
+	if (atten_level >= 0 && atten_level <= 7)
+		return atten_labels[atten_level];
+	return atten_labels[0];
+}
+
 void RIG_IC7800::set_compression(int on, int val)
 {
 	if (on) {
@@ -834,7 +839,7 @@ void RIG_IC7800::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -866,7 +871,7 @@ void RIG_IC7800::get_band_selection(int v)
 
 void RIG_IC7800::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int fil = (inuse == onB ? filB : filA);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
