@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <sstream>
@@ -152,28 +152,29 @@ RIG_IC9100::RIG_IC9100() {
 
 	_mode_type = IC9100_mode_type;
 
-	comm_baudrate = BR19200;
+	serial_baudrate = BR19200;
 
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
-	A.freq = 14070000;
+	A.freq = 14070000ULL;
 	A.imode = USB9100D;
 	A.iBW = 34;
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = USB9100D;
 	B.iBW = 34;
 
-	def_freq = 14070000L;
+	def_freq = 14070000ULL;
 	def_mode = USB9100D;
 	def_bw = 34;
 
@@ -276,7 +277,7 @@ bool RIG_IC9100::check ()
 	return ok;
 }
 
-unsigned long int RIG_IC9100::get_vfoA ()
+unsigned long long RIG_IC9100::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -297,7 +298,7 @@ unsigned long int RIG_IC9100::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC9100::set_vfoA (unsigned long int freq)
+void RIG_IC9100::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -308,7 +309,7 @@ void RIG_IC9100::set_vfoA (unsigned long int freq)
 	set_trace(2, "set_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 }
 
-unsigned long int RIG_IC9100::get_vfoB ()
+unsigned long long RIG_IC9100::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -329,7 +330,7 @@ unsigned long int RIG_IC9100::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC9100::set_vfoB (unsigned long int freq)
+void RIG_IC9100::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -1255,11 +1256,9 @@ int  RIG_IC9100::agc_val()
 void RIG_IC9100::set_attenuator(int val)
 {
 	if (val) {
-		atten_label("20 dB", true);
 		atten_level = 1;
 		set_preamp(0);
 	} else {
-		atten_label("ATT", false);
 		atten_level = 0;
 	}
 
@@ -1291,11 +1290,9 @@ int RIG_IC9100::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
-				atten_label("ATT", false);
 				atten_level = 0;
 				return 0;
 			} else {
-				atten_label("20 dB", true);
 				atten_level = 1;
 				return 1;
 			}
@@ -1323,13 +1320,10 @@ void RIG_IC9100::set_preamp(int val)
 	cmd += '\x02';
 
 	if (val == 0) {
-		preamp_label("Pre", false);
 		preamp_level = 0;
 	} else if (val == 1) {
-		preamp_label("Pre 1", true);
 		preamp_level = 1;
 	} else {
-		preamp_label("Pre 2", true);
 		preamp_level = 2;
 	}
 	cmd += preamp_level;
@@ -1358,13 +1352,10 @@ int RIG_IC9100::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
-				preamp_label("Pre 1", true);
 				preamp_level = 1;
 			} else if (replystr[p+6] == 0x02) {
-				preamp_label("Pre 2", true);
 				preamp_level = 2;
 			} else {
-				preamp_label("Pre", false);
 				preamp_level = 0;
 			}
 		}
@@ -1374,6 +1365,30 @@ int RIG_IC9100::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_IC9100::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "Amp 1"; break;
+		case 2:
+			return "Amp 2"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_IC9100::ATT_label()
+{
+	if (atten_level == 0x06)
+		return("6 dB");
+	if (atten_level == 0x12)
+		return("12 dB");
+	if (atten_level == 0x18)
+		return("18 dB");
+	return "ATT";
+}
+
 // Tranceiver PTT on/off
 void RIG_IC9100::set_PTT_control(int val)
 {
@@ -1710,7 +1725,7 @@ void RIG_IC9100::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1743,7 +1758,7 @@ void RIG_IC9100::get_band_selection(int v)
 
 void RIG_IC9100::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
