@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <sstream>
@@ -159,28 +159,29 @@ RIG_IC9700::RIG_IC9700() {
 
 	_mode_type = IC9700_mode_type;
 
-	comm_baudrate = BR19200;
+	serial_baudrate = BR19200;
 
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
-	A.freq = 14070000;
+	A.freq = 14070000ULL;
 	A.imode = USB9700D;
 	A.iBW = 34;
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = USB9700D;
 	B.iBW = 34;
 
-	def_freq = 14070000L;
+	def_freq = 14070000ULL;
 	def_mode = USB9700D;
 	def_bw = 34;
 
@@ -276,8 +277,8 @@ void RIG_IC9700::set_xcvr_auto_on()
 	if (waitFOR(8, "get ID") == false) {
 		cmd.clear();
 		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		if (progStatus.serial_baudrate >= 0 && progStatus.serial_baudrate <= 11) {
+			cmd.append( fes[progStatus.serial_baudrate], '\xFE');
 		}
 		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
@@ -383,7 +384,7 @@ bool RIG_IC9700::check ()
 
 static int ret = 0;
 
-unsigned long int RIG_IC9700::get_vfoA ()
+unsigned long long RIG_IC9700::get_vfoA ()
 {
 #ifdef DUALWATCH_SUB_AS_B
   int sat_mode = get_sat_mode() + get_dualwatch();
@@ -451,7 +452,7 @@ unsigned long int RIG_IC9700::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC9700::set_vfoA (unsigned long int freq)
+void RIG_IC9700::set_vfoA (unsigned long long freq)
 {
   A.freq = freq;
 
@@ -488,7 +489,7 @@ void RIG_IC9700::set_vfoA (unsigned long int freq)
   }
 }
 
-unsigned long int RIG_IC9700::get_vfoB ()
+unsigned long long RIG_IC9700::get_vfoB ()
 {
 #ifdef DUALWATCH_SUB_AS_B
   int sat_mode = get_sat_mode() + get_dualwatch();
@@ -553,7 +554,7 @@ unsigned long int RIG_IC9700::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC9700::set_vfoB (unsigned long int freq)
+void RIG_IC9700::set_vfoB (unsigned long long freq)
 {
   B.freq = freq;
 
@@ -1461,10 +1462,8 @@ int  RIG_IC9700::agc_val()
 void RIG_IC9700::set_attenuator(int val)
 {
 	if (val) {
-		atten_label("10 dB", true);
 		atten_level = 1;
 	} else {
-		atten_label("ATT", false);
 		atten_level = 0;
 	}
 
@@ -1496,11 +1495,9 @@ int RIG_IC9700::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
-				atten_label("ATT", false);
 				atten_level = 0;
 				return 0;
 			} else {
-				atten_label("10 dB", true);
 				atten_level = 1;
 				return 1;
 			}
@@ -1524,31 +1521,12 @@ int RIG_IC9700::next_preamp()
 
 void RIG_IC9700::set_preamp(int val)
 {
+	preamp_level = val;
+
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
-
-	switch (val) {
-		default:
-		case 0 :
-			preamp_label("P0/E0", false);
-			preamp_level = 0;
-			break;
-		case 1 :
-			preamp_label("P1/E0", true);
-			preamp_level = 1;
-			break;
-		case 2 :
-			preamp_label("P0/E1", true);
-			preamp_level = 2;
-			break;
-		case 3 :
-			preamp_label("P1/E1", true);
-			preamp_level = 3;
-			break;
-	}
 	cmd += preamp_level;
-
 	cmd.append( post );
 	waitFB("set Pre");
 
@@ -1568,33 +1546,39 @@ int RIG_IC9700::get_preamp()
 	cmd.append( post );
 	if (waitFOR(8, "get Pre")) {
 		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos) {
-			switch (replystr[p+6]) {
-			default:
-			case 0 :
-				preamp_label("P0/E0", false);
-				preamp_level = 0;
-				break;
-			case 1 :
-				preamp_label("P1/E0", true);
-				preamp_level = 1;
-				break;
-			case 2 :
-				preamp_label("P0/E1", true);
-				preamp_level = 2;
-				break;
-			case 3 :
-				preamp_label("P1/E1", true);
-				preamp_level = 3;
-				break;
-			}
-		}
+		if (p != std::string::npos)
+			preamp_level = replystr[p+6];
 	}
 	get_trace(2, "get_preamp()", str2hex(replystr.c_str(), replystr.length()));
 
 	return preamp_level;
 }
 
+const char *RIG_IC9700::PRE_label()
+{
+	switch (preamp_level) {
+		case 0 : default:
+			break;
+		case 1 :
+			return("P1/E0");
+			break;
+		case 2 :
+			return("P0/E1");
+			break;
+		case 3 :
+			return("P1/E1");
+			break;
+	}
+	return("P0/E0");
+}
+
+const char *RIG_IC9700::ATT_label()
+{
+	if (atten_level == 1)
+		return("10 dB");
+	return "ATT";
+}
+
 // Tranceiver PTT on/off
 void RIG_IC9700::set_PTT_control(int val)
 {
@@ -1931,7 +1915,7 @@ void RIG_IC9700::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != std::string::npos) {
-			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long long bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1964,7 +1948,7 @@ void RIG_IC9700::get_band_selection(int v)
 
 void RIG_IC9700::set_band_selection(int v)
 {
-	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	unsigned long long freq = (inuse == onB ? B.freq : A.freq);
 	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
