@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 #include <sstream>
@@ -160,24 +160,25 @@ RIG_ICF8101::RIG_ICF8101() {
 //	bw_vals_ = ICF8101_bw_vals_SSB;
 	widgets = ICF8101_widgets;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 //	def_bw = A.iBW = 29;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 //	B.iBW = 29;
 
@@ -280,7 +281,7 @@ bool RIG_ICF8101::check ()
 	return ok;
 }
 
-unsigned long int RIG_ICF8101::get_vfoA ()
+unsigned long long RIG_ICF8101::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -298,7 +299,7 @@ unsigned long int RIG_ICF8101::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_ICF8101::set_vfoA (unsigned long int freq)
+void RIG_ICF8101::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -311,7 +312,7 @@ void RIG_ICF8101::set_vfoA (unsigned long int freq)
 	setthex("set vfoA");
 }
 
-unsigned long int RIG_ICF8101::get_vfoB ()
+unsigned long long RIG_ICF8101::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -329,7 +330,7 @@ unsigned long int RIG_ICF8101::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_ICF8101::set_vfoB (unsigned long int freq)
+void RIG_ICF8101::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -843,15 +844,12 @@ void RIG_ICF8101::set_preamp(int val)
 	cmd += '\x00';
 	switch (val) {
 		case 0:
-			preamp_label("OFF", false);
 			cmd += '\x01';
 			break;
 		case 1:
-			preamp_label("PRE", true);
 			cmd += '\x00';
 			break;
 		case 2:
-			preamp_label("ATT", true);
 			cmd += '\x02';
 	}
 	cmd.append( post );
@@ -872,15 +870,12 @@ int RIG_ICF8101::get_preamp()
 		if (p != std::string::npos) {
 			switch (replystr[p+9]) {
 			case 0:
-				preamp_label("PRE", false);
 				preamp_level = 1;
 				break;
 			case 1:
-				preamp_label("OFF", true);
 				preamp_level = 0;
 				break;
 			case 2:
-				preamp_label("ATT", true);
 				preamp_level = 2;
 			}
 		}
@@ -889,6 +884,19 @@ int RIG_ICF8101::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_ICF8101::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "OFF"; break;
+		case 1:
+			return "PRE"; break;
+		case 2:
+			return "ATT"; break;
+	}
+	return "PRE";
+}
+
 void RIG_ICF8101::set_compression(int on, int val)
 {
 	std::string onoff = "\x1A\x05\x03\x09";
