@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -91,14 +91,6 @@ bool RIG_ICOM::sendICcommand(std::string cmd, int nbr)
 	return true;
 }
 
-void RIG_ICOM::delayCommand(std::string cmd, int wait)
-{
-	int oldwait = progStatus.comm_wait;
-	progStatus.comm_wait += wait;
-	sendCommand(cmd);
-	progStatus.comm_wait = oldwait;
-}
-
 #include <fstream>
 
 void RIG_ICOM::ICtrace(std::string cmd, std::string hexstr) 
@@ -115,19 +107,21 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 	std::string eor   = "\xFD";
 	std::string bad   = "\xFA\xFD";
 
+	// This code creates the preamble of the response from the preamble of the command
+	// by swapping the controller / radio addresses.
 	check[0] = cmd[0];
 	check[1] = cmd[1];
 	check[2] = cmd[3];
 	check[3] = cmd[2];
 
-	int delay =  n * 11000.0 / RigSerial->Baud();
+//	int delay =  n * 11000.0 / RigSerial->Baud();
 	int retnbr = 0;
 
 	replystr.clear();
 
 	if (progStatus.use_tcpip) {
-		send_to_remote(cmd, progStatus.byte_interval);
-		MilliSleep(delay + progStatus.tcpip_ping_delay);
+		send_to_remote(cmd);
+		MilliSleep(progStatus.tcpip_ping_delay);
 		retnbr = read_from_remote(replystr);
 		LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr, replystr.c_str());
 	} else {
@@ -138,17 +132,21 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 		RigSerial->FlushBuffer();
 		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
-		size_t tout1 = zmsec();
-		size_t tout2 = tout1;
+		size_t tstart = zmsec();
+		size_t tout = tstart + timeout;
 		size_t pcheck = std::string::npos;
 		size_t peor = std::string::npos;
 
 		std::string tempstr;
 		int nret;
 
-		while ((tout2 - tout1) < timeout) {
+		while ( zmsec() < tout ) {
 			tempstr.clear();
-			nret = RigSerial->ReadBuffer(tempstr, n + cmd.length(), check, eor);
+			nret = RigSerial->ReadBuffer(
+				tempstr, 
+				n + (progStatus.serial_echo ? cmd.length() : 0), 
+				check, 
+				eor);
 			replystr.append(tempstr);
 			retnbr += nret;
 
@@ -161,9 +159,7 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 				(peor != std::string::npos) &&
 				(peor > pcheck) )
 				return true;
-
-			tout2 = zmsec();
-			if (tout2 < tout1) tout1 = tout2;
+			MilliSleep(1);
 		}
 
 	}
@@ -171,17 +167,15 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 	return false;
 }
 
-bool RIG_ICOM::waitFB(const char *sz, int timeout)
+// waitFB - This function sends the command in the 'cmd' member string (via 'waitFOR'),
+//          specifying the number of bytes in the expected resposne.  'waitFOR' already
+//          knows the construction of the response message so this seems superfluous.
+bool RIG_ICOM::waitFB(const char *sz, unsigned long timeout)
 {
 #if SERIAL_DEBUG
 fprintf(serlog, "waitFB\n");
 #endif
-
-	if (!waitFOR(6, sz, timeout))
-		return false;
-	if (replystr.rfind("\xFB\xFD") == std::string::npos)
-		return false;
-	return true;
+	return waitFOR(6, sz, timeout);
 }
 
 // exchange & equalize are available in these Icom xcvrs
