@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "kenwood/TS570.h"
@@ -96,22 +96,25 @@ RIG_TS570::RIG_TS570() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	A.freq = 14070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	A.freq = 14070000ULL;
 	A.imode = 1;
 	A.iBW = 1;
-	B.freq = 7035000;
+	B.freq = 7035000ULL;
 	B.imode = 1;
 	B.iBW = 1;
 	can_change_alt_vfo = true;
@@ -234,7 +237,7 @@ bool RIG_TS570::check ()
 	return is_TS570;
 }
 
-unsigned long int RIG_TS570::get_vfoA ()
+unsigned long long RIG_TS570::get_vfoA ()
 {
 	cmd = "FA;";
 	get_trace(1, "get_vfoA()");
@@ -245,14 +248,14 @@ unsigned long int RIG_TS570::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return A.freq;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	A.freq = f;
 	return A.freq;
 }
 
-void RIG_TS570::set_vfoA (unsigned long int freq)
+void RIG_TS570::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -264,7 +267,7 @@ void RIG_TS570::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "set vfoA", cmd, "");
 }
 
-unsigned long int RIG_TS570::get_vfoB ()
+unsigned long long RIG_TS570::get_vfoB ()
 {
 	cmd = "FB;";
 
@@ -276,14 +279,14 @@ unsigned long int RIG_TS570::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return freqB;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqB = f;
 	return freqB;
 }
 
-void RIG_TS570::set_vfoB (unsigned long int freq)
+void RIG_TS570::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000000;";
@@ -310,15 +313,15 @@ int RIG_TS570::get_smeter()
 	cmd = "SM;";
 
 	get_trace(1, "get_smeter()");
-	int n = wait_char(';', 6, 100, "get smeter", ASC);
+	int n = wait_char(';', 7, 100, "get smeter", ASC);
 	gett("");
 
-	if (n < 6) return 0;
+	if (n < 7) return 0;
 	size_t p = replystr.rfind("SM");
 	if (p == std::string::npos) return -1;
 
-	size_t len = replystr.length();
-	replystr[len - 1] = 0;
+//	size_t len = replystr.length();
+//	replystr[len - 1] = 0;
 
 	int mtr = atoi(&replystr[p + 2]);
 	if (mtr <= 9)
