@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "kenwood/TS790.h"
@@ -38,20 +38,23 @@ RIG_TS790::RIG_TS790() {
 	modes_ = TS790modes_;
 	_mode_type = TS790_mode_type;
 	bandwidths_ = NULL;
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeB = modeA = def_mode = 1;
 	bwB = bwA = def_bw = 1;
-	freqB = freqA = def_freq = 146900000;
+	freqB = freqA = def_freq = 146900000ULL;
 	can_change_alt_vfo = true;
 
 	has_bandwidth_control =
@@ -87,7 +90,7 @@ bool RIG_TS790::check ()
 	return true;
 }
 
-unsigned long int RIG_TS790::get_vfoA ()
+unsigned long long RIG_TS790::get_vfoA ()
 {
 	cmd = "FA;";
 
@@ -97,14 +100,14 @@ unsigned long int RIG_TS790::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return freqA;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_TS790::set_vfoA (unsigned long int freq)
+void RIG_TS790::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000000;";
@@ -116,7 +119,7 @@ void RIG_TS790::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
-unsigned long int RIG_TS790::get_vfoB ()
+unsigned long long RIG_TS790::get_vfoB ()
 {
 	cmd = "FB;";
 	int ret = wait_char(';', 14, 100, "get vfo B", ASC);
@@ -125,14 +128,14 @@ unsigned long int RIG_TS790::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return freqB;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqB = f;
 	return freqB;
 }
 
-void RIG_TS790::set_vfoB (unsigned long int freq)
+void RIG_TS790::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000000;";
