@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "config.h"
@@ -200,21 +200,24 @@ RIG_TS890S::RIG_TS890S() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR115200;
+	serial_baudrate = BR115200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	B.imode = A.imode = USB;
 	B.iBW = A.iBW = DEF_SL_SH;
-	B.freq = A.freq = 14070000;
+	B.freq = A.freq = 14070000ULL;
 	can_change_alt_vfo = true;
 
 	nb_level = 2;
@@ -343,11 +346,6 @@ void RIG_TS890S::set_attenuator(int val)
 		cmd = "RA0";
 		cmd[2] = '0' + att_level;
 		sendCommand(cmd, 0);
-		atten_label(
-			(val == 0 ? "OFF" :
-			val == 1 ? "6 dB" :
-			val == 2 ? "12 dB" : "18 dB"),
-			(val == 0 ? false : true));
 	}
 }
 
@@ -380,10 +378,6 @@ void RIG_TS890S::set_preamp(int val)
 	if (val) cmd = "PA1;";
 	else     cmd = "PA0;";
 	sendCommand(cmd, 0);
-	if (val)
-		preamp_label("OFF", false);
-	else
-		preamp_label("ON", true);
 }
 
 int RIG_TS890S::get_preamp()
@@ -401,6 +395,20 @@ int RIG_TS890S::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_TS890S::PRE_label()
+{
+	if (preamp_level == 1) return "Pre 1";
+	return "PRE";
+}
+
+const char *RIG_TS890S::ATT_label()
+{
+	if (atten_level == 1) return "6 dB";
+	if (atten_level == 2) return "12 dB";
+	if (atten_level == 3) return "18 dB";
+	return "ATT";
+}
+
 //======================================================================
 // mode commands
 //======================================================================
@@ -1302,7 +1310,7 @@ int RIG_TS890S::get_split()
 	return split;
 }
 
-unsigned long int RIG_TS890S::get_vfoA ()
+unsigned long long RIG_TS890S::get_vfoA ()
 {
 	cmd = "FA;";
 	if (wait_char(';', 14, 100, "get vfoA", ASC) < 14) return A.freq;
@@ -1310,8 +1318,8 @@ unsigned long int RIG_TS890S::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return A.freq;
 
-	unsigned long int f = 0L;
-	unsigned long int mul = 1L;
+	unsigned long long f = 0ULL;
+	unsigned long long mul = 1ULL;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -1320,7 +1328,7 @@ unsigned long int RIG_TS890S::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_TS890S::set_vfoA (unsigned long int freq)
+void RIG_TS890S::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -1332,7 +1340,7 @@ void RIG_TS890S::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
-unsigned long int RIG_TS890S::get_vfoB ()
+unsigned long long RIG_TS890S::get_vfoB ()
 {
 	cmd = "FB;";
 	if (wait_char(';', 14, 100, "get vfoB", ASC) < 14) return B.freq;
@@ -1340,8 +1348,8 @@ unsigned long int RIG_TS890S::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return B.freq;
 
-	unsigned long int f = 0L;
-	unsigned long int mul = 1L;
+	unsigned long long f = 0ULL;
+	unsigned long long mul = 1ULL;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -1351,7 +1359,7 @@ unsigned long int RIG_TS890S::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_TS890S::set_vfoB (unsigned long int freq)
+void RIG_TS890S::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = "FB00000000000;";
