@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "kenwood/TS950.h"
@@ -71,23 +71,26 @@ RIG_TS950::RIG_TS950() {
 	_mode_type = TS950_mode_type;
 	bandwidths_ = TS950_widths;
 	bw_vals_ = TS950_bw_vals;
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = rig_widgets;
 
 	modeB = modeA = def_mode = 1;
 	bwB = bwA = def_bw = 1;
-	freqB = freqA = def_freq = 14070000;
+	freqB = freqA = def_freq = 14070000ULL;
 	can_change_alt_vfo = true;
 
 	has_noise_control =
@@ -135,7 +138,7 @@ void RIG_TS950::set_data_port()
 	sendCommand(cmd);
 }
 
-unsigned long int RIG_TS950::get_vfoA ()
+unsigned long long RIG_TS950::get_vfoA ()
 {
 	cmd = "FA;";
 
@@ -145,7 +148,7 @@ unsigned long int RIG_TS950::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return freqA;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqA = f;
@@ -153,7 +156,7 @@ unsigned long int RIG_TS950::get_vfoA ()
 	return freqA;
 }
 
-void RIG_TS950::set_vfoA (unsigned long int freq)
+void RIG_TS950::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000000;";
@@ -165,7 +168,7 @@ void RIG_TS950::set_vfoA (unsigned long int freq)
 	sett("vfo A");
 }
 
-unsigned long int RIG_TS950::get_vfoB ()
+unsigned long long RIG_TS950::get_vfoB ()
 {
 	cmd = "FB;";
 	int ret = wait_char(';', 14, 100, "get vfo B", ASC);
@@ -174,7 +177,7 @@ unsigned long int RIG_TS950::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return freqB;
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqB = f;
@@ -182,7 +185,7 @@ unsigned long int RIG_TS950::get_vfoB ()
 	return freqB;
 }
 
-void RIG_TS950::set_vfoB (unsigned long int freq)
+void RIG_TS950::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000000;";
