@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 /*
  * Copyright (c) 2014 Andy Burnett, G0HIX
@@ -334,7 +334,7 @@ RIG_TS990::RIG_TS990() {
 	name_ = TS990name_;
 	modes_ = TS990modes_;
 
-	B.freq = A.freq = 14107500;
+	B.freq = A.freq = 14107500ULL;
 
 	A.imode = USB;
 	A.iBW = A_default_HI_LO;
@@ -354,17 +354,20 @@ RIG_TS990::RIG_TS990() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR115200;
+	serial_baudrate = BR115200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	can_change_alt_vfo = true;
 
@@ -465,17 +468,13 @@ void RIG_TS990::set_attenuator(int val)
 	if (inuse == onB) {
 		if (atten_level == 1) {			// If attenuator level = 0 (off)
 			cmd = "RA11;";				// this is the command...
-			atten_label("Att 6", true);	// show it in the button...
 		}
 		else if (atten_level == 2) {		// If attenuator level = 1 (6dB)
 			cmd = "RA12;";
-			atten_label("Att 12", true);
 		} else if (atten_level == 3) {		// if it's 12dB
 			cmd = "RA13;";
-			atten_label("Att 18", true);
 		} else if (atten_level == 0) {		// If it's 18dB
 			cmd = "RA10;";
-			atten_label("Att", false);
 		}
 		sendCommand(cmd);
 		showresp(INFO, ASC, "set Att B", cmd, "");
@@ -483,17 +482,13 @@ void RIG_TS990::set_attenuator(int val)
 	} else {
 		if (atten_level == 1) {
 			cmd = "RA01;";
-			atten_label("Att 6", true);
 		}
 		else if (atten_level == 2) {
 			cmd = "RA02;";
-			atten_label("Att 12", true);
 		} else if (atten_level == 3) {
 			cmd = "RA03;";
-			atten_label("Att 18", true);
 		} else if (atten_level == 0) {
 			cmd = "RA00;";
-			atten_label("Att", false);
 		}
 		sendCommand(cmd);
 		showresp(INFO, ASC, "set Att A", cmd, "");
@@ -517,19 +512,15 @@ int RIG_TS990::get_attenuator() {
 		if (replystr[p + 2] == '1' && replystr[p + 3] == '0') {
 			att_on = 0;						// Attenuator is OFF
 			atten_level = 0;					// remember it...
-			atten_label("Att", false);		// show it...
 		} else if (replystr[p + 2] == '1' && replystr[p + 3] == '1') {
 			att_on = 1;						// Attenuator is ON, 6dB
 			atten_level = 1;					// remember the level
-			atten_label("Att 6", true);		// show it...
 		} else if (replystr[p + 2] == '1' && replystr[p + 3] == '2') {
 			att_on = 1;						// .. still ON, 12dB
 			atten_level = 2;					// remember this level
-			atten_label("Att 12", true);	// show it.
 		} else if (replystr[p + 2] == '1' && replystr[p + 3] == '3') {
 			att_on = 1;						// .. still ON 18dB
 			atten_level = 3;					// remember...
-			atten_label("Att 18", true);	// show this too..
 		}
 	} else {
 		cmd = "RA0;";
@@ -541,19 +532,15 @@ int RIG_TS990::get_attenuator() {
 		if (replystr[p + 2] == '0' && replystr[p + 3] == '0') {
 			att_on = 0;
 			atten_level = 0;
-			atten_label("Att", false);
 		} else if (replystr[p + 2] == '0' && replystr[p + 3] == '1') {
 			att_on = 1;
 			atten_level = 1;
-			atten_label("Att 6", true);
 		} else if (replystr[p + 2] == '0' && replystr[p + 3] == '2') {
 			att_on = 1;
 			atten_level = 2;
-			atten_label("Att 12", true);
 		} else if (replystr[p + 2] == '0' && replystr[p + 3] == '3') {
 			att_on = 1;
 			atten_level = 3;
-			atten_label("Att 18", true);
 		}
 	}
 	return att_on;
@@ -622,6 +609,21 @@ int RIG_TS990::get_preamp()
 	return preamp_level;
 }
 
+const char *RIG_TS990::PRE_label()
+{
+	if (preamp_level == 1) return "Pre 1";
+	return "PRE";
+}
+
+const char *RIG_TS990::ATT_label()
+{
+	if (atten_level == 1) return "6 dB";
+	if (atten_level == 2) return "12 dB";
+	if (atten_level == 3) return "18 dB";
+	return "ATT";
+}
+
+
 //==============================================================================
 
 void RIG_TS990::set_split(bool val)
@@ -718,7 +720,7 @@ bool RIG_TS990::check ()
 	return true;
 }
 
-unsigned long int RIG_TS990::get_vfoA ()
+unsigned long long RIG_TS990::get_vfoA ()
 {
 	gett("get_vfoA()");
 
@@ -728,8 +730,8 @@ unsigned long int RIG_TS990::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return A.freq;
 
-	unsigned long int f = 0L;
-	unsigned long int mul = 1L;
+	unsigned long long f = 0ULL;
+	unsigned long long mul = 1ULL;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -738,9 +740,9 @@ unsigned long int RIG_TS990::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_TS990::set_vfoA (unsigned long int freq)
+void RIG_TS990::set_vfoA (unsigned long long freq)
 {
-	sett("set_vfoA(unsigned long int freq)");
+	sett("set_vfoA(unsigned long long freq)");
 
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -752,7 +754,7 @@ void RIG_TS990::set_vfoA (unsigned long int freq)
 	showresp(INFO, ASC, "set vfo A", cmd, "");
 }
 
-unsigned long int RIG_TS990::get_vfoB ()
+unsigned long long RIG_TS990::get_vfoB ()
 {
 	gett("get_vfoB()");
 
@@ -762,8 +764,8 @@ unsigned long int RIG_TS990::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == std::string::npos) return B.freq;
 
-	unsigned long int f = 0L;
-	unsigned long int mul = 1L;
+	unsigned long long f = 0ULL;
+	unsigned long long mul = 1ULL;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -773,9 +775,9 @@ unsigned long int RIG_TS990::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_TS990::set_vfoB (unsigned long int freq)
+void RIG_TS990::set_vfoB (unsigned long long freq)
 {
-	sett("set_vfoB(unsigned long int freq)");
+	sett("set_vfoB(unsigned long long freq)");
 
 	B.freq = freq;
 	cmd = "FB00000000000;";
