@@ -113,20 +113,23 @@ RIG_TX500::RIG_TX500() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts =  false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt =  true;
-	comm_rtsptt =  false;
-	comm_dtrptt =  false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts =  false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt =  true;
+	serial_rtsptt =  false;
+	serial_dtrptt =  false;
 	B.imode = A.imode = 1;
 	B.iBW = A.iBW = 0x8803;
-	B.freq = A.freq = 14070000;
+	B.freq = A.freq = 14070000ULL;
 	can_change_alt_vfo = true;
 
 	has_power_out =
@@ -319,7 +322,7 @@ void RIG_TX500::selectB()
 	inuse = onB;
 }
 
-unsigned long int RIG_TX500::get_vfoA ()
+unsigned long long RIG_TX500::get_vfoA ()
 {
 	cmd = "FA;";
 	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
@@ -327,12 +330,12 @@ unsigned long int RIG_TX500::get_vfoA ()
 
 	size_t p = replystr.rfind("FA");
 	if (p != std::string::npos && (p + 12 < replystr.length())) {
-		A.freq = atol(&replystr[ p + 2]);
+		A.freq = strtoull(&replystr[ p + 2], NULL, 10);
 	}
 	return A.freq;
 }
 
-void RIG_TX500::set_vfoA (unsigned long int freq)
+void RIG_TX500::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -346,7 +349,7 @@ void RIG_TX500::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
-unsigned long int RIG_TX500::get_vfoB ()
+unsigned long long RIG_TX500::get_vfoB ()
 {
 	cmd = "FB;";
 	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
@@ -354,12 +357,12 @@ unsigned long int RIG_TX500::get_vfoB ()
 
 	size_t p = replystr.rfind("FB");
 	if (p != std::string::npos && (p + 12 < replystr.length())) {
-		B.freq = atol(&replystr[ p + 2 ]);
+		B.freq = strtoull(&replystr[ p + 2 ], NULL, 10);
 	}
 	return B.freq;
 }
 
-void RIG_TX500::set_vfoB (unsigned long int freq)
+void RIG_TX500::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = "FB00000000000;";
