@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 // AOR 5000 driver based on several other drivers as examples.
 //          Written 05/2017 by Mario Lorenz, dl5mlo@amsat-dl.org
@@ -71,22 +71,25 @@ RIG_AOR5K::RIG_AOR5K() {
 	SH_tooltip = AOR5K_SH_label;
 	SH_label = AOR5K_SH_label;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 
 	widgets = aor5k_widgets;
 
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = false;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	def_freq = freqA = freqB = 14070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = false;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	def_freq = freqA = freqB = 14070000ULL;
 	def_mode = modeA = modeB = 1;
 	def_bw = bwA = bwB = 1;
 
@@ -225,7 +228,7 @@ bool RIG_AOR5K::check()
 	return true;
 }
 
-unsigned long int RIG_AOR5K::get_vfoA ()
+unsigned long long RIG_AOR5K::get_vfoA ()
 {
 	cmd = "RX\r";
 	int ret = wait_char('\r', 34, AOR5K_WAIT_TIME, "get vfo A", ASC);
@@ -235,7 +238,7 @@ unsigned long int RIG_AOR5K::get_vfoA ()
 	if (p < 3) return freqA;
 	if (replystr[p-2] =='E') {
 		// VFO A is active. Instead of A we use E
-		unsigned long int f = 0;
+		unsigned long long f = 0;
 		for (size_t n = 2; n < 12; n++)
 			f = f*10 + replystr[p + n] - '0';
 		freqA = f;
@@ -243,7 +246,7 @@ unsigned long int RIG_AOR5K::get_vfoA ()
 	return freqA;
 }
 
-void RIG_AOR5K::set_vfoA (unsigned long int freq)
+void RIG_AOR5K::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "VE0000000000\r";
@@ -254,7 +257,7 @@ void RIG_AOR5K::set_vfoA (unsigned long int freq)
 	wait_char('\r', 1, AOR5K_WAIT_TIME, "set VFO A", ASC);
 }
 
-unsigned long int RIG_AOR5K::get_vfoB ()
+unsigned long long RIG_AOR5K::get_vfoB ()
 {
 	cmd = "RX\r";
 	int ret = wait_char('\r', 34, AOR5K_WAIT_TIME, "get vfo B", ASC);
@@ -264,7 +267,7 @@ unsigned long int RIG_AOR5K::get_vfoB ()
 	if (p < 3) return freqB;
 	if (replystr[p-2] == 'B') {
 		// VFO B active
-		unsigned long int f = 0;
+		unsigned long long f = 0;
 		for (size_t n = 2; n < 12; n++)
 			f = f*10 + replystr[p + n] - '0';
 		freqB = f;
@@ -272,7 +275,7 @@ unsigned long int RIG_AOR5K::get_vfoB ()
 	return freqB;
 }
 
-void RIG_AOR5K::set_vfoB (unsigned long int freq)
+void RIG_AOR5K::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "VB0000000000\r";
@@ -369,23 +372,19 @@ void RIG_AOR5K::set_attenuator(int val)
 	switch (atten_level) {
 		case 1:
 			cmd = "AT1\r";
-			atten_label("10 dB", true);
 			break;
 		case 2:
 			cmd = "AT2\r";
-			atten_label("20 dB", true);
 			break;
 		case 22:
 			cmd = "ATF\r";
-			atten_label("AUTO", true);
 			break;
 		case 0:
 		default:
 			cmd = "AT0\r";
-			atten_label("0 dB", false);
 			break;
 	}
-	wait_char('\r', 1, AOR5K_WAIT_TIME, "set BW A", ASC);
+	wait_char('\r', 1, AOR5K_WAIT_TIME, "set attenuator", ASC);
 }
 
 int RIG_AOR5K::get_attenuator()
@@ -400,15 +399,21 @@ int RIG_AOR5K::get_attenuator()
 		atten_level = 22;
 	else atten_level = replystr[p + 3] - '0';
 
-	switch (atten_level) {
-		case 0:	atten_label("0 dB", false); break;
-		case 1: atten_label("10 dB", true); break;
-		case 2: atten_label("20 dB", true); break;
-		case 22: atten_label("AUTO", true); break;
-	}
 	return atten_level;
 }
 
+const char *RIG_AOR5K::ATT_label()
+{
+	switch (atten_level) {
+		default:
+		case 0:	return "0 dB"; break;
+		case 1: return "10 dB"; break;
+		case 2: return "20 dB"; break;
+		case 22: return "AUTO"; break;
+	}
+	return "0 dB";
+}
+
 //SM $ (S-meter Read; GET only)
 int RIG_AOR5K::get_smeter()
 {
