@@ -16,7 +16,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "other/FLEX1500.h"
@@ -95,15 +95,15 @@ static char *varwidths[] = {
 //------------------------------------------------------------------------------
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 }, // 1
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 368 }, // 1
 	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 }, // 3
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 }, // 4
-	{ (Fl_Widget *)btnNotch,    214, 125,  50 }, // 5
-	{ (Fl_Widget *)sldrNOTCH,   266, 125, 156 }, // 6
-	{ (Fl_Widget *)sldrSQUELCH, 266, 145, 156 }, // 7
+	{ (Fl_Widget *)btnIFsh,       2, 165,  50 }, // 3
+	{ (Fl_Widget *)sldrIFSHIFT,  54, 165, 156 }, // 4
+	{ (Fl_Widget *)btnNotch,    214, 145,  50 }, // 5
+	{ (Fl_Widget *)sldrNOTCH,   266, 145, 156 }, // 6
+	{ (Fl_Widget *)sldrSQUELCH, 266, 165, 156 }, // 7
 	{ (Fl_Widget *)sldrMICGAIN, 266, 165, 156 }, // 8
-	{ (Fl_Widget *)sldrPOWER,    54, 165, 368 }, // 9
+	{ (Fl_Widget *)sldrPOWER,    54, 185, 368 }, // 9
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
@@ -164,27 +164,30 @@ RIG_FLEX1500::RIG_FLEX1500() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	B.imode = A.imode = 1;
 	B.iBW = A.iBW = 0x8803;
-	B.freq = A.freq = 14070000;
+	B.freq = A.freq = 14070000ULL;
 	can_change_alt_vfo = true;
 
 	has_dsp_controls =
-	has_preamp_control =
-	has_power_out = false;
+	false;
 
-	has_swr_control = true;
+	has_power_out =
+	has_swr_control =
 	has_alc_control =
 	has_split =
 	has_split_AB =
@@ -192,7 +195,7 @@ RIG_FLEX1500::RIG_FLEX1500() {
 	has_auto_notch =
 	has_ifshift_control =
 	has_smeter =
-	has_noise_reduction = true;
+	has_noise_reduction =
 	has_noise_reduction_control =
 	has_noise_control =
 	has_micgain_control =
@@ -202,8 +205,9 @@ RIG_FLEX1500::RIG_FLEX1500() {
 	has_mode_control =
 	has_bandwidth_control =
 	has_sql_control =
-	has_ptt_control = 
-	has_extras = true;
+	has_ptt_control =
+	has_extras =
+	has_preamp_control = true;
 
 	rxona = true;
 
@@ -281,17 +285,17 @@ void RIG_FLEX1500::set_power_control(double val)
 	sett("pwr control");
 }
 
-//int RIG_FLEX1500::get_power_out()
-//{
-//	float mtr = 0.0;
-//	cmd = "ZZRM5;";
-//	get_trace(1, "get_power_out");
-//	ret = wait_char(';', 11, 100, "get power", ASC);
-//	gett("");
-//	if (ret < 11) return 0;
-//	sscanf(&replystr[0],"ZZRM5%f", &mtr);
-//	return (int)(10 * mtr);
-//}
+int RIG_FLEX1500::get_power_out()
+{
+	float mtr = 0.0;
+	cmd = "ZZRM5;";
+	get_trace(1, "get_power_out");
+	ret = wait_char(';', 11, 100, "get power", ASC);
+	gett("");
+	if (ret < 11) return 0;
+	sscanf(&replystr[0],"ZZRM5%f", &mtr);
+	return (int)(10 * mtr);
+}
 
 double RIG_FLEX1500::get_power_control()
 {
@@ -310,131 +314,81 @@ double RIG_FLEX1500::get_power_control()
 }
 
 struct meterpair {float mtr; float val;};
-//static meterpair swr_tbl[] = {
-//	{ 1,   0  },
-//	{ 1.5,  12.5  },
-//	{ 2,  25 },
-//	{ 3,  50 },
-//	{ 20, 100 }
-//};
+static meterpair swr_tbl[] = {
+	{ 1,   0  },
+	{ 1.5,  12.5  },
+	{ 2,  25 },
+	{ 3,  50 },
+	{ 20, 100 }
+};
 
-//int RIG_FLEX1500::get_swr()
-//{
-//	double mtr = 0;
-//	if (get_tune() != 0) return 0; // swr only works when tuning
-//	cmd = "ZZRM8;";
-//	get_trace(1, "get_swr");
-//	ret = wait_char(';', 8, 100, "get SWR", ASC);
-//	gett("");
-//	if (ret < 8) return (int)mtr;
-//	if (sscanf(&replystr[0], "ZZRM8%lf", &mtr)!=1) {
-//		return 0;
-//	}
-//	size_t i = 0;
-//	for (i = 0; i < sizeof(swr_tbl) / sizeof(meterpair) - 1; i++)
-//		if (mtr >= swr_tbl[i].mtr && mtr < swr_tbl[i+1].mtr)
-//			break;
-//	if (mtr > 19) mtr = 19;
-//	mtr = (int)round(swr_tbl[i].val +
-//		(swr_tbl[i+1].val - swr_tbl[i].val)*(mtr - swr_tbl[i].mtr)/(swr_tbl[i+1].mtr - swr_tbl[i].mtr));
-//	if (mtr > 100) mtr = 100;
-//	return mtr;
-//}
-
-//int RIG_FLEX1500::get_alc()
-//{
-//	double alc = 0;
-//	cmd = "ZZRM4;";
-//	get_trace(1, "get_alc");
-//	ret = wait_char(';', 8, 100, "get ALC", ASC);
-//	gett("");
-//	if (ret < 8) return (int)alc;
-//	if (sscanf(&replystr[0], "ZZRM4%lf", &alc) != 1) alc=0;
-//	return alc;
-//}
-
-#if 0
-/* disabling this as Thetis ZZPA command is screwy and won't work on all the models
-Using the selector
-0dB = ZZPA1
--10dB = ZZPA2 = -140
--20dB = ZZPA0 = -130
--30dB = ZZPA8 = -120 yet ZZPA8; does nothing
-
-If I look at the signal level for what the level is now.
-ZZPA0 = -130
-ZZPA1 = -150
-ZZPA2 = -140 -- but ZZPA then reports ZZPA7;
-ZZPA3 = -130
-ZZPA4 = -120
-ZZPA5 = -110
-ZZPA6 = -100
-ZZPA7 does nothing
-*/
-
-int  RIG_FLEX1500::next_preamp()
-{   
-	// strange sequence for ANAN 7000DLE MKII
-	switch(preamp_level)
-	{
-		case 0: preamp_level = 1;break;
-		case 1: preamp_level = 2;break;
-		case 7: preamp_level = 3;break;
-		case 3: preamp_level = 4;break;
-		case 4: preamp_level = 5;break;
-		case 5: preamp_level = 6;break;
-		default:
-		case 6: preamp_level = 0;break;
+int RIG_FLEX1500::get_swr()
+{
+	double mtr = 0;
+	if (get_tune() != 0) return 0; // swr only works when tuning
+	cmd = "ZZRM8;";
+	get_trace(1, "get_swr");
+	ret = wait_char(';', 8, 100, "get SWR", ASC);
+	gett("");
+	if (ret < 8) return (int)mtr;
+	if (sscanf(&replystr[0], "ZZRM8%lf", &mtr)!=1) {
+		return 0;
 	}
-	return preamp_level;
+	size_t i = 0;
+	for (i = 0; i < sizeof(swr_tbl) / sizeof(meterpair) - 1; i++)
+		if (mtr >= swr_tbl[i].mtr && mtr < swr_tbl[i+1].mtr)
+			break;
+	if (mtr > 19) mtr = 19;
+	mtr = (int)round(swr_tbl[i].val +
+		(swr_tbl[i+1].val - swr_tbl[i].val)*(mtr - swr_tbl[i].mtr)/(swr_tbl[i+1].mtr - swr_tbl[i].mtr));
+	if (mtr > 100) mtr = 100;
+	return mtr;
 }
 
+int RIG_FLEX1500::get_alc()
+{
+	double alc = 0;
+	cmd = "ZZRM4;";
+	get_trace(1, "get_alc");
+	ret = wait_char(';', 8, 100, "get ALC", ASC);
+	gett("");
+	if (ret < 8) return (int)alc;
+	if (sscanf(&replystr[0], "ZZRM4%lf", &alc) != 1) alc=0;
+	return alc;
+}
+
+/*
+  ZZPA0 : -10 dB
+  ZZPA1 : 0 dB
+  ZZPA2 : 10 dB
+  ZZPA3 : 20 dB
+  ZZPA4 : 30 dB
+*/
+
 void RIG_FLEX1500::set_preamp(int val)
 {
 	preamp_level = val;
 	cmd = "ZZPA";
-	cmd.append(to_decimal(val, 1)).append(";");
+	cmd += (val + '0');
+	cmd += ';';
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set PRE", cmd, "");
 	sett("preamp");
-		case 7: preamp_level = 0;break;
-	if (val == 0) {
-		preamp_label("Pre", false);
-		preamp_level = 0;
-	} else if (val == 1) {
-		preamp_label("Pre 1", true);
-		preamp_level = 1;
-	} else if (val == 7) {
-		preamp_label("Pre 2", true);
-		preamp_level = 2;
-	}
-
 }
 
 int RIG_FLEX1500::get_preamp()
 {
-	int preamp_level;
 	cmd = "ZZPA;";
-	std::stringstream str;
-	sendCommand(cmd);
 	get_trace(1, "get_preamp");
 	ret = wait_char(';', 6, 100, "get PRE", ASC);
 	gett("");
-	if (ret == 6) {
-		size_t p = replystr.rfind("PA");
-		str << "ZZPA #2 replystr=" << replystr << ", p=" << p;
-		trace(2, "get_preamp", replystr.c_str());
-		if (p != std::string::npos && (p+2 < replystr.length())) {
-			preamp_level = fm_decimal(replystr.substr(p+2),1);
-			// need to map 7 to 2 to keep FLRig cbPreamp happy
-			// when ZZPA2; is sent ZZPA7; comes back
-			if (preamp_level == 7) preamp_level = 2; 
-		}
-	}
-	else preamp_level = 0;
+	if (ret < 6) return preamp_level;
+
+	size_t p = replystr.rfind("PA");
+	if (p != std::string::npos)
+		preamp_level = (unsigned char)replystr[p+2] - '0';
 	return preamp_level;
 }
-#endif
 
 int RIG_FLEX1500::set_widths(int val)
 {
@@ -499,6 +453,18 @@ int RIG_FLEX1500::set_widths(int val)
 
 const char **RIG_FLEX1500::bwtable(int val)
 {
+	switch (val) {
+	case LSB: case USB:
+		bandwidths_ = FLEX1500_USBwidths; break;
+	case DIGU: case DIGL:
+		bandwidths_ = FLEX1500_DIGwidths; break;
+	case FM: case SPEC: case DRM:
+		bandwidths_ = FLEX1500_WIDEwidths; break;
+	case CWL: case CWU:
+		bandwidths_ = FLEX1500_CWwidths; break;
+	case AM: case SAM: case DSB: default:
+		bandwidths_ = FLEX1500_AMwidths; break;
+	}
 	return bandwidths_;
 }
 
@@ -528,6 +494,45 @@ const char **RIG_FLEX1500::hitable(int val)
 }
 #endif
 
+void RIG_FLEX1500::set_pbt(int inner, int outer)
+{
+	char cmdstr[50];
+	snprintf(cmdstr, sizeof(cmdstr), "ZZFL%c%04d;",
+			inner < 0 ? '-' : '+', inner);
+	sendCommand(cmd = cmdstr);
+	sett("");
+	snprintf(cmdstr, sizeof(cmdstr), "ZZFH%c%04d;",
+			outer < 0 ? '-' : '+', outer);
+	sendCommand(cmd = cmdstr);
+	sett("");
+}
+
+int RIG_FLEX1500::get_pbt_inner()
+{
+	cmd = "ZZFL;";
+	get_trace(1, "get_pbt_inner (lower)");
+	ret = wait_char(';', 10, 100, "get PBT lower", ASC);
+	gett("");
+	size_t p = replystr.find("ZZFL");
+	if (p != std::string::npos) {
+		FilterInner = atoi(replystr.substr(p+4).c_str());
+	}
+	return FilterInner;
+}
+
+int RIG_FLEX1500::get_pbt_outer()
+{
+	cmd = "ZZFH;";
+	get_trace(1, "get_pbt_inner (upper)");
+	ret = wait_char(';', 10, 100, "get PBT upper", ASC);
+	gett("");
+	size_t p = replystr.find("ZZFH");
+	if (p != std::string::npos) {
+		FilterOuter = atoi(replystr.substr(p+4).c_str());
+	}
+	return FilterOuter;
+}
+
 void RIG_FLEX1500::set_modeA(int val)
 {
 	if (val >= (int)(sizeof(FLEX1500_mode_chr)/sizeof(*FLEX1500_mode_chr))) return;
@@ -547,7 +552,7 @@ int RIG_FLEX1500::get_modeA()
 	if (tuning()) return A.imode;
 	cmd = "ZZMD;";
 	get_trace(1, "get_modeA");
-	ret = wait_char(';', 7, 100, "get mode A", 7);
+	ret = wait_char(';', 7, 100, "get mode A", ASC);
 	gett("");
 	if (ret == 7) {
 		size_t p = replystr.rfind("MD");
@@ -657,80 +662,47 @@ void RIG_FLEX1500::set_bwA(int val)
 	}
 }
 
-int RIG_FLEX1500::get_bwA()
+int RIG_FLEX1500::get_bw(int mode)
 {
 	size_t i = 0;
-	size_t p;
-	std::stringstream str;
-	str << "get_bwA" ;
-	A.iBW = 0;
-	trace(2, __func__, str.str().c_str());
-	if (A.imode == FM || A.imode == DRM || A.imode == SPEC) {
-		A.iBW = 0;
+	int bw = 0;
+	const char **tbl;
+	if (mode == FM || mode == DRM || mode == SPEC) 
 		gett("get_bwA Wideband");
-	}
-	else if (A.imode == LSB || A.imode == USB) {  
+	else {
 		cmd = "ZZFI;";
-		get_trace(1, "get_bw SSB");
+		get_trace(3, "get ", FLEX1500modes_[mode], " bandwidth");
 		ret = wait_char(';', 7, 100, "get ZZFI", ASC);
 		gett("");
-		if (ret == 7) {
-			p = replystr.rfind("ZZFI");
-			if (p != std::string::npos) {
-				for (i = 0; FLEX1500_CAT_USB[i] != NULL; i++)
-				{
-					if (replystr.find(FLEX1500_CAT_USB[i]) == p)
-						break;
-				}
-				A.iBW = i;
+		if (ret) {
+			switch (mode) {
+				default:
+				case LSB : case USB :
+					tbl = FLEX1500_CAT_USB;
+					break;
+				case CWL : case CWU :
+					tbl = FLEX1500_CAT_CW;
+					break;
+				case DIGU : case DIGL :
+					tbl = FLEX1500_CAT_DIG;
+					break;
+				case AM : case SAM : case DSB :
+					tbl = FLEX1500_CAT_AM;
+					break;
 			}
-		}
-	} 
-	else if (A.imode == CWL || A.imode == CWU) {
-		cmd = "ZZFI;";
-		get_trace(1, "get_bw CW");
-		ret = wait_char(';', 7, 100, "get ZZFI", ASC);
-		gett("");
-		if (ret == 7) {
-			p = replystr.rfind("ZZFI");
-			if (p != std::string::npos) {
-				for (i = 0; FLEX1500_CAT_CW[i] != NULL; i++)
-					if (replystr.find(FLEX1500_CAT_CW[i]) == p)
-						break;
-				A.iBW = i;
-			}
-		}
-	} 
-	else if (A.imode == DIGU || A.imode == DIGL) {
-		cmd = "ZZFI;";
-		get_trace(1, "get_bw DIGI");
-		ret = wait_char(';', 7, 100, "get ZZFI", ASC);
-		gett("");
-		if (ret == 7) {
-				for (i = 0; FLEX1500_CAT_DIG[i] != NULL; i++) {
-					if (replystr.compare(FLEX1500_CAT_DIG[i]) == 0) {
-						break;
-					}
-				}
-				A.iBW = i;
-		}
-	}
-	else if (A.imode == AM || A.imode == SAM || A.imode == DSB) {
-		cmd = "ZZFI;";
-		get_trace(1, "get_bw AM");
-		ret = wait_char(';', 7, 100, "get ZZFI", ASC);
-		gett("");
-		if (ret == 7) {
-			p = replystr.rfind("ZZFI");
-			if (p != std::string::npos) {
-				for (i = 0; FLEX1500_CAT_AM[i] != NULL; i++)
-					if (replystr.find(FLEX1500_CAT_AM[i]) == p)
-						break;
-				A.iBW = i;
+			for (i = 0; tbl[i] != NULL; i++)
+				if (replystr.find(tbl[i]) != std::string::npos) {
+					bw = i;
+					break;
 			}
 		}
 	}
-	vfoA.iBW = A.iBW;
+	return bw;
+}
+
+int RIG_FLEX1500::get_bwA()
+{
+	vfoA.iBW = A.iBW = get_bw(A.imode);
 	progStatus.iBW_A = A.iBW;
 	return A.iBW;
 }
@@ -747,11 +719,7 @@ void RIG_FLEX1500::set_bwB(int val)
 
 int RIG_FLEX1500::get_bwB() // same as A
 {
-	B.iBW =  get_bwA();
-	std::stringstream str;
-	str << "B.iBW = " << B.iBW;
-	trace(2, __func__, str.str().c_str());
-	vfoB.iBW = B.iBW;
+	vfoB.iBW = B.iBW = get_bw(B.imode);
 	progStatus.iBW_B = B.iBW;
 	return B.iBW;
 }
