@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <stdlib.h>
@@ -46,24 +46,27 @@ RIG_RAY152::RIG_RAY152() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR1200;
+	serial_baudrate = BR1200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 10;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	A.freq = 14070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	A.freq = 14070000ULL;
 	A.imode = 0;
 	A.iBW = 0;
 
-	B.freq = 3580000;
+	B.freq = 3580000ULL;
 	B.imode = 0;
 	B.iBW = 0;
 
@@ -197,12 +200,12 @@ void RIG_RAY152::shutdown()
 LOG_INFO("%s", cmd.c_str());
 }
 
-unsigned long int RIG_RAY152::get_vfoA ()
+unsigned long long RIG_RAY152::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_RAY152::set_vfoA (unsigned long int freq)
+void RIG_RAY152::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = "FT000000\r";
@@ -220,12 +223,12 @@ LOG_INFO("%s", cmd.c_str());
 LOG_INFO("%s", cmd.c_str());
 }
 
-unsigned long int RIG_RAY152::get_vfoB ()
+unsigned long long RIG_RAY152::get_vfoB ()
 {
 	return B.freq;
 }
 
-void RIG_RAY152::set_vfoB (unsigned long int freq)
+void RIG_RAY152::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = "FT000000\r";
