@@ -15,18 +15,14 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "other/tcisdr.h"
 #include "support.h"
 
-static const char SDR2_PROname_[] = "TciSDR";
-
-enum TCI_MODES {
-TCI_AM, TCI_SAM, TCI_DSB, TCI_LSB, TCI_USB,
-TCI_CW, TCI_NFM, TCI_DIGL, TCI_DIGU, TCI_WFM,
-TCI_DRM };
+static const char TCI_SUNDX_name_[] = "SunSDR2-DX/TCI";
+static const char TCI_SUNPRO_name_[] = "SunSDR2-Pro/TCI";
 
 static const char *TCI_modes[] = {
 "AM", "SAM", "DSB", "LSB", "USB", "CW", "NFM", "DIGL", "DIGU", "WFM", "DRM", NULL };
@@ -150,6 +146,7 @@ void tci_adjust_widths()
 	int  tci_freq;
 
 	if (tci_center != progStatus.tci_center) {
+		tci_center = progStatus.tci_center;
 		tci_freq = tci_centers[tci_center];
 
 		for (int i = 0; i < tci_nbr_usb; i++ ) {
@@ -239,7 +236,7 @@ bool RIG_TCI_SDR::check()
 
 RIG_TCI_SDR::RIG_TCI_SDR() {
 // base class values
-	name_ = SDR2_PROname_;
+	name_ = TCI_SUNDX_name_;
 	modes_ = TCI_modes;
 	_mode_type = TCI_mode_type;
 	bandwidths_ = TCI_USBwidths;
@@ -249,23 +246,26 @@ RIG_TCI_SDR::RIG_TCI_SDR() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR115200;
+	serial_baudrate = BR115200;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	A.freq  =  7070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	A.freq  =  7070000ULL;
 	A.imode = TCI_CW;
 	A.iBW   = 6;
 
-	B.freq  = 14070000;
+	B.freq  = 14070000ULL;
 	B.imode = TCI_USB;
 	B.iBW   = 10;
 
@@ -301,6 +301,7 @@ RIG_TCI_SDR::RIG_TCI_SDR() {
 	_nrval2 = 4;
 	preamp_level = atten_level = 0;
 
+	sdrtype = UNK;
 }
 
 const char * RIG_TCI_SDR::get_bwname_(int n, int md)
@@ -481,8 +482,14 @@ void RIG_TCI_SDR::set_bwA(int val)
 
 	tcicmd.append(pairs);
 	A.iBW = val;
+	slice_0.A.bw = pairs;
 
 	tci_send(tcicmd);
+
+	FilterInner_A = atoi(pairs.c_str());
+	size_t pos = pairs.find(",");
+	if (pos != std::string::npos) pairs.erase(0,pos);
+	FilterOuter_A = atoi(pairs.c_str());
 }
 
 int RIG_TCI_SDR::get_bwA()
@@ -510,6 +517,13 @@ int RIG_TCI_SDR::get_bwA()
 		n++;
 	}
 	if (!tbl[n].empty()) A.iBW = n;
+
+	FilterInner_A = atoi(sbw.c_str());
+	size_t pos = sbw.find(",");
+	if (pos != std::string::npos) {
+		sbw.erase(0, pos + 1);
+		FilterOuter_A = atoi(sbw.c_str());
+	}
 	return A.iBW;
 }
 
@@ -534,7 +548,13 @@ void RIG_TCI_SDR::set_bwB(int val)
 	}
 	tcicmd.append(pairs);
 	B.iBW = val;
+	slice_0.B.bw = pairs;
 	tci_send(tcicmd);
+
+	FilterInner_B = atoi(pairs.c_str());
+	size_t pos = pairs.find(",");
+	if (pos != std::string::npos) pairs.erase(0,pos);
+	FilterOuter_B = atoi(pairs.c_str());
 }
 
 int RIG_TCI_SDR::get_bwB()
@@ -562,6 +582,12 @@ int RIG_TCI_SDR::get_bwB()
 		n++;
 	}
 	if (!tbl[n].empty()) B.iBW = n;
+
+	FilterInner_B = atoi(sbw.c_str());
+	size_t pos = sbw.find(",");
+	if (pos != std::string::npos) sbw.erase(0,pos + 1);
+	FilterOuter_B = atoi(sbw.c_str());
+
 	return B.iBW;
 }
 
@@ -590,6 +616,30 @@ int RIG_TCI_SDR::adjust_bandwidth(int val)
 	return def_bandwidth(val);
 }
 
+void RIG_TCI_SDR::set_pbt(int inner, int outer)
+{
+	char cmdstr[50];
+	snprintf(cmdstr, sizeof(cmdstr), "rx_filter_band:%c,%d,%d;",
+		onA ? '0' : '1', inner, outer);
+	tci_send(cmdstr);
+}
+
+int RIG_TCI_SDR::get_pbt_inner()
+{
+	if (onA)
+		return FilterInner_A;
+	else
+		return FilterInner_B;
+}
+
+int RIG_TCI_SDR::get_pbt_outer()
+{
+	if (onA)
+		return FilterOuter_A;
+	else
+		return FilterOuter_B;
+}
+
 void RIG_TCI_SDR::set_attenuator(int val)
 {
 }
@@ -668,7 +718,7 @@ void RIG_TCI_SDR::set_PTT_control(int val)
 	} else
 		tcicmd = "TRX:0,false;";
 	tci_send(tcicmd);
-	ptt_ = val;
+	ptt_ = slice_0.ptt = val;
 }
 
 int RIG_TCI_SDR::get_PTT()
@@ -691,15 +741,15 @@ void RIG_TCI_SDR::get_rf_min_max_step(int &min, int &max, int &step)
 	min = 0; max = 100; step = 1;
 }
 
-//void RIG_TCI_SDR::selectA()
-//{
-//	inuse = onA;
-//}
+void RIG_TCI_SDR::selectA()
+{
+	inuse = onA;
+}
 
-//void RIG_TCI_SDR::selectB()
-//{
-//	inuse = onB;
-//}
+void RIG_TCI_SDR::selectB()
+{
+	inuse = onB;
+}
 
 void RIG_TCI_SDR::set_split(bool val)
 {
@@ -719,31 +769,31 @@ int RIG_TCI_SDR::get_split()
 	return slice_0.split;
 }
 
-unsigned long int RIG_TCI_SDR::get_vfoA ()
+unsigned long long RIG_TCI_SDR::get_vfoA ()
 {
 	A.freq = slice_0.A.freq;
 	return A.freq;
 }
 
-void RIG_TCI_SDR::set_vfoA (unsigned long int freq)
+void RIG_TCI_SDR::set_vfoA (unsigned long long freq)
 {
-	A.freq = freq;
+	A.freq = slice_0.A.freq = freq;
 	char vfostr[20];
-	snprintf(vfostr, sizeof(vfostr), "vfo:0,0,%ld;", freq);
+	snprintf(vfostr, sizeof(vfostr), "vfo:0,0,%llu;", freq);
 	tci_send(vfostr);
 }
 
-unsigned long int RIG_TCI_SDR::get_vfoB ()
+unsigned long long RIG_TCI_SDR::get_vfoB ()
 {
 	B.freq = slice_0.B.freq;
 	return B.freq;
 }
 
-void RIG_TCI_SDR::set_vfoB (unsigned long int freq)
+void RIG_TCI_SDR::set_vfoB (unsigned long long freq)
 {
-	B.freq = freq;
+	B.freq = slice_0.B.freq = freq;
 	char vfostr[20];
-	snprintf(vfostr, sizeof(vfostr), "vfo:0,1,%ld;", freq);
+	snprintf(vfostr, sizeof(vfostr), "vfo:0,1,%llu;", freq);
 	tci_send(vfostr);
 }
 
@@ -790,12 +840,18 @@ void RIG_TCI_SDR::get_mic_min_max_step(int &min, int &max, int &step)
 }
 */
 
+void RIG_TCI_SDR::set_volume_min_max_step(double &min, double &max, double &step)
+{
+	min = -60; max = 0; step = 1; // in dBm
+}
+
 void RIG_TCI_SDR::set_volume_control(int val)
 {
 	char szcmd[20];
 	val = ((val * 60)/100) - 60;
 	snprintf(szcmd, sizeof(szcmd), "volume:%d;", val);
 	tci_send(szcmd);
+	slice_0.vol = val;
 }
 
 int RIG_TCI_SDR::get_volume_control()
@@ -804,17 +860,30 @@ int RIG_TCI_SDR::get_volume_control()
 	return vol;
 }
 
+void RIG_TCI_SDR::get_pc_min_max_step(double &min, double &max, double &step)
+{
+	if (sdrtype == DX) {
+		min = 0; max = 100; step = 1; 
+	} else {
+		min = 0; max = 20; step = 0.1; 
+	}
+}
+
 void RIG_TCI_SDR::set_power_control(double val)
 {
 	char szcmd[20];
-	snprintf(szcmd, sizeof(szcmd), "drive:%d;", (int)(val * 5));
+	if (sdrtype == PRO)
+		val *= 5;
+	snprintf(szcmd, sizeof(szcmd), "drive:%d;", (int)(val));
 	tci_send(szcmd);
+	slice_0.pwr = val;
 }
 
 double RIG_TCI_SDR::get_power_control()
 {
 	double pwr = slice_0.pwr;
-	return pwr / 5.0;
+	if (sdrtype == PRO) pwr *= 0.2;
+	return pwr;
 }
 
 static bool tune_on = false;
@@ -827,3 +896,19 @@ void RIG_TCI_SDR::tune_rig()
 	tci_send(szcmd);
 }
 
+//======================================================================
+
+RIG_TCI_SUNPRO::RIG_TCI_SUNPRO() {
+	sdrtype = PRO;
+	name_ = TCI_SUNPRO_name_;
+};
+
+//======================================================================
+
+RIG_TCI_SUNDX::RIG_TCI_SUNDX() {
+	sdrtype = DX;
+	name_ = TCI_SUNDX_name_;
+};
+
+
+
