@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -27,6 +27,7 @@
 #include "support.h"
 #include "socket_io.h"
 #include "tod_clock.h"
+#include "serial.h"
 
 #include "rigs.h"
 
@@ -59,16 +60,19 @@ rigbase::rigbase()
 
 	widgets = basewidgets;
 
-	serloop_timing = 200; // msec, 5x / second
-
 	stopbits = 2;
 
+	serial_write_delay = 0;
+	serial_post_write_delay = 0;
+
+	serloop_timing = 200; // msec, 5x / second
+
 	CIV = 0;
 	defaultCIV = 0;
 	USBaudio = false;
 
 	has_xcvr_auto_on_off =
-	comm_echo =
+	serial_echo =
 	has_vfo_adj =
 	has_rit =
 	has_xit =
@@ -141,25 +145,27 @@ rigbase::rigbase()
 
 	data_type = DT_BINARY;
 
-	A.freq = 14070000L;
+	A.freq = 14070000ULL;
 	A.imode = 1;
 	A.iBW = 0;
-	B.freq = 14070000L;
+	A.bw_val = 800;
+	B.freq = 14070000ULL;
 	B.imode = 1;
 	B.iBW = 0;
+	B.bw_val = 800;
 	inuse = onA;
 	precision = 1;
-	ndigits = 9;
+	ndigits = 10;
 	can_change_alt_vfo = false;
 
-	freqA = 14070000L;
+	freqA = 14070000ULL;
 	modeA = 1;
 	bwA = 0;
-	freqB = 14070000L;
+	freqB = 14070000ULL;
 	modeB = 1;
 	bwB = 0;
 
-	def_freq = 14070000L;
+	def_freq = 14070000ULL;
 	def_mode = 1;
 	def_bw = 0;
 	bpf_center = 0;
@@ -182,7 +188,7 @@ rigbase::rigbase()
 	preamp_level = 0;
 }
 
-std::string rigbase::to_bcd_be(unsigned long int freq, int len)
+std::string rigbase::to_bcd_be(unsigned long long val, int len)
 {
 	unsigned char a;
 	int numchars = len / 2;
@@ -190,18 +196,18 @@ std::string rigbase::to_bcd_be(unsigned long int freq, int len)
 	if (len & 1) numchars ++;
 	for (int i = 0; i < numchars; i++) {
 		a = 0;
-		a |= freq % 10;
-		freq /= 10;
-		a |= (freq % 10)<<4;
-		freq /= 10;
+		a |= val % 10;
+		val /= 10;
+		a |= (val % 10)<<4;
+		val /= 10;
 		bcd += a;
 	}
 	return bcd;
 }
 
-std::string rigbase::to_bcd(unsigned long int freq, int len)
+std::string rigbase::to_bcd(unsigned long long val, int len)
 {
-	std::string bcd_be = to_bcd_be(freq, len);
+	std::string bcd_be = to_bcd_be(val, len);
 	std::string bcd = "";
 	int bcdlen = bcd_be.size();
 	for (int i = bcdlen - 1; i >= 0; i--)
@@ -209,10 +215,10 @@ std::string rigbase::to_bcd(unsigned long int freq, int len)
 	return bcd;
 }
 
-unsigned long int rigbase::fm_bcd (std::string bcd, int len)
+unsigned long long rigbase::fm_bcd (std::string bcd, int len)
 {
 	int i;
-	unsigned long int f = 0;
+	unsigned long long f = 0;
 	int numchars = len/2;
 	if (len & 1) numchars ++;
 	for (i = 0; i < numchars; i++) {
@@ -225,7 +231,7 @@ unsigned long int rigbase::fm_bcd (std::string bcd, int len)
 }
 
 
-unsigned long int rigbase::fm_bcd_be(std::string bcd, int len)
+unsigned long long rigbase::fm_bcd_be(std::string bcd, int len)
 {
 	char temp;
 	int numchars = len/2;
@@ -238,30 +244,30 @@ unsigned long int rigbase::fm_bcd_be(std::string bcd, int len)
 	return fm_bcd(bcd, len);
 }
 
-std::string rigbase::to_binary_be(unsigned long int freq, int len)
+std::string rigbase::to_binary_be(unsigned long long val, int len)
 {
 	static std::string bin = "";
 	for (int i = 0; i < len; i++) {
-		bin += freq & 0xFF;
-		freq >>= 8;
+		bin += val & 0xFF;
+		val >>= 8;
 	}
 	return bin;
 }
 
-std::string rigbase::to_binary(unsigned long int freq, int len)
+std::string rigbase::to_binary(unsigned long long val, int len)
 {
 	static std::string bin = "";
-	std::string bin_be = to_binary_be(freq, len);
+	std::string bin_be = to_binary_be(val, len);
 	int binlen = bin_be.size();
 	for (int i = binlen - 1; i >= 0; i--)
 		bin += bin_be[i];
 	return bin;
 }
 
-unsigned long int rigbase::fm_binary(std::string binary, int len)
+unsigned long long rigbase::fm_binary(std::string binary, int len)
 {
 	int i;
-	unsigned long int f = 0;
+	unsigned long long f = 0;
 	for (i = 0; i < len; i++) {
 		f *= 256;
 		f += (unsigned char)binary[i];
@@ -269,7 +275,7 @@ unsigned long int rigbase::fm_binary(std::string binary, int len)
 	return f;
 }
 
-unsigned long int rigbase::fm_binary_be(std::string binary_be, int len)
+unsigned long long rigbase::fm_binary_be(std::string binary_be, int len)
 {
 	unsigned char temp;
 	int numchars = len/2;
@@ -282,7 +288,7 @@ unsigned long int rigbase::fm_binary_be(std::string binary_be, int len)
 	return fm_binary(binary_be, len);
 }
 
-std::string rigbase::to_decimal_be(unsigned long int d, int len)
+std::string rigbase::to_decimal_be(unsigned long long d, int len)
 {
 	static std::string sdec_be;
 	sdec_be.clear();
@@ -293,7 +299,7 @@ std::string rigbase::to_decimal_be(unsigned long int d, int len)
 	return sdec_be;
 }
 
-std::string rigbase::to_decimal(unsigned long int d, int len)
+std::string rigbase::to_decimal(unsigned long long d, int len)
 {
 	static std::string sdec;
 	sdec.clear();
@@ -304,9 +310,9 @@ std::string rigbase::to_decimal(unsigned long int d, int len)
 	return sdec;
 }
 
-unsigned long int rigbase::fm_decimal(std::string decimal, int len)
+unsigned long long rigbase::fm_decimal(std::string decimal, int len)
 {
-	unsigned long int d = 0;
+	unsigned long long d = 0;
 	for (int i = 0; i < len; i++) {
 		d *= 10;
 		d += decimal[i] - '0';
@@ -314,7 +320,7 @@ unsigned long int rigbase::fm_decimal(std::string decimal, int len)
 	return d;
 }
 
-unsigned long int rigbase::fm_decimal_be(std::string decimal_be, int len)
+unsigned long long rigbase::fm_decimal_be(std::string decimal_be, int len)
 {
 	unsigned char temp;
 	int numchars = len/2;
@@ -375,29 +381,23 @@ int rigbase::hex2val(std::string hexstr)
 
 //======================================================================
 
-int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
+int rigbase::waitN(int n, int timeout, const char *sz, int pr)
 {
 	guard_lock reply_lock(&mutex_replystr);
 
-	int delay =  (n + cmd.length()) * 11000.0 / RigSerial->Baud();
 	int retnbr = 0;
 
 	replystr.clear();
 
 	if (progStatus.use_tcpip) {
-		send_to_remote(cmd, progStatus.byte_interval);
-		MilliSleep(delay + progStatus.tcpip_ping_delay);
+		send_to_remote(cmd);
+		MilliSleep(progStatus.tcpip_ping_delay);
 		retnbr = read_from_remote(replystr);
-		LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr, 
+		LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr,
 			(pr == HEX ? str2hex(replystr.c_str(), replystr.length()): replystr.c_str()));
 		return retnbr;
 	}
 
-	if (this->name_ == rig_FT817.name_ ||
-		this->name_ == rig_FT817BB.name_ ||
-		this->name_ == rig_FT818ND.name_ )
-		delay += progStatus.comm_wait;
-
 	if(!RigSerial->IsOpen()) {
 		LOG_DEBUG("TEST %s", sz);
 		return 0;
@@ -407,34 +407,56 @@ int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 
 	RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
-	MilliSleep(delay);
+	size_t tstart = zmsec();
+	size_t tout = tstart + progStatus.serial_timeout; // minimum of 100 msec
+	std::string tempstr;
+	int nret;
 
-	retnbr = RigSerial->ReadBuffer(replystr, n);
+	do {
+		tempstr.clear();
+		nret = RigSerial->ReadBuffer(tempstr, n - retnbr);
+		if (nret) {
+			for (int nc = 0; nc < nret; nc++)
+				replystr += tempstr[nc];
+			retnbr += nret;
+			tout = zmsec() + progStatus.serial_timeout;
+		}
+		if (retnbr >= n)
+			break;
+		MilliSleep(1);
+	} while  ( zmsec() < tout );
+
+	static char ctrace[1000];
+	memset(ctrace, 0, 1000);
+	snprintf( ctrace, sizeof(ctrace), "%s: read %d bytes in %d msec, %s",
+		sz, retnbr,
+		(int)(zmsec() - tstart),
+		(pr == HEX ? str2hex(replystr.c_str(), replystr.length()): replystr.c_str()) );
+
+	if (SERIALDEBUG)
+		ser_trace(1, ctrace);
 
-	LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr,
-			(pr == HEX ? str2hex(replystr.c_str(), replystr.length()): replystr.c_str()));
 	return retnbr;
 
 }
 
-int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
+int rigbase::wait_char(int ch, int n, int timeout, const char *sz, int pr)
 {
 	guard_lock reply_lock(&mutex_replystr);
 
 	std::string wait_str = " ";
 	wait_str[0] = ch;
 
-	int delay =  (n + cmd.length()) * 11000.0 / RigSerial->Baud();
 	int retnbr = 0;
 
 	replystr.clear();
 
 	if (progStatus.use_tcpip) {
-		send_to_remote(cmd, progStatus.byte_interval);
-		MilliSleep(delay + progStatus.tcpip_ping_delay);
+		send_to_remote(cmd);
+		MilliSleep(progStatus.tcpip_ping_delay);
 		retnbr = read_from_remote(replystr);
 		LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr, replystr.c_str());
-		return retnbr;
+		return (int)retnbr;
 	}
 
 	if(!RigSerial->IsOpen()) {
@@ -446,30 +468,111 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 
 	RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
-	if (this->name_ == rig_TT566.name_) delay += progStatus.comm_wait;
-
-	MilliSleep(delay);
-
-	size_t tout1 = zmsec();//todmsec();
-	size_t tout2 = tout1;
-	size_t test = timeout;
+	size_t tstart = zmsec();
+	size_t tout = tstart + progStatus.serial_timeout;
 	std::string tempstr;
 	int nret;
 
-	while ( (tout2 - tout1) < test) {
+	do  {
 		tempstr.clear();
 		nret = RigSerial->ReadBuffer(tempstr, n - retnbr, wait_str);
-		replystr.append(tempstr);
-		retnbr += nret;
-
-		tout2 = zmsec();//todmsec();
-		if (tout2 < tout1) tout1 = tout2;
+		if (nret) {
+			for (int nc = 0; nc < nret; nc++)
+				replystr += tempstr[nc];
+			retnbr += nret;
+			tout = zmsec() + progStatus.serial_timeout;
+		}
+		if (retnbr >= n)
+			break;
 
 		if (replystr.find(wait_str) != std::string::npos)
 			break;
+
+		MilliSleep(1);
+	} while ( zmsec() < tout );
+
+	static char ctrace[1000];
+	memset(ctrace, 0, 1000);
+	snprintf( ctrace, sizeof(ctrace), "%s: read %d bytes in %d msec, %s",
+		sz, retnbr,
+		(int)(zmsec() - tstart),
+		(pr == HEX ? str2hex(replystr.c_str(), replystr.length()): replystr.c_str()) );
+
+	if (SERIALDEBUG)
+		ser_trace(1, ctrace);
+
+	LOG_DEBUG ("%s", ctrace);
+
+	return retnbr;
+}
+
+int rigbase::wait_crlf(std::string cmd, std::string sz, int nr, int timeout, int pr)
+{
+	guard_lock reply_lock(&mutex_replystr);
+
+	char crlf[3] = "\r\n";
+
+	int retnbr = 0;
+
+	replystr.clear();
+
+	if (progStatus.use_tcpip) {
+		send_to_remote(cmd);
+		MilliSleep(progStatus.tcpip_ping_delay);
+		retnbr = read_from_remote(replystr);
+		LOG_DEBUG ("%s: read %d bytes, %s", sz.c_str(), retnbr, replystr.c_str());
+		return retnbr;
 	}
 
-	LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr, replystr.c_str());
+	if(!RigSerial->IsOpen()) {
+		LOG_DEBUG("TEST %s", sz.c_str());
+		return 0;
+	}
+
+	RigSerial->FlushBuffer();
+
+	RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
+
+	size_t tstart = zmsec();
+	size_t tout = zmsec() + timeout + progStatus.serial_timeout;
+	std::string tempstr;
+	int nret;
+
+	do {
+		tempstr.clear();
+		nret = RigSerial->ReadBuffer(tempstr, nr - retnbr, crlf);
+		if (nret) {
+			replystr.append(tempstr);
+			retnbr += nret;
+			tout = zmsec() + timeout + progStatus.serial_timeout;
+		}
+
+		if (replystr.find(crlf) != std::string::npos)
+			break;
+
+		if (retnbr >= nr) break;
+
+		MilliSleep(1);
+	} while ( zmsec() < tout );
+
+	static char ctrace[1000];
+	memset(ctrace, 0, 1000);
+	std::string srx = replystr;
+	if (srx[0] == '\n') srx.replace(0,1,"<lf>");
+	size_t psrx = srx.find("\r\n");
+	if (psrx != std::string::npos)
+		srx.replace(psrx, 2, "<cr><lf>");
+
+	snprintf( ctrace, sizeof(ctrace), "%s: read %d bytes in %d msec, %s", 
+		sz.c_str(), retnbr,
+		(int)(zmsec() - tstart),
+		srx.c_str());
+
+	if (SERIALDEBUG)
+		ser_trace(1, ctrace);
+
+	LOG_DEBUG ("%s", ctrace);
+
 	return retnbr;
 }
 
@@ -484,27 +587,34 @@ bool rigbase::id_OK(std::string ID, int wait)
 {
 	guard_lock reply_lock(&mutex_replystr);
 
-//	int retnbr = 0;
-
-	for (int n = 0; n < progStatus.comm_retries; n++) {
+	std::string buff;
+	int retn = 0;
+	size_t tout = 0;
+	for (int n = 0; n < progStatus.serial_retries; n++) {
 
 		RigSerial->FlushBuffer();
 		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
-		MilliSleep(50);
 
-		for (int cnt = 0; cnt < wait / 10; cnt++) {
+		replystr.clear();
+		tout = zmsec() + wait;
 
-			replystr.clear();
-//			retnbr =
-			RigSerial->ReadBuffer(replystr, 10, ID, ";");
+		do {
+			MilliSleep(50);
+			buff.clear();
 
+			retn = RigSerial->ReadBuffer(buff, 10, ID, ";");
+			if (retn) {
+				replystr.append(buff);
+				tout = zmsec() + wait;
+			}
 			if (replystr.rfind(ID)) {
 				return true;
 			}
-			MilliSleep(10);
 			Fl::awake();
-		}
+
+		} while (zmsec() < tout);
 	}
+
 	replystr.clear();
 	return false;
 }
