@@ -72,6 +72,7 @@ RIG_IC728		rig_IC728;
 RIG_IC735		rig_IC735;
 RIG_IC746		rig_IC746;
 RIG_IC746PRO	rig_IC746PRO;
+RIG_IC751		rig_IC751;
 RIG_IC756		rig_IC756;
 RIG_IC756PRO	rig_IC756PRO;
 RIG_IC756PRO2	rig_IC756PRO2;
@@ -90,9 +91,11 @@ RIG_IC9100		rig_IC9100;
 RIG_IC9700		rig_IC9700;
 RIG_IC910H		rig_IC910H;
 RIG_ICF8101		rig_ICF8101;
+RIG_ICR71		rig_ICR71;
 RIG_K2			rig_K2;
 RIG_K3			rig_K3;
 RIG_KX3			rig_KX3;
+RIG_K4			rig_K4;
 RIG_PCR1000		rig_PCR1000;
 RIG_RAY152		rig_RAY152;
 RIG_TMD710		rig_TMD710;
@@ -128,7 +131,10 @@ RIG_FLEX1500	rig_FLEX1500;
 RIG_TX500		rig_TX500;
 RIG_QCXP		rig_QCXP;
 RIG_SDR2_PRO	rig_sdr2;
-RIG_TCI_SDR		rig_tcisdr;
+RIG_TCI_SUNDX	rig_tci_sundx;
+RIG_TCI_SUNPRO	rig_tci_sunpro;
+RIG_TRUSDX		rig_trusdx;
+RIG_QDX			rig_qdx;
 
 rigbase *rigs[] = {
 	&rig_null,		// 0
@@ -174,66 +180,72 @@ rigbase *rigs[] = {
 	&rig_IC735,		// 30
 	&rig_IC746,		// 41
 	&rig_IC746PRO,	// 42
-	&rig_IC756,		// 43
-	&rig_IC756PRO,	// 44
-	&rig_IC756PRO2,	// 45
-	&rig_IC756PRO3,	// 46
-	&rig_IC7000,	// 47
-	&rig_IC7100,	// 48
-	&rig_IC7200,	// 49
-	&rig_IC7300,	// 40
-	&rig_IC7410,	// 51
-	&rig_IC7600,	// 52
-	&rig_IC7610,	// 53
-	&rig_IC7700,	// 54
-	&rig_IC7800,	// 55
-	&rig_IC7851,	// 56
-	&rig_IC9100,	// 57
-	&rig_IC9700,	// 58
-	&rig_IC910H,	// 59
-	&rig_ICF8101,	// 50
-	&rig_K2,		// 61
-	&rig_K3,		// 62
-	&rig_KX3,		// 63
-	&rig_PCR1000,	// 64
-	&rig_RAY152,	// 65
-	&rig_TMD710,	// 66
-	&rig_TS140,		// 67
-	&rig_TS440,		// 68
-	&rig_TS450S,	// 69
-	&rig_TS480HX,	// 60
-	&rig_TS480SAT,	// 71
-	&rig_TS570,		// 72
-	&rig_TS590S,	// 73
-	&rig_TS590SG,	// 74
-	&rig_TS790,		// 75
-	&rig_TS850,		// 76
-	&rig_TS870S,	// 77
-	&rig_TS890S,	// 78
-	&rig_TS940S,	// 79
-	&rig_TS950,		// 70
-	&rig_TS990,		// 81
-	&rig_TS2000,	// 82
-	&rig_TT516,		// 83
-	&rig_TT535,		// 84
-	&rig_TT538,		// 85
-	&rig_TT550,		// 86
-	&rig_TT563,		// 87
-	&rig_TT566,		// 88
-	&rig_TT588,		// 89
-	&rig_TT599,		// 80
-	&rig_AOR5K,		// 91
-	&rig_XI5105,	// 92
-	&rig_XIG90,		// 93
-	&rig_X6100,		// 94
-	&rig_PowerSDR,	// 95
-	&rig_FLEX1500,	// 96
-	&rig_TX500,		// 97
-	&rig_QCXP,		// 98
-	&rig_sdr2,		// 99
-	&rig_tcisdr,	// 100
-
+	&rig_IC751,		// 43
+	&rig_IC756,		// 44
+	&rig_IC756PRO,	// 45
+	&rig_IC756PRO2,	// 46
+	&rig_IC756PRO3,	// 47
+	&rig_IC7000,	// 48
+	&rig_IC7100,	// 49
+	&rig_IC7200,	// 50
+	&rig_IC7300,	// 51
+	&rig_IC7410,	// 52
+	&rig_IC7600,	// 53
+	&rig_IC7610,	// 54
+	&rig_IC7700,	// 55
+	&rig_IC7800,	// 56
+	&rig_IC7851,	// 57
+	&rig_IC9100,	// 58
+	&rig_IC9700,	// 59
+	&rig_IC910H,	// 60
+	&rig_ICF8101,	// 61
+	&rig_ICR71,		// 62
+	&rig_K2,		// 63
+	&rig_K3,		// 64
+	&rig_KX3,		// 65
+	&rig_K4,		// 66
+	&rig_PCR1000,	// 67
+	&rig_RAY152,	// 68
+	&rig_TMD710,	// 69
+	&rig_TS140,		// 70
+	&rig_TS440,		// 79
+	&rig_TS450S,	// 70
+	&rig_TS480HX,	// 71
+	&rig_TS480SAT,	// 72
+	&rig_TS570,		// 73
+	&rig_TS590S,	// 74
+	&rig_TS590SG,	// 75
+	&rig_TS790,		// 76
+	&rig_TS850,		// 77
+	&rig_TS870S,	// 78
+	&rig_TS890S,	// 79
+	&rig_TS940S,	// 80
+	&rig_TS950,		// 81
+	&rig_TS990,		// 82
+	&rig_TS2000,	// 83
+	&rig_TT516,		// 84
+	&rig_TT535,		// 85
+	&rig_TT538,		// 86
+	&rig_TT550,		// 87
+	&rig_TT563,		// 88
+	&rig_TT566,		// 89
+	&rig_TT588,		// 90
+	&rig_TT599,		// 91
+	&rig_AOR5K,		// 92
+	&rig_XI5105,	// 93
+	&rig_XIG90,		// 94
+	&rig_X6100,		// 95
+	&rig_PowerSDR,	// 96
+	&rig_FLEX1500,	// 97
+	&rig_TX500,		// 98
+	&rig_QCXP,		// 99
+	&rig_sdr2,		// 100
+	&rig_tci_sundx,	// 101
+	&rig_tci_sunpro,// 102
+	&rig_trusdx,	// 103
+	&rig_qdx,		// 104
 	NULL
+
 };
 
 //=============================================================================
