@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 /*
@@ -120,22 +120,25 @@ RIG_TT538::RIG_TT538() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR57600;
+	serial_baudrate = BR57600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 20;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;// false;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;// false;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	serloop_timing = 200;
 
 	def_mode = modeB = modeA = 1;
 	def_bw = bwB = bwA = 25;
-	def_freq = freqB = freqA = 14070000;
+	def_freq = freqB = freqA = 14070000ULL;
 
 	max_power = 100;
 	pbt = 0;
@@ -205,28 +208,28 @@ bool RIG_TT538::check ()
 	return true;
 }
 
-unsigned long int RIG_TT538::get_vfoA ()
+unsigned long long RIG_TT538::get_vfoA ()
 {
 	cmd = TT538getFREQA;
 	int ret = sendCommand(cmd);
 	gTT("get vfoA");
 
-	if (ret < 6) return (unsigned long int)(freqA / (1 + VfoAdj/1e6) + 0.5);
+	if (ret < 6) return (unsigned long long)(freqA / (1 + VfoAdj/1e6) + 0.5);
 	size_t p = replystr.rfind("A");
-	if (p == std::string::npos) return (unsigned long int)(freqA / (1 + VfoAdj/1e6) + 0.5);
+	if (p == std::string::npos) return (unsigned long long)(freqA / (1 + VfoAdj/1e6) + 0.5);
 	
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 1; n < 5; n++)
 		f = f*256 + (unsigned char)replystr[p + n];
 	freqA = f;
 
-	return (unsigned long int)(freqA / (1 + VfoAdj/1e6) + 0.5);
+	return (unsigned long long)(freqA / (1 + VfoAdj/1e6) + 0.5);
 }
 
-void RIG_TT538::set_vfoA (unsigned long int freq)
+void RIG_TT538::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
-	unsigned long int xfreq = freqA * (1 + VfoAdj/1e6) + 0.5;
+	unsigned long long xfreq = freqA * (1 + VfoAdj/1e6) + 0.5;
 	cmd = TT538setFREQA;
 	cmd[5] = xfreq & 0xff; xfreq = xfreq >> 8;
 	cmd[4] = xfreq & 0xff; xfreq = xfreq >> 8;
@@ -239,29 +242,29 @@ void RIG_TT538::set_vfoA (unsigned long int freq)
 	return ;
 }
 
-unsigned long int RIG_TT538::get_vfoB ()
+unsigned long long RIG_TT538::get_vfoB ()
 {
 //	cmd = TT538getFREQB;
 	cmd = TT538getFREQA;
 	int ret = sendCommand(cmd);
 	gTT("get vfoB");
 
-	if (ret < 6) return (unsigned long int)(freqB / (1 + VfoAdj/1e6) + 0.5);
+	if (ret < 6) return (unsigned long long)(freqB / (1 + VfoAdj/1e6) + 0.5);
 	size_t p = replystr.rfind("B");
-	if (p == std::string::npos) return (unsigned long int)(freqB / (1 + VfoAdj/1e6) + 0.5);
+	if (p == std::string::npos) return (unsigned long long)(freqB / (1 + VfoAdj/1e6) + 0.5);
 
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 1; n < 5; n++)
 		f = f*256 + (unsigned char)replystr[p + n];
 	freqB = f;
 
-	return (unsigned long int)(freqB / (1 + VfoAdj/1e6) + 0.5);
+	return (unsigned long long)(freqB / (1 + VfoAdj/1e6) + 0.5);
 }
 
-void RIG_TT538::set_vfoB (unsigned long int freq)
+void RIG_TT538::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
-	unsigned long int xfreq = freqB * (1 + VfoAdj/1e6) + 0.5;
+	unsigned long long xfreq = freqB * (1 + VfoAdj/1e6) + 0.5;
 //	cmd = TT538setFREQB;
 	cmd = TT538setFREQA;
 	cmd[5] = xfreq & 0xff; xfreq = xfreq >> 8;
