@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "tentec/TT563.h"
@@ -37,24 +37,27 @@ RIG_TT563::RIG_TT563() {
 	bandwidths_ = RIG_TT563widths;
 	bw_vals_ = TT563_bw_vals;
 
-	comm_baudrate = BR9600;
+	serial_baudrate = BR9600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 10;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
 
-	def_freq = A.freq = 14070000;
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 1;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 1;
 
@@ -153,7 +156,7 @@ bool RIG_TT563::check ()
 	return ok;
 }
 
-unsigned long int RIG_TT563::get_vfoA ()
+unsigned long long RIG_TT563::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -170,7 +173,7 @@ unsigned long int RIG_TT563::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_TT563::set_vfoA (unsigned long int freq)
+void RIG_TT563::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -181,7 +184,7 @@ void RIG_TT563::set_vfoA (unsigned long int freq)
 	waitFB("set vfo A");
 }
 
-unsigned long int RIG_TT563::get_vfoB ()
+unsigned long long RIG_TT563::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -198,7 +201,7 @@ unsigned long int RIG_TT563::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_TT563::set_vfoB (unsigned long int freq)
+void RIG_TT563::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
