@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "tentec/TT566.h"
@@ -192,21 +192,24 @@ RIG_TT566::RIG_TT566() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR57600;
+	serial_baudrate = BR57600;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 10;
-	comm_timeout = 50;
-	comm_echo = true;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_echo = true;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	def_mode = modeB = modeA = A.imode = B.imode = 1;
 	def_bw = bwB = bwA = A.iBW = B.iBW = 19;
-	def_freq = freqB = freqA = A.freq = B.freq = 14070000;
+	def_freq = freqB = freqA = A.freq = B.freq = 14070000ULL;
 
 	max_power = 100;
 	atten_level = 0;
@@ -268,7 +271,7 @@ bool RIG_TT566::check ()
 	return true;
 }
 
-unsigned long int RIG_TT566::get_vfoA ()
+unsigned long long RIG_TT566::get_vfoA ()
 {
 	cmd = TT566getFREQa; 
 //	replystr = "@AF14070050\r";
@@ -278,13 +281,13 @@ unsigned long int RIG_TT566::get_vfoA ()
 	size_t p = replystr.rfind(TT566rspFREQa);
 	if (p == std::string::npos) return A.freq;
 
-	int f = 0;
-	sscanf(&replystr[p + strlen(TT566rspFREQa)], "%d", &f);
+	unsigned long long f = 0;
+	sscanf(&replystr[p + strlen(TT566rspFREQa)], "%llu", &f);
 	A.freq = f;
 	return A.freq;
 }
 
-void RIG_TT566::set_vfoA (unsigned long int freq)
+void RIG_TT566::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = TT566setFREQa;
@@ -295,7 +298,7 @@ void RIG_TT566::set_vfoA (unsigned long int freq)
 	return;
 }
 
-unsigned long int RIG_TT566::get_vfoB ()
+unsigned long long RIG_TT566::get_vfoB ()
 {
 	cmd = TT566getFREQb;
 //	replystr = "@BF7070000\r";
@@ -305,13 +308,13 @@ unsigned long int RIG_TT566::get_vfoB ()
 	size_t p = replystr.rfind(TT566rspFREQb);
 	if (p == std::string::npos) return B.freq;
 
-	int f = 0;
-	sscanf(&replystr[p + strlen(TT566rspFREQb)], "%d", &f);
+	unsigned long long f = 0;
+	sscanf(&replystr[p + strlen(TT566rspFREQb)], "%llu", &f);
 	B.freq = f;
 	return B.freq;
 }
 
-void RIG_TT566::set_vfoB (unsigned long int freq)
+void RIG_TT566::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = TT566setFREQb;
@@ -701,13 +704,7 @@ void RIG_TT566::set_attenuator(int val)
 {
 	atten_level = val;
 	cmd = TT566setATTa;
-
-	switch (atten_level) {
-		case 0: atten_label("0 dB", false); cmd += '0'; break;
-		case 1: atten_label("6 dB", true); 	cmd += '1'; break;
-		case 2: atten_label("12 dB", true); cmd += '2'; break;
-		case 3: atten_label("18 dB", true); cmd += '3'; break;
-	}
+	cmd += (atten_level + '0');
 	cmd += '\r';
 	sendCommand(cmd);
 	setcr("set attenuator");
@@ -728,12 +725,6 @@ int RIG_TT566::get_attenuator()
 	val = (replystr[p + strlen(TT566rspATTa)] - '0');
 
 	if (atten_level != val) atten_level = val;
-	switch (atten_level) {
-		case 0: atten_label("0 dB", false); break;
-		case 1: atten_label("6 dB", true); break;
-		case 2: atten_label("12 dB", true); break;
-		case 3: atten_label("18 dB", true); break;
-	}
 	return atten_level;
 }
 
@@ -757,6 +748,21 @@ int RIG_TT566::get_preamp()
 	return replystr[p + strlen(TT566rspPREAMP)] - '0';
 }
 
+const char *RIG_TT566::PRE_label()
+{
+	if (preamp_level == 1) return "Pr ON";
+	return "Pre";
+}
+
+const char *RIG_TT566::ATT_label()
+{
+	if (atten_level == 0) return "0 dB";
+	if (atten_level == 1) return "6 dB";
+	if (atten_level == 2) return "12 dB";
+	if (atten_level == 3) return "18 dB";
+	return "ATT";
+}
+
 void RIG_TT566::set_noise(bool val)
 {
 	cmd = TT566setNBa;
