@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "xiegu/Xiegu-G90.h"
@@ -124,16 +124,19 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	_mode_type = Xiegu_G90_mode_type;
 	adjustCIV(defaultCIV);
 
-	comm_retries = 2;
-	comm_wait = 20;
-	comm_timeout = 50;
-	comm_echo = false;
-	comm_rtscts = false;
-	comm_rtsplus = true;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+//	serial_write_delay = 0;
+//	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_echo = false;
+	serial_rtscts = false;
+	serial_rtsplus = true;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	widgets = Xiegu_G90_widgets;
 
@@ -141,11 +144,11 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	ndigits = 9;
 	A.filter = B.filter = 1;
 
-	def_freq = A.freq = 14070000;
+	def_freq = A.freq = 14070000ULL;
 	def_mode = A.imode = 1;
 	def_bw = A.iBW = 0;
 
-	B.freq = 7070000;
+	B.freq = 7070000ULL;
 	B.imode = 1;
 	B.iBW = 0;
 
@@ -239,7 +242,7 @@ void RIG_Xiegu_G90::selectB()
 	inuse = onB;
 }
 
-unsigned long int RIG_Xiegu_G90::get_vfoA ()
+unsigned long long RIG_Xiegu_G90::get_vfoA ()
 {
 	if (inuse == onB) return A.freq;
 	std::string resp = pre_fm;
@@ -261,7 +264,7 @@ unsigned long int RIG_Xiegu_G90::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_Xiegu_G90::set_vfoA (unsigned long int freq)
+void RIG_Xiegu_G90::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -273,7 +276,7 @@ void RIG_Xiegu_G90::set_vfoA (unsigned long int freq)
 	isett("");
 }
 
-unsigned long int RIG_Xiegu_G90::get_vfoB ()
+unsigned long long RIG_Xiegu_G90::get_vfoB ()
 {
 	if (inuse == onA) return B.freq;
 	std::string resp = pre_fm;
@@ -295,7 +298,7 @@ unsigned long int RIG_Xiegu_G90::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_Xiegu_G90::set_vfoB (unsigned long int freq)
+void RIG_Xiegu_G90::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -479,11 +482,8 @@ void RIG_Xiegu_G90::set_attenuator(int val)
 {
    if (val) {
 		atten_level = 1;
-		atten_label("ATT", true);
-		preamp_label("PRE", false);
 	} else {
 		atten_level = 0;
-		atten_label("ATT", false);
 	}
 
 	cmd = pre_to;
@@ -508,11 +508,8 @@ int RIG_Xiegu_G90::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+5] == 0x00) {
 			atten_level = 0;
-			atten_label("ATT", false);
 		} else {
 			atten_level = 1;
-			atten_label("ATT", true);
-			preamp_label("PRE", false);
 		}
 	}
 	return atten_level;
@@ -525,11 +522,8 @@ void RIG_Xiegu_G90::set_preamp(int val)
 	cmd += '\x02';
 
 	if (val) {
-		preamp_label("PRE", true);
-		atten_label("ATT", false);
 		cmd += '\x01';
 	} else {
-		preamp_label("PRE", false);
 		cmd += '\x00';
 	}
 
@@ -554,15 +548,28 @@ int RIG_Xiegu_G90::get_preamp()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos)
 			preamp_level = replystr[p+6];
-		if (preamp_level == 1) {
-			preamp_label("PRE", true);
-			atten_label("ATT", false);
-		} else
-			preamp_label("PRE", false);
 	}
 	return preamp_level;
 }
 
+const char *RIG_Xiegu_G90::PRE_label()
+{
+	switch (preamp_level) {
+		case 0: default:
+			return "PRE"; break;
+		case 1:
+			return "ON"; break;
+	}
+	return "PRE";
+}
+
+const char *RIG_Xiegu_G90::ATT_label()
+{
+	if (atten_level)
+		return "ON";
+	return "ATT";
+}
+
 static int compon = 0;
 static int compval = 0;
 
@@ -720,10 +727,6 @@ int RIG_Xiegu_G90::get_power_out(void)
 			} else {
 				mtr = 100 * hexval(replystr[p + 7]) + hexval(replystr[p + 6]);
 			}
-//int p6 = hexval(replystr[p+6]);
-//int p7 = hexval(replystr[p+7]);
-//std::cout << "power out: " << str2hex(replystr.c_str(), replystr.length()) << std::endl;
-//std::cout << "pout vals: " << p6 << ", " << p7 << ", " << 100*p7+p6 << std::endl;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 213) mtr = 213;
 		}
@@ -869,8 +872,7 @@ int RIG_Xiegu_G90::get_smeter()
 			if (replystr[p + 7] == '\xFD') {
 				mtr = hexval(replystr[p + 6]);
 			} else {
-				mtr = hexval(replystr[p + 6]);
-				mtr += 100 * hexval(replystr[p + 7]);
+				mtr = 100 * hexval(replystr[p + 6]) + hexval(replystr[p + 7]);
 			}
 			if (mtr < 0) mtr = 0;
 			if (mtr > 241) mtr = 241;
@@ -907,27 +909,25 @@ int RIG_Xiegu_G90::get_swr()
 	cmd.append( post );
 	int mtr= -1;
 	get_trace(1, "get swr");
-	if (waitFOR(9, "get SWR")) {
+	if (waitFOR(9, "get SWR")) 
+	{
 		igett("");
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				mtr = hexval(replystr[p + 6]);
 			} else {
-				mtr = 100 * hexval(replystr[p + 7]) + hexval(replystr[p + 6]);
+				mtr = 100 * hexval(replystr[p + 6]) + hexval(replystr[p + 7]);
 			}
-std::cout << "SWR: " << str2hex(replystr.c_str(), replystr.length()) << std::endl;
-std::cout << "meter: " << mtr << " --> ";
 			size_t i = 0;
 			for (i = 0; i < sizeof(swrtbl) / sizeof(meterpair) - 1; i++)
 				if (mtr >= swrtbl[i].mtr && mtr < swrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(smtrtbl[i].val + 
-				(smtrtbl[i+1].val - smtrtbl[i].val)*(mtr - smtrtbl[i].mtr)/(smtrtbl[i+1].mtr - smtrtbl[i].mtr));
+			mtr = (int)ceil(swrtbl[i].val + 
+				(swrtbl[i+1].val - swrtbl[i].val)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
 			if (mtr > 100) mtr = 100;
-std::cout << mtr << std::endl;
 		}
 	}
 	return mtr;
@@ -982,10 +982,10 @@ void RIG_Xiegu_G90::get_band_selection(int v)
 	if (bandmode < 0) bandmode = 0;
 	if (bandmode > 4) bandmode = 0;
 	if (inuse == onB) {
-		set_vfoB(bandfreq);
+		set_vfoB((unsigned long long)bandfreq);
 		set_modeB(bandmode);
 	} else {
-		set_vfoA(bandfreq);
+		set_vfoA((unsigned long long)bandfreq);
 		set_modeA(bandmode);
 		}
 	set_trace(1, "get band selection");
@@ -993,19 +993,23 @@ void RIG_Xiegu_G90::get_band_selection(int v)
 
 void RIG_Xiegu_G90::set_band_selection(int v)
 {
+	// Carrier freq needs to be unsigned long long because of potential
+	// microwave band use; however, the established HF amateur bands fit
+	// within an int and the fltk Fl_Preferences class doesn't support
+	// unsigned or long long so we store as int and use a mask to avoid compiler complaint.
 	switch (v) {
 		default:
-		case 1:  progStatus.f160 = vfo->freq; progStatus.m160 = vfo->imode; break;
-		case 2:  progStatus.f80 = vfo->freq;  progStatus.m80 = vfo->imode;  break;
-		case 3:  progStatus.f40 = vfo->freq;  progStatus.m40 = vfo->imode;  break;
-		case 4:  progStatus.f30 = vfo->freq;  progStatus.m30 = vfo->imode;  break;
-		case 5:  progStatus.f20 = vfo->freq;  progStatus.m20 = vfo->imode;  break;
-		case 6:  progStatus.f17 = vfo->freq;  progStatus.m17 = vfo->imode;  break;
-		case 7:  progStatus.f15 = vfo->freq;  progStatus.m15 = vfo->imode;  break;
-		case 8:  progStatus.f12 = vfo->freq;  progStatus.m12 = vfo->imode;  break;
-		case 9:  progStatus.f10 = vfo->freq;  progStatus.m10 = vfo->imode;  break;
-		case 10: progStatus.f6 = vfo->freq;   progStatus.m6 = vfo->imode;   break;
-		case 13: progStatus.fgen = vfo->freq; progStatus.mgen = vfo->imode; break;
+		case 1:  progStatus.f160 = (int)vfo->freq & 0x7FFFFFFF; progStatus.m160 = vfo->imode; break;
+		case 2:  progStatus.f80 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m80 = vfo->imode;  break;
+		case 3:  progStatus.f40 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m40 = vfo->imode;  break;
+		case 4:  progStatus.f30 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m30 = vfo->imode;  break;
+		case 5:  progStatus.f20 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m20 = vfo->imode;  break;
+		case 6:  progStatus.f17 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m17 = vfo->imode;  break;
+		case 7:  progStatus.f15 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m15 = vfo->imode;  break;
+		case 8:  progStatus.f12 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m12 = vfo->imode;  break;
+		case 9:  progStatus.f10 =  (int)vfo->freq & 0x7FFFFFFF;  progStatus.m10 = vfo->imode;  break;
+		case 10: progStatus.f6 =   (int)vfo->freq & 0x7FFFFFFF;   progStatus.m6 = vfo->imode;   break;
+		case 13: progStatus.fgen = (int)vfo->freq & 0x7FFFFFFF; progStatus.mgen = vfo->imode; break;
 	}
 	set_trace(1, "set_band_selection()");
 }
