@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "yaesu/FT1000.h"
@@ -79,18 +79,21 @@ RIG_FT1000::RIG_FT1000() {
 
 	can_change_alt_vfo = true;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 100;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
-	afreq = bfreq = A.freq = B.freq = 7100000;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 5;
+
+	serial_timeout = 100;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+	afreq = bfreq = A.freq = B.freq = 7100000ULL;
 	//amode = bmode = A.imode = B.imode = 1;
 	aBW = bBW = A.iBW = B.iBW = 0;
 
@@ -246,7 +249,7 @@ bool RIG_FT1000::get_info()
 }
 
 
-unsigned long int RIG_FT1000::get_vfoA ()
+unsigned long long RIG_FT1000::get_vfoA ()
 {
 	return A.freq;
 }
@@ -264,7 +267,7 @@ int RIG_FT1000::get_bwA()
 }
 
 
-void RIG_FT1000::set_vfoA (unsigned long int freq)
+void RIG_FT1000::set_vfoA (unsigned long long freq)
 {
 
 	A.freq = freq;
@@ -309,7 +312,7 @@ void RIG_FT1000::set_bwA (int val)
 }
 
 
-unsigned long int RIG_FT1000::get_vfoB()
+unsigned long long RIG_FT1000::get_vfoB()
 {
 	return B.freq;
 }
@@ -327,7 +330,7 @@ int  RIG_FT1000::get_bwB()
 }
 
 
-void RIG_FT1000::set_vfoB(unsigned long int freq)
+void RIG_FT1000::set_vfoB(unsigned long long freq)
 {
 
 	B.freq = freq;
