@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -103,22 +103,25 @@ RIG_FT2000::RIG_FT2000() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 5;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeA = 1;
 	bwA = 2;
 	def_mode = 1;
 	def_bw = 2;
-	def_freq = 14070000;
+	def_freq = 14070000ULL;
 
 	has_band_selection =
 	has_extras =
@@ -212,7 +215,7 @@ bool RIG_FT2000::check ()
 	return false;
 }
 
-unsigned long int RIG_FT2000::get_vfoA ()
+unsigned long long RIG_FT2000::get_vfoA ()
 {
 	cmd = "FA;";
 	int ret = wait_char(';', 11, 100, "get vfoA", ASC);
@@ -222,7 +225,7 @@ unsigned long int RIG_FT2000::get_vfoA ()
 	if (ret < 11) return freqA;
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return freqA;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqA = f;
@@ -230,7 +233,7 @@ unsigned long int RIG_FT2000::get_vfoA ()
 	return freqA;
 }
 
-void RIG_FT2000::set_vfoA (unsigned long int freq)
+void RIG_FT2000::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000;";
@@ -241,7 +244,7 @@ void RIG_FT2000::set_vfoA (unsigned long int freq)
 	sendCommand(cmd, 0);
 }
 
-unsigned long int RIG_FT2000::get_vfoB ()
+unsigned long long RIG_FT2000::get_vfoB ()
 {
 	cmd = "FB;";
 	int ret = wait_char(';', 11, 100, "get vfoB", ASC);
@@ -251,7 +254,7 @@ unsigned long int RIG_FT2000::get_vfoB ()
 	if (ret < 11) return freqB;
 	size_t p = replystr.rfind("FA");
 	if (p == std::string::npos) return freqB;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p + n] - '0';
 	freqB = f;
@@ -259,7 +262,7 @@ unsigned long int RIG_FT2000::get_vfoB ()
 	return freqB;
 }
 
-void RIG_FT2000::set_vfoB (unsigned long int freq)
+void RIG_FT2000::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000;";
@@ -442,20 +445,16 @@ void RIG_FT2000::set_attenuator(int val)
 	atten_level = val;
 	switch (val) {
 		case 1 :
-			atten_label("6 dB", true);
 			cmd = "RA01;";
 			break;
 		case 2 :
-			atten_label("12 dB", true);
 			cmd = "RA02;";
 			break;
 		case 3 :
-			atten_label("18 dB", true);
 			cmd = "RA03;";
 			break;
 		case 0 :
 		default :
-			atten_label("Att", false);
 			cmd = "RA00;";
 	}
 	sendCommand(cmd, 0);
@@ -469,31 +468,25 @@ int RIG_FT2000::get_attenuator()
 	rig_trace(2, "get_attenuator()", replystr.c_str());
 
 	if (ret < 5) {
-		atten_label("Att", false);
 		return 0;
 	}
 	size_t p = replystr.rfind("RA");
 	if (p == std::string::npos) {
-		atten_label("Att", false);
 		atten_level = 0;
 		return 0;
 	}
 	int reply = replystr[p + 3];
 	switch (reply) {
 		case '1' :
-			atten_label("6 dB", true);
 			atten_level = 1;
 			break;
 		case '2' :
-			atten_label("12 dB", true);
 			atten_level = 2;
 			break;
 		case '3' :
-			atten_label("18 dB", true);
 			atten_level = 3;
 			break;
 		default :
-			atten_label("Att", false);
 			atten_level = 0;
 			break;
 	}
@@ -515,16 +508,13 @@ void RIG_FT2000::set_preamp(int val)
 	preamp_level = val;
 	switch (preamp_level) {
 		case 1 :
-			preamp_label("Pre 1", true);
 			cmd = "PA01;";
 			break;
 		case 2 :
-			preamp_label("Pre 2", true);
 			cmd = "PA02;";
 			break;
 		case 0 :
 		default :
-			preamp_label("Pre", false);
 			cmd = "PA00;";
 	}
 	sendCommand(cmd, 0);
@@ -538,13 +528,11 @@ int RIG_FT2000::get_preamp()
 	rig_trace(2, "get_preamp()", replystr.c_str());
 
 	if (ret < 5) {
-		preamp_label("Pre", false);
 		preamp_level = 0;
 		return 0;
 	}
 	size_t p = replystr.rfind("PA");
 	if (p == std::string::npos) {
-		preamp_label("Pre", false);
 		preamp_level = 0;
 		return 0;
 	}
@@ -552,20 +540,36 @@ int RIG_FT2000::get_preamp()
 	switch (reply) {
 		case '1' :
 			preamp_level = 1;
-			preamp_label("Pre 1", true);
 			break;
 		case '2' :
 			preamp_level = 2;
-			preamp_label("Pre 2", true);
 			break;
 		case '0' :
 		default :
 			preamp_level = 0;
-			preamp_label("Pre", false);
 	}
 	return preamp_level;
 }
 
+const char *RIG_FT2000::ATT_label()
+{
+	if (atten_level == 1)
+		return "6 dB";
+	if (atten_level == 2)
+		return "12 dB";
+	if (atten_level == 3)
+		return "18 dB";
+	return "ATT";
+}
+
+const char *RIG_FT2000::PRE_label()
+{
+	if (preamp_level == 1)
+		return "Amp 1";
+	if (preamp_level == 2)
+		return "Amp 2";
+	return "PRE";
+}
 
 void RIG_FT2000::set_modeA(int val)
 {
