@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 #include <sstream>
@@ -37,17 +37,22 @@ static const char FT817_mode_type[] = { 'L', 'U', 'U', 'L', 'U', 'U', 'U', 'U' }
 RIG_FT817::RIG_FT817() {
 	name_ = FT817name_;
 	modes_ = FT817modes_;
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 4;
-	comm_wait = 10;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+
+	serial_retries = 4;
+
+	serial_write_delay = 1;
+	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeA = 1;
 	bwA = 0;
 
@@ -99,7 +104,7 @@ bool RIG_FT817::check ()
 	return true;
 }
 
-unsigned long int RIG_FT817::get_vfoA()
+unsigned long long RIG_FT817::get_vfoA()
 {
 	if (inuse == onB) return freqA;
 
@@ -128,13 +133,13 @@ unsigned long int RIG_FT817::get_vfoA()
 			break;
 		}
 	static char msg[50];
-	snprintf(msg, sizeof(msg), "get vfoA: %lu, %s", freqA, FT817modes_[i]);
+	snprintf(msg, sizeof(msg), "get vfoA: %llu, %s", freqA, FT817modes_[i]);
 	getr(msg);
 
 	return freqA;
 }
 
-void RIG_FT817::set_vfoA (unsigned long int freq)
+void RIG_FT817::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	freq /=10; // 817 does not support 1 Hz resolution
@@ -172,7 +177,7 @@ void RIG_FT817::set_modeA(int val)
 }
 
 // VFO B ===============================================================
-unsigned long int RIG_FT817::get_vfoB ()
+unsigned long long RIG_FT817::get_vfoB ()
 {
 	if (inuse == onA) return freqB;
 	init_cmd();
@@ -200,13 +205,13 @@ unsigned long int RIG_FT817::get_vfoB ()
 			break;
 		}
 	static char msg[50];
-	snprintf(msg, sizeof(msg), "get vfoB: %lu, %s", freqB, FT817modes_[i]);
+	snprintf(msg, sizeof(msg), "get vfoB: %llu, %s", freqB, FT817modes_[i]);
 	getr(msg);
 
 	return freqB;
 }
 
-void RIG_FT817::set_vfoB (unsigned long int freq)
+void RIG_FT817::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	freq /=10; // 817 does not support 1 Hz resolution
