@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <stdio.h>
@@ -58,17 +58,20 @@ RIG_FT857D::RIG_FT857D() {
 	mode_vals = FT857D_mode_val;
 	mode_type = FT857D_mode_type;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 	modeA = 1;
 	bwA = 0;
 
@@ -121,7 +124,7 @@ bool RIG_FT857D::check ()
 
 }
 
-unsigned long int RIG_FT857D::get_vfoA ()
+unsigned long long RIG_FT857D::get_vfoA ()
 {
 	if (inuse == onB) return freqA;
 	init_cmd();
@@ -142,13 +145,13 @@ unsigned long int RIG_FT857D::get_vfoA ()
 	}
 
 	static char msg[50];
-	snprintf(msg, sizeof(msg), "get vfoA: %lu, %s", freqA, modes_[modeA]);
+	snprintf(msg, sizeof(msg), "get vfoA: %llu, %s", freqA, modes_[modeA]);
 	getr(msg);
 
 	return freqA;
 }
 
-void RIG_FT857D::set_vfoA (unsigned long int freq)
+void RIG_FT857D::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	freq /=10; // 857D does not support 1 Hz resolution
@@ -160,7 +163,7 @@ void RIG_FT857D::set_vfoA (unsigned long int freq)
 	setthex("set_vfoA");
 }
 
-unsigned long int RIG_FT857D::get_vfoB ()
+unsigned long long RIG_FT857D::get_vfoB ()
 {
 	if (inuse == onA) return freqB;
 	init_cmd();
@@ -181,13 +184,13 @@ unsigned long int RIG_FT857D::get_vfoB ()
 	}
 
 	static char msg[50];
-	snprintf(msg, sizeof(msg), "get vfoB: %lu, %s", freqA, modes_[modeB]);
+	snprintf(msg, sizeof(msg), "get vfoB: %llu, %s", freqA, modes_[modeB]);
 	getr(msg);
 
 	return freqB;
 }
 
-void RIG_FT857D::set_vfoB (unsigned long int freq)
+void RIG_FT857D::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	freq /=10; // 857D does not support 1 Hz resolution
@@ -286,6 +289,22 @@ int  RIG_FT857D::get_smeter(void)
 
 void RIG_FT857D::selectA()
 {
+	bool isA = true;
+
+	init_cmd();
+	cmd[1] = 0x68;
+	cmd[4] = 0xBB;
+
+	int ret = waitN(1, 100, "get eeprom @ 0068");
+	getthex("get eeprom data @ 0068");
+	if (ret != 0)
+		isA = ((replystr[0] & 0x01) == 0);
+
+	if (isA) {
+		inuse = onA;
+		return;
+	}
+
 	init_cmd();
 	cmd[4] = 0x81;
 	sendCommand(cmd);
@@ -296,6 +315,22 @@ void RIG_FT857D::selectA()
 
 void RIG_FT857D::selectB()
 {
+	bool isB = true;
+
+	init_cmd();
+	cmd[1] = 0x68;
+	cmd[4] = 0xBB;
+
+	int ret = waitN(1, 100, "get eeprom @ 0068");
+	getthex("get eeprom data @ 0068");
+	if (ret != 0)
+		isB = ((replystr[0] & 0x01) == 0x01);
+
+	if (isB) {
+		inuse = onB;
+		return;
+	}
+
 	init_cmd();
 	cmd[4] = 0x81;
 	sendCommand(cmd);
@@ -346,7 +381,7 @@ int  RIG_FT857D::get_split()
 
 void RIG_FT857D::set_band_selection(int v)
 {
-	unsigned long int freq = 14070000L;
+	unsigned long long freq = 14070000ULL;
 	int  mode = 0;
 	switch (v) {
 		case 1: freq = progStatus.f160; mode = progStatus.m160; break; // 160 meters
