@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <sstream>
@@ -104,21 +104,24 @@ RIG_FT891::RIG_FT891() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR38400;
+	serial_baudrate = BR38400;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 50;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	A.imode = B.imode = modeB = modeA = def_mode = 1;
 	A.iBW = B.iBW = bwA = bwB = def_bw = 12;
-	A.freq = B.freq = freqA = freqB = def_freq = 14070000;
+	A.freq = B.freq = freqA = freqB = def_freq = 14070000ULL;
 
 	has_compression =
 	has_compON =
@@ -232,7 +235,7 @@ bool RIG_FT891::check ()
 	return false;
 }
 
-unsigned long int RIG_FT891::get_vfoA ()
+unsigned long long RIG_FT891::get_vfoA ()
 {
 	// When VFOA is 'selected', radio has it actively loaded in FA, otherwise
 	// it is in FB
@@ -250,14 +253,14 @@ unsigned long int RIG_FT891::get_vfoA ()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqA;
 	p += 2;
-	int f = 0;
+	unsigned long long f = 0;
 	for (int n = 0; n < ndigits; n++)
 		f = f * 10 + replystr[p + n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_FT891::set_vfoA (unsigned long int freq)
+void RIG_FT891::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	
@@ -280,7 +283,7 @@ void RIG_FT891::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
 }
 
-unsigned long int RIG_FT891::get_vfoB ()
+unsigned long long RIG_FT891::get_vfoB ()
 {
 	// When VFOB is 'selected', radio has it actively loaded in FA, otherwise
 	// it is in FB
@@ -297,7 +300,7 @@ unsigned long int RIG_FT891::get_vfoB ()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqB;
 	p += 2;
-	int f = 0;
+	unsigned long long f = 0;
 	for (int n = 0; n < ndigits; n++)
 		f = f * 10 + replystr[p + n] - '0';
 	freqB = f;
@@ -305,7 +308,7 @@ unsigned long int RIG_FT891::get_vfoB ()
 }
 
 
-void RIG_FT891::set_vfoB (unsigned long int freq)
+void RIG_FT891::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	
@@ -632,11 +635,6 @@ void RIG_FT891::set_preamp(int val)
 {
 	if (val) cmd = "PA01;";
 	else     cmd = "PA00;";
-	if (val) {
-		preamp_label("AMP", true);
-	} else {
-		preamp_label("IPO", false);
-	}
 	preamp_level = val;
 
 	set_trace(1, "set_preamp()");
@@ -656,16 +654,23 @@ int RIG_FT891::get_preamp()
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
-
-	if (preamp_level == 1) {
-		preamp_label("Amp", true);
-	} else {
-		preamp_label("IPO", false);
-	}
-
 	return preamp_level;
 }
 
+const char *RIG_FT891::ATT_label()
+{
+	if (atten_level == 1)
+		return "12 dB";
+	return "ATT";
+}
+
+const char *RIG_FT891::PRE_label()
+{
+	if (preamp_level == 1)
+		return "Amp";
+	return "IPO";
+}
+
 int RIG_FT891::adjust_bandwidth(int val)
 {
 	switch (val) {
