@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "yaesu/FT920.h"
@@ -46,18 +46,21 @@ RIG_FT920::RIG_FT920() {
 	bandwidths_ = FT920widths_;
 	bw_vals_ = FT920_bw_val;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = false;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
-	afreq = bfreq = A.freq = B.freq = 14070000;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 80;
+
+	serial_timeout = 50;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = false;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+	afreq = bfreq = A.freq = B.freq = 14070000ULL;
 	amode = bmode = A.imode = B.imode = 1;
 	aBW = bBW = A.iBW = B.iBW = 0;
 	precision = 10;
@@ -148,8 +151,8 @@ bool RIG_FT920::get_info()
 			afreq = afreq * 256 + (unsigned char)replystr[p + n];
 			bfreq = bfreq * 256 + (unsigned char)replystr[p + 14 + n];
 		}
-		afreq = afreq * 1.25;
-		bfreq = bfreq * 1.25;
+		afreq *= 10;
+		bfreq *= 10;
 		int md = replystr[p+5];
 		switch (md) {
 			case 0 : 
@@ -213,12 +216,12 @@ bool RIG_FT920::get_info()
 	return false;
 }
 
-unsigned long int RIG_FT920::get_vfoA ()
+unsigned long long RIG_FT920::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_FT920::set_vfoA (unsigned long int freq)
+void RIG_FT920::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
 	freq /=10; // 920 does not support 1 Hz resolution
@@ -258,12 +261,12 @@ int RIG_FT920::get_bwA()
 	return A.iBW;
 }
 
-unsigned long int RIG_FT920::get_vfoB()
+unsigned long long RIG_FT920::get_vfoB()
 {
 	return B.freq;
 }
 
-void RIG_FT920::set_vfoB(unsigned long int freq)
+void RIG_FT920::set_vfoB(unsigned long long freq)
 {
 	B.freq = freq;
 	freq /=10; // 920 does not support 1 Hz resolution
