@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "yaesu/FT990a.h"
@@ -64,18 +64,21 @@ RIG_FT990A::RIG_FT990A() {
 	bandwidths_ = FT990Awidths_;
 	bw_vals_ = FT990A_bw_vals;
 
-	comm_baudrate = BR4800;
+	serial_baudrate = BR4800;
 	stopbits = 2;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 100;
-	comm_rtscts = false;
-	comm_rtsplus = false;
-	comm_dtrplus = true;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
-	afreq = bfreq = A.freq = B.freq = 14070000;
+	serial_retries = 2;
+
+	serial_write_delay = 50;
+	serial_post_write_delay = 5;
+
+	serial_timeout = 100;
+	serial_rtscts = false;
+	serial_rtsplus = false;
+	serial_dtrplus = true;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
+	afreq = bfreq = A.freq = B.freq = 14070000ULL;
 	amode = bmode = A.imode = B.imode = 1;
 	aBW = bBW = A.iBW = B.iBW = 2;
 
@@ -266,12 +269,12 @@ bool RIG_FT990A::get_info()
 	return false;
 }
 
-unsigned long int RIG_FT990A::get_vfoA ()
+unsigned long long RIG_FT990A::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_FT990A::set_vfoA (unsigned long int freq)
+void RIG_FT990A::set_vfoA (unsigned long long freq)
 {
 	int current_vfo = inuse;
 	if (current_vfo == onB) selectA();
@@ -330,12 +333,12 @@ int RIG_FT990A::get_bwA()
 	return A.iBW;
 }
 
-unsigned long int RIG_FT990A::get_vfoB()
+unsigned long long RIG_FT990A::get_vfoB()
 {
 	return B.freq;
 }
 
-void RIG_FT990A::set_vfoB(unsigned long int freq)
+void RIG_FT990A::set_vfoB(unsigned long long freq)
 {
 	int current_vfo = inuse;
 	if (current_vfo == onA) selectB();
