@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -159,21 +159,24 @@ RIG_FTdx101D::RIG_FTdx101D() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR38400;
+	serial_baudrate = BR38400;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 0;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	A.imode = B.imode = modeB = modeA = def_mode = 1;
 	A.iBW = B.iBW = bwA = bwB = def_bw = 0;
-	A.freq = B.freq = freqA = freqB = def_freq = 14070000;
+	A.freq = B.freq = freqA = freqB = def_freq = 14070000ULL;
 
 	notch_on = false;
 
@@ -308,7 +311,7 @@ bool RIG_FTdx101D::check ()
 	return false;
 }
 
-unsigned long int RIG_FTdx101D::get_vfoA ()
+unsigned long long RIG_FTdx101D::get_vfoA ()
 {
 	cmd = rsp = "FA";
 	cmd += ';';
@@ -318,14 +321,14 @@ unsigned long int RIG_FTdx101D::get_vfoA ()
 //replystr = Avfo;
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqA;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_FTdx101D::set_vfoA (unsigned long int freq)
+void RIG_FTdx101D::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA000000000;";
@@ -338,7 +341,7 @@ void RIG_FTdx101D::set_vfoA (unsigned long int freq)
 	sett("SET vfo A");
 }
 
-unsigned long int RIG_FTdx101D::get_vfoB ()
+unsigned long long RIG_FTdx101D::get_vfoB ()
 {
 	cmd = rsp = "FB";
 	cmd += ';';
@@ -348,7 +351,7 @@ unsigned long int RIG_FTdx101D::get_vfoB ()
 //replystr = Bvfo;
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqB;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqB = f;
@@ -356,7 +359,7 @@ unsigned long int RIG_FTdx101D::get_vfoB ()
 }
 
 
-void RIG_FTdx101D::set_vfoB (unsigned long int freq)
+void RIG_FTdx101D::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB000000000;";
@@ -478,7 +481,8 @@ struct pwrpair {int mtr; float pwr;};
 int RIG_FTdx101D::get_power_out()
 {
 	static pwrpair pwrtbl[] = { 
-		{ 35,  5.0 },
+		{  0,  0.0 },
+		{ 27,  5.0 },
 		{ 94, 25.0 },
 		{147, 50.0 },
 		{176, 75.0 },
@@ -487,7 +491,7 @@ int RIG_FTdx101D::get_power_out()
 
 	cmd = rsp = "RM5";
 	sendCommand(cmd.append(";"));
-	wait_char(';', 7, 100, "get pout", ASC);
+	wait_char(';', 10, 100, "get pout", ASC);
 	gett("get_power_out()");
 
 	size_t p = replystr.rfind(rsp);
@@ -654,15 +658,6 @@ int  RIG_FTdx101D::next_attenuator()
 void RIG_FTdx101D::set_attenuator(int val)
 {
 	atten_level = val;
-	if (atten_level == 1)
-		atten_label("6 dB", true);
-	else if (atten_level == 2)
-		atten_label("12 dB", true);
-	else if (atten_level == 3)
-		atten_label("18 dB", true);
-	else if (atten_level == 0)
-		atten_label("Att", false);
-
 	cmd = "RA00;";
 	cmd[3] += atten_level;
 	sendCommand(cmd);
@@ -681,16 +676,6 @@ int RIG_FTdx101D::get_attenuator()
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
-	if (atten_level == 1) {
-		atten_label("6 dB", true);
-	} else if (atten_level == 2) {
-		atten_label("12 dB", true);
-	} else if (atten_level == 3) {
-		atten_label("18 dB", true);
-	} else {
-		atten_level = 0;
-		atten_label("Att", false);
-	}
 	return atten_level;
 }
 
@@ -708,14 +693,6 @@ void RIG_FTdx101D::set_preamp(int val)
 {
 	preamp_level = val;
 	cmd = "PA00;";
-
-	if (preamp_level == 1)
-		preamp_label("Amp 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Amp 2", true);
-	else if (preamp_level == 0)
-		preamp_label("IPO", false);
-
 	cmd[3] = '0' + preamp_level;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
@@ -732,17 +709,29 @@ int RIG_FTdx101D::get_preamp()
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
-	if (preamp_level == 1) {
-		preamp_label("Amp 1", true);
-	} else if (preamp_level == 2) {
-		preamp_label("Amp 2", true);
-	} else {
-		preamp_label("IPO", false);
-		preamp_level = 0;
-	}
 	return preamp_level;
 }
 
+const char *RIG_FTdx101D::ATT_label()
+{
+	if (atten_level == 1)
+		return "6 dB";
+	if (atten_level == 2)
+		return "12 dB";
+	if (atten_level == 3)
+		return "18 dB";
+	return "ATT";
+}
+
+const char *RIG_FTdx101D::PRE_label()
+{
+	if (preamp_level == 1)
+		return "Amp 1";
+	if (preamp_level == 2)
+		return "Amp 2";
+	return "IPO";
+}
+
 static bool narrow = 0; // 0 - wide, 1 - narrow
 
 int RIG_FTdx101D::adjust_bandwidth(int val)
