@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -118,21 +118,24 @@ RIG_FTdx1200::RIG_FTdx1200() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR38400;
+	serial_baudrate = BR38400;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 5;
+	serial_post_write_delay = 5;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	A.imode = B.imode = modeB = modeA = def_mode = 1;
 	A.iBW = B.iBW = bwA = bwB = def_bw = 12;
-	A.freq = B.freq = freqA = freqB = def_freq = 14070000;
+	A.freq = B.freq = freqA = freqB = def_freq = 14070000ULL;
 
 	has_compON =
 	has_compression =
@@ -224,7 +227,7 @@ void RIG_FTdx1200::initialize()
 // Disable Auto Information mode
 	sendCommand("AI0;");
 
-// "MRnnn;" if valid, returns last channel used, "mrlll...;", aunsigned long int with channel nnn info.
+// "MRnnn;" if valid, returns last channel used, "mrlll...;", along with channel nnn info.
 	cmd = "MR118;";
 	wait_char(';', 27, 100, "Read UK 60m Channel Mem", ASC);
 	size_t p = replystr.rfind("MR");
@@ -264,15 +267,20 @@ bool RIG_FTdx1200::check ()
 {
 	cmd = "FA;";
 	rsp = "FA";
+	int tries = 10;
+	MilliSleep(200);
 	int ret = wait_char(';', 11, 100, "check", ASC);
-
 	get_trace(3, "check()", cmd.c_str(), replystr.c_str());
-
-	if (ret >= 11) return true;
-	return false;
+	while (ret < 11 && tries--) {
+		MilliSleep(200);
+		ret = wait_char(';', 11, 100, "check", ASC);
+		get_trace(3, "check()", cmd.c_str(), replystr.c_str());
+	}
+	if (ret < 11) return false;
+	return true;
 }
 
-unsigned long int RIG_FTdx1200::get_vfoA ()
+unsigned long long RIG_FTdx1200::get_vfoA ()
 {
 	cmd = "FA;";
 	rsp = "FA";
@@ -282,14 +290,14 @@ unsigned long int RIG_FTdx1200::get_vfoA ()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqA;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_FTdx1200::set_vfoA (unsigned long int freq)
+void RIG_FTdx1200::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000;";
@@ -302,7 +310,7 @@ void RIG_FTdx1200::set_vfoA (unsigned long int freq)
 	set_trace(3,"set_vfoA", cmd.c_str(), replystr.c_str());
 }
 
-unsigned long int RIG_FTdx1200::get_vfoB ()
+unsigned long long RIG_FTdx1200::get_vfoB ()
 {
 	cmd = "FB;";
 	rsp = "FB";
@@ -312,7 +320,7 @@ unsigned long int RIG_FTdx1200::get_vfoB ()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqB;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqB = f;
@@ -320,7 +328,7 @@ unsigned long int RIG_FTdx1200::get_vfoB ()
 }
 
 
-void RIG_FTdx1200::set_vfoB (unsigned long int freq)
+void RIG_FTdx1200::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000;";
@@ -644,7 +652,7 @@ void RIG_FTdx1200::tune_rig(int)
 	static int rmd = modeA;
 	static int rbw = bwA;
 	static int rpwr = 100;
-	static unsigned long int rfreq = freqA;	// fix for menu 047 OFSt default
+	static unsigned long long rfreq = freqA;	// fix for menu 047 OFSt default
 	int use_int_tuner = true;
 
 //  On-The-Fly bandstack by bandstack int/ext tuner
@@ -708,16 +716,6 @@ int  RIG_FTdx1200::next_attenuator()
 void RIG_FTdx1200::set_attenuator(int val)
 {
 	atten_level = val;
-
-	if (atten_level == 1)
-		atten_label("6 dB", true);
-	else if (atten_level == 2)
-		atten_label("12 dB", true);
-	else if (atten_level == 3)
-		atten_label("18 dB", true);
-	else if (atten_level == 0)
-		atten_label("Att", false);
-
 	cmd = "RA00;";
 	cmd[3] += atten_level;
 	sendCommand(cmd);
@@ -737,16 +735,6 @@ int RIG_FTdx1200::get_attenuator()
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
-	if (atten_level == 1) {
-		atten_label("6 dB", true);
-	} else if (atten_level == 2) {
-		atten_label("12 dB", true);
-	} else if (atten_level == 3) {
-		atten_label("18 dB", true);
-	} else {
-		atten_level = 0;
-		atten_label("Att", false);
-	}
 	return atten_level;
 }
 
@@ -764,14 +752,6 @@ void RIG_FTdx1200::set_preamp(int val)
 {
 	preamp_level = val;
 	cmd = "PA00;";
-
-	if (preamp_level == 1)
-		preamp_label("Amp 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Amp 2", true);
-	else if (preamp_level == 0)
-		preamp_label("IPO", false);
-
 	cmd[3] = '0' + preamp_level;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
@@ -789,17 +769,29 @@ int RIG_FTdx1200::get_preamp()
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
-	if (preamp_level == 1) {
-		preamp_label("Amp 1", true);
-	} else if (preamp_level == 2) {
-		preamp_label("Amp 2", true);
-	} else {
-		preamp_label("IPO", false);
-		preamp_level = 0;
-	}
 	return preamp_level;
 }
 
+const char *RIG_FTdx1200::ATT_label()
+{
+	if (atten_level == 1)
+		return "6 dB";
+	if (atten_level == 2)
+		return "12 dB";
+	if (atten_level == 3)
+		return "18 dB";
+	return "ATT";
+}
+
+const char *RIG_FTdx1200::PRE_label()
+{
+	if (preamp_level == 1)
+		return "Amp 1";
+	if (preamp_level == 2)
+		return "Amp 2";
+	return "IPO";
+}
+
 int RIG_FTdx1200::adjust_bandwidth(int val)
 {
 	switch (val) {
