@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -150,21 +150,24 @@ RIG_FTdx9000::RIG_FTdx9000() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR38400;
+	serial_baudrate = BR38400;
 	stopbits = 1;
-	comm_retries = 2;
-	comm_wait = 5;
-	comm_timeout = 50;
-	comm_rtscts = true;
-	comm_rtsplus = false;
-	comm_dtrplus = false;
-	comm_catptt = true;
-	comm_rtsptt = false;
-	comm_dtrptt = false;
+	serial_retries = 2;
+
+	serial_write_delay = 0;
+	serial_post_write_delay = 5;
+
+	serial_timeout = 50;
+	serial_rtscts = true;
+	serial_rtsplus = false;
+	serial_dtrplus = false;
+	serial_catptt = true;
+	serial_rtsptt = false;
+	serial_dtrptt = false;
 
 	A.imode = B.imode = modeB = modeA = def_mode = 1;
 	A.iBW = B.iBW = bwA = bwB = def_bw = 19;
-	A.freq = B.freq = freqA = freqB = def_freq = 14070000;
+	A.freq = B.freq = freqA = freqB = def_freq = 14070000ULL;
 
 	notch_on = false;
 
@@ -286,7 +289,7 @@ bool RIG_FTdx9000::check ()
 	return false;
 }
 
-unsigned long int RIG_FTdx9000::get_vfoA ()
+unsigned long long RIG_FTdx9000::get_vfoA ()
 {
 	cmd = rsp = "FA";
 	cmd += ';';
@@ -296,14 +299,14 @@ unsigned long int RIG_FTdx9000::get_vfoA ()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqA;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_FTdx9000::set_vfoA (unsigned long int freq)
+void RIG_FTdx9000::set_vfoA (unsigned long long freq)
 {
 	freqA = freq;
 	cmd = "FA00000000;";
@@ -315,7 +318,7 @@ void RIG_FTdx9000::set_vfoA (unsigned long int freq)
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
 }
 
-unsigned long int RIG_FTdx9000::get_vfoB ()
+unsigned long long RIG_FTdx9000::get_vfoB ()
 {
 	cmd = rsp = "FB";
 	cmd += ';';
@@ -325,7 +328,7 @@ unsigned long int RIG_FTdx9000::get_vfoB ()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqB;
-	int f = 0;
+	unsigned long long f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqB = f;
@@ -333,7 +336,7 @@ unsigned long int RIG_FTdx9000::get_vfoB ()
 }
 
 
-void RIG_FTdx9000::set_vfoB (unsigned long int freq)
+void RIG_FTdx9000::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
 	cmd = "FB00000000;";
@@ -608,14 +611,6 @@ int  RIG_FTdx9000::next_attenuator()
 void RIG_FTdx9000::set_attenuator(int val)
 {
 	atten_level = val;
-	if (atten_level == 1)
-		atten_label("6 dB", true);
-	else if (atten_level == 2)
-		atten_label("12 dB", true);
-	else if (atten_level == 3)
-		atten_label("18 dB", true);
-	else if (atten_level == 0)
-		atten_label("Att", false);
 
 	cmd = "RA00;";
 	cmd[3] += atten_level;
@@ -635,16 +630,6 @@ int RIG_FTdx9000::get_attenuator()
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
-	if (atten_level == 1) {
-		atten_label("6 dB", true);
-	} else if (atten_level == 2) {
-		atten_label("12 dB", true);
-	} else if (atten_level == 3) {
-		atten_label("18 dB", true);
-	} else {
-		atten_level = 0;
-		atten_label("Att", false);
-	}
 	return atten_level;
 }
 
@@ -662,13 +647,6 @@ void RIG_FTdx9000::set_preamp(int val)
 {
 	preamp_level = val;
 	cmd = "PA00;";
-	if (preamp_level == 1)
-		preamp_label("Amp 1", true);
-	else if (preamp_level == 2)
-		preamp_label("Amp 2", true);
-	else if (preamp_level == 0)
-		preamp_label("IPO", false);
-
 	cmd[3] = '0' + preamp_level;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
@@ -685,17 +663,29 @@ int RIG_FTdx9000::get_preamp()
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
-	if (preamp_level == 1) {
-		preamp_label("Amp 1", true);
-	} else if (preamp_level == 2) {
-		preamp_label("Amp 2", true);
-	} else {
-		preamp_label("IPO", false);
-		preamp_level = 0;
-	}
 	return preamp_level;
 }
 
+const char *RIG_FTdx9000::ATT_label()
+{
+	if (atten_level == 1)
+		return "6 dB";
+	if (atten_level == 2)
+		return "12 dB";
+	if (atten_level == 3)
+		return "18 dB";
+	return "ATT";
+}
+
+const char *RIG_FTdx9000::PRE_label()
+{
+	if (preamp_level == 1)
+		return "Amp 1";
+	if (preamp_level == 2)
+		return "Amp 2";
+	return "IPO";
+}
+
 int RIG_FTdx9000::adjust_bandwidth(int val)
 {
 	int bw = 0;
