@@ -18,6 +18,9 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+#include "config.h"
+#include "compat.h" // Must precede all FL includes
+
 #include <stdlib.h>
 #include <iostream>
 #include <fstream>
