@@ -18,6 +18,9 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+#include "config.h"
+#include "compat.h" // Must precede all FL includes
+
 #include <FL/Fl.H>
 #include <FL/x.H>
 #include <FL/fl_draw.H>
@@ -1053,13 +1056,13 @@ void setColors()
 	progStatus.tab_blue = tab_blue;
 
 	if (selrig->inuse == onB) {
-		FreqDispB->SetONOFFCOLOR( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
-		FreqDispA->SetONOFFCOLOR(
+		FreqDispB->SetCOLORS( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
+		FreqDispA->SetCOLORS(
 			fl_rgb_color(fg_red, fg_green, fg_blue),
 			fl_color_average(bgclr, FL_BLACK, 0.87));
 	} else {
-		FreqDispA->SetONOFFCOLOR( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
-		FreqDispB->SetONOFFCOLOR(
+		FreqDispA->SetCOLORS( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
+		FreqDispB->SetCOLORS(
 			fl_rgb_color(fg_red, fg_green, fg_blue),
 			fl_color_average(bgclr, FL_BLACK, 0.87));
 	}
@@ -1790,7 +1793,7 @@ void cb_send_command(std::string command, Fl_Output *resp)
 {
 	if (command.empty()) return;
 	bool usehex = false;
-	if (command.empty()) return;
+
 	std::string cmd = "";
 	if (command.find("x") != std::string::npos) { // hex std::strings
 		size_t p = 0;
@@ -1813,9 +1816,9 @@ void cb_send_command(std::string command, Fl_Output *resp)
 	guard_lock lock1(&mutex_srvc_reqs);
 	guard_lock lock2(&mutex_serial);
 
-	sendCommand(cmd, 0);//cmd.length());
+	sendCommand(cmd);
 	set_trace(2, "command: ", command.c_str());
-	waitResponse(100);
+	waitResponse(200);
 
 	std::string retstr = usehex ? 
 		str2hex(respstr.c_str(), respstr.length()) :
