@@ -18,6 +18,7 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+
 #include "support.h"
 #include "ptt.h"
 
@@ -69,6 +70,24 @@ void TRACED(adjust_small_ui)
 	btnAGC->hide();
 	sldrRFGAIN->redraw_label();
 
+
+	if (!selrig->has_power_out && !selrig->has_voltmeter) {
+		sm_grp1->resize(FreqDispA->x(), sm_grp1->y(), FreqDispA->w(), 40);
+		sm_grp1->color(fl_rgb_color(progStatus.bg_red, progStatus.bg_green, progStatus.bg_blue));
+		grpMeters->resize(sm_grp1->x()+ 2, sm_grp1->y() + 2, sm_grp1->w() - 4, sm_grp1->h() - 4);
+		scaleSmeter->resize(grpMeters->x(), grpMeters->y() + 6, grpMeters->w(), scaleSmeter->h());
+		sldrRcvSignal->resize(scaleSmeter->x() + 2, scaleSmeter->y() + scaleSmeter->h() + 6, scaleSmeter->w() - 4, sldrRcvSignal->h());
+		sldrALC->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
+		sldrIDD->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
+		sldrSWR->resize(sldrRcvSignal->x(), sldrRcvSignal->y(), sldrRcvSignal->w(), sldrRcvSignal->h());
+		grpMeters->redraw();
+		sm_grp1->redraw();
+		sldrRcvSignal->redraw();
+		sldrALC->redraw();
+		sldrIDD->redraw();
+		sldrSWR->redraw();
+	}
+
 	if (progStatus.schema == 1 && selrig->widgets[0].W != (Fl_Widget *)0) {
 		int i = 0;
 		while (selrig->widgets[i].W != NULL) {
@@ -93,7 +112,7 @@ void TRACED(adjust_small_ui)
 		if (mnuSchema) mnuSchema->set();
 	} else {
 		if (mnuSchema) mnuSchema->clear();
-		y = cntRIT->y() + 2;
+		y = grpMeters->y() + grpMeters->h() - 18;
 		if (selrig->has_volume_control) {
 			y += 20;
 			btnVol->position( 2, y);
@@ -211,6 +230,9 @@ void TRACED(adjust_small_ui)
 	btn_tune_on_off->position( btn_tune_on_off->x(), y);
 	btn_tune_on_off->redraw();
 
+	cbo_preamp->resize( btnAttenuator->x(), btnAttenuator->y(), cbo_preamp->w(), btnAttenuator->h());
+	cbo_preamp->redraw();
+
 	if (selrig->has_noise_reduction) {
 		btnNOISE->show();
 	} else {
@@ -219,6 +241,7 @@ void TRACED(adjust_small_ui)
 	btnNOISE->redraw();
 
 	if (selrig->has_agc_control) {
+		btnAGC->resize(btnAGC->x(), sldrRFGAIN->y(), btnAGC->w(), btnAGC->h());
 		btnAGC->show();
 		sldrRFGAIN->label("");
 		sldrRFGAIN->redraw_label();
@@ -433,7 +456,9 @@ void TRACED(adjust_wide_ui)
 		sldrINNER->show();
 		sldrOUTER->show();
 		sldrINNER->value(progStatus.pbt_inner);
+		sldrINNER->redraw();
 		sldrOUTER->value(progStatus.pbt_outer);
+		sldrOUTER->redraw();
 	}
 	btnNotch->show();
 	sldrNOTCH->show();
@@ -462,24 +487,7 @@ void TRACED(adjust_wide_ui)
 	} else {
 		tabs550->hide();
 
-		tabsGeneric->remove(genericAux);
-		genericAux->hide();
-		btnAuxDTR->hide();
-		btnAuxRTS->hide();
-		btnDataPort->hide();
-		if (progStatus.aux_serial_port != "NONE") {
-			btnAuxRTS->show();
-			btnAuxDTR->show();
-			tabsGeneric->add(genericAux);
-			genericAux->show();
-		}
 
-		tabsGeneric->remove(genericRXB);
-		if (selrig->has_rit || selrig->has_xit || selrig->has_bfo)
-			tabsGeneric->add(genericRXB);
-
-		tabsGeneric->redraw();
-		tabsGeneric->show();
 		if (selrig->has_agc_control) {
 			btnAGC->show();
 			sldrRFGAIN->label("");
@@ -581,8 +589,18 @@ void TRACED(adjust_touch_ui)
 		}
 
 		tabsGeneric->remove(genericRXB);
-		if (selrig->has_rit || selrig->has_xit || selrig->has_bfo)
+		genericRXB->hide();
+		if (selrig->has_rit || selrig->has_xit || selrig->has_bfo) {
+			if (selrig->has_rit) cntRIT->show();
+			else                 cntRIT->hide();
+			if (selrig->has_xit) cntXIT->show();
+			else                 cntXIT->hide();
+			if (selrig->has_bfo) cntBFO->show();
+			else                 cntBFO->hide();
 			tabsGeneric->add(genericRXB);
+			genericRXB->show();
+		}
+
 		tabsGeneric->show();
 	}
 
@@ -608,10 +626,49 @@ void TRACED(adjust_touch_ui)
 
 void TRACED(adjust_control_positions)
 
-	if (!selrig->has_smeter)
-		grpMeters->deactivate();
-	else
-		grpMeters->activate();
+	sldrRcvSignal->activate();
+	sigbar_SMETER->activate();
+
+	sldrALC->activate();
+	sigbar_ALC->activate();
+
+	sldrIDD->activate();
+	sigbar_IDD->activate();
+
+	sldrSWR->activate();
+	sigbar_SWR->activate();
+
+	sldrVoltage->activate();
+	sigbar_VOLTS->activate();
+
+	sldrFwdPwr->activate();
+	sigbar_PWR->activate();
+
+	if (!selrig->has_smeter) {
+		sldrRcvSignal->deactivate();
+		sigbar_SMETER->deactivate();
+	}
+	if (!selrig->has_alc_control) {
+		sldrALC->deactivate();
+		sigbar_ALC->deactivate();
+	}
+	if (!selrig->has_idd_control) {
+		sldrIDD->deactivate();
+		sigbar_IDD->deactivate();
+	}
+	if (!selrig->has_swr_control) {
+		sldrSWR->deactivate();
+		sigbar_SWR->deactivate();
+	}
+	if (!selrig->has_voltmeter) {
+		sldrVoltage->deactivate();
+		sigbar_VOLTS->deactivate();
+	}
+	if (!selrig->has_power_out) {
+		sldrFwdPwr->deactivate();
+		sigbar_PWR->hide(); //deactivate();
+		scalePower->hide();
+	}
 
 	switch (progStatus.UIsize) {
 		case small_ui :
@@ -656,7 +713,6 @@ void TRACED(adjust_control_positions)
 }
 
 void TRACED(init_Generic_Tabs)
-
 	if (hidden_tabs) {
 		hidden_tabs->remove(tab_yaesu_bands);
 		hidden_tabs->remove(tab_ft991_bands);
@@ -670,6 +726,7 @@ void TRACED(init_Generic_Tabs)
 		hidden_tabs->remove(genericRx);
 		hidden_tabs->remove(genericMisc);
 		hidden_tabs->remove(genericAux);
+		hidden_tabs->remove(genericRXB);
 		hidden_tabs->remove(genericUser_1);
 		hidden_tabs->remove(genericUser_2);
 		hidden_tabs->remove(genericUser_3);
@@ -688,6 +745,7 @@ void TRACED(init_Generic_Tabs)
 		hidden_tabs->add(genericRx);
 		hidden_tabs->add(genericMisc);
 		hidden_tabs->add(genericAux);
+		hidden_tabs->add(genericRXB);
 		hidden_tabs->add(genericUser_1);
 		hidden_tabs->add(genericUser_2);
 		hidden_tabs->add(genericUser_3);
@@ -706,6 +764,7 @@ void TRACED(init_Generic_Tabs)
 		tabsGeneric->remove(genericRx);
 		tabsGeneric->remove(genericMisc);
 		tabsGeneric->remove(genericAux);
+		tabsGeneric->remove(genericRXB);
 		tabsGeneric->remove(genericUser_1);
 		tabsGeneric->remove(genericUser_2);
 		tabsGeneric->remove(genericUser_3);
@@ -905,32 +964,25 @@ void TRACED(init_Generic_Tabs)
 	}
 
 	if (selrig->has_nb_level ||
-		selrig->has_bpf_center ) {
+		selrig->has_bpf_center ||
+		selrig->has_vfo_adj ||
+		selrig->has_line_out ) {
 
 		if (selrig->has_nb_level)
 			sldr_nb_level->show();
 		else
 			sldr_nb_level->hide();
 
-		spnr_bpf_center->show();
-		btn_use_bpf_center->show();
 		if (selrig->has_bpf_center) {
 			spnr_bpf_center->value(progStatus.bpf_center);
 			spnr_bpf_center->activate();
 			btn_use_bpf_center->activate();
+			spnr_bpf_center->show();
+			btn_use_bpf_center->show();
 		} else {
-			spnr_bpf_center->deactivate();
-			btn_use_bpf_center->deactivate();
+			spnr_bpf_center->hide();
+			btn_use_bpf_center->hide();
 		}
-		tabsGeneric->add(genericRx);
-		genericRx->redraw();
-		genericRx->show();
-	}
-
-	if (selrig->has_vfo_adj ||
-		selrig->has_line_out ||
-		selrig->has_xcvr_auto_on_off ||
-		selrig->can_synch_clock ) {
 
 		if (selrig->has_vfo_adj) {
 			double min, max, step;
@@ -940,15 +992,27 @@ void TRACED(init_Generic_Tabs)
 			spnr_vfo_adj->step(step);
 			progStatus.vfo_adj = selrig->getVfoAdj();
 			spnr_vfo_adj->value(progStatus.vfo_adj);
+			spnr_vfo_adj->activate();
 			spnr_vfo_adj->show();
 		} else
 			spnr_vfo_adj->hide();
 
-		spnr_line_out->show();
-		if (selrig->has_line_out)
+		if (selrig->has_line_out) {
 			spnr_line_out->activate();
-		else
+			spnr_line_out->show();
+		} else {
 			spnr_line_out->deactivate();
+			spnr_line_out->hide();
+		}
+
+		tabsGeneric->add(genericRx);
+		genericRx->redraw();
+		genericRx->show();
+	}
+
+	if (selrig->has_line_out ||
+		selrig->has_xcvr_auto_on_off ||
+		selrig->can_synch_clock ) {
 
 		btn_xcvr_auto_on->show();
 		btn_xcvr_auto_off->show();
@@ -981,20 +1045,38 @@ void TRACED(init_Generic_Tabs)
 		tabsGeneric->add(genericMisc);
 		genericMisc->redraw();
 		genericMisc->show();
-
 	}
 
-
+	tabsGeneric->remove(genericAux);
+	genericAux->hide();
 	btnAuxDTR->hide();
 	btnAuxRTS->hide();
 	btnDataPort->hide();
-
 	if (progStatus.aux_serial_port != "NONE") {
 		btnAuxRTS->show();
 		btnAuxDTR->show();
 		tabsGeneric->add(genericAux);
+		genericAux->show();
 	}
 
+	tabsGeneric->remove(genericRXB);
+	genericRXB->hide();
+	if (selrig->has_rit || selrig->has_xit || selrig->has_bfo) {
+		if (selrig->has_rit) cntRIT->show();
+		else                 cntRIT->hide();
+		if (selrig->has_xit) cntXIT->show();
+		else                 cntXIT->hide();
+		if (selrig->has_bfo) cntBFO->show();
+		else                 cntBFO->hide();
+		tabsGeneric->add(genericRXB);
+		genericRXB->show();
+	}
+	genericRXB->redraw();
+
+//	btnAuxDTR->hide();
+//	btnAuxRTS->hide();
+//	btnDataPort->hide();
+
 	tabsGeneric->add(genericUser_1);
 	genericUser_1->redraw();
 	genericUser_1->show();
@@ -1054,11 +1136,13 @@ void TRACED(init_Generic_Tabs)
 	if (!selrig->has_auto_notch ||
 		xcvr_name == rig_FT1000MP.name_ )
 		{ poll_auto_notch->deactivate(); poll_auto_notch->value(0); }
-	if (!selrig->has_ifshift_control &&
-		!selrig->has_pbt_controls) { poll_ifshift->deactivate(); poll_ifshift->value(0); }
-	if (selrig->has_pbt_controls) {
-		poll_ifshift->label("pbt");
-		poll_ifshift->redraw_label();
+	if (!selrig->has_ifshift_control) {
+		poll_ifshift->deactivate();
+		poll_ifshift->value(0);
+	}
+	if (!selrig->has_pbt_controls) { 
+		poll_pbt->deactivate(); 
+		poll_pbt->value(0);
 	}
 	if (!selrig->has_power_control) { poll_power_control->deactivate(); poll_power_control->value(0); }
 	if (!selrig->has_preamp_control && !selrig->has_attenuator_control)
@@ -1074,7 +1158,6 @@ void TRACED(init_Generic_Tabs)
 }
 
 void TRACED(initTabs)
-
 	if (xcvr_name == rig_TT550.name_)
 		init_TT550_tabs();
 	else
@@ -1168,6 +1251,11 @@ void TRACED(init_bfo)
 	}
 }
 
+static void cb_pbt(Fl_Counter *, void *)
+{
+	selrig->set_pbt( opFilterInner->value(), opFilterOuter->value() );
+}
+
 void TRACED(init_dsp_controls)
 
 	if (selrig->has_dsp_controls) {
@@ -1213,19 +1301,25 @@ void TRACED(init_dsp_controls)
 		opDSP_hi->hide();
 		btnFILT->hide();
 		opBW->show();
-		if (selrig->name_ == rig_tcisdr.name_) {
+		if (selrig->name_ == rig_tci_sundx.name_ ||
+			selrig->name_ == rig_tci_sunpro.name_ ||
+			selrig->name_ == rig_FLEX1500.name_ ) {
 			opCENTER->clear();
 			for (int i = 0; i < tci_nbr_centers; i++)
 				opCENTER->add(TCI_centers[i]);
 			opCENTER->show();
 			opCENTER->index(progStatus.tci_center);
+			if (progStatus.UIsize == small_ui) {
+				opFilterInner->resize(214, 103, 100, 18);
+				opFilterInner->redraw();
+				opFilterOuter->resize(320, 103, 100, 18);
+				opFilterOuter->redraw();
+			}
+			opFilterInner->callback((Fl_Callback*)cb_pbt);
+			opFilterInner->show();
+			opFilterOuter->callback((Fl_Callback*)cb_pbt);
+			opFilterOuter->show();
 		}
-//		switch (progStatus.UIsize) {
-//			case small_ui :
-//				opCENTER->resize(opBW->x(), opBW->y() + opBW->h() + 2, opCENTER->w(), opCENTER->h());
-//				break;
-//			case wide_ui : case touch_ui : default : break;
-//		}
 	}
 }
 
@@ -1582,7 +1676,11 @@ void TRACED(init_if_shift_control)
 		sldrINNER->show();
 		sldrOUTER->show();
 		sldrINNER->value(progStatus.pbt_inner);
+		sldrINNER->redraw();
 		sldrOUTER->value(progStatus.pbt_outer);
+		sldrOUTER->redraw();
+		selrig->set_pbt_outer(progStatus.pbt_outer);
+		selrig->set_pbt_inner(progStatus.pbt_inner);
 	}
 
 	if (xcvr_name == rig_TS870S.name_) {
@@ -1812,17 +1910,32 @@ void TRACED(init_agc_control)
 void TRACED(init_preamp_control)
 
 	if (selrig->has_preamp_control) {
+
+		if (selrig->name_ == rig_FLEX1500.name_ ) {
+			btnAttenuator->hide();
+			btnPreamp->hide();
+			cbo_preamp->show();
+			return;
+		}
+
 		if (selrig->name_ == rig_FT891.name_) {
 			btnPreamp->label("IPO");
 			btnPreamp->redraw_label();
 		}
-		switch (progStatus.UIsize) {
+
+		if (selrig->name_ == rig_PCR1000.name_) {
+			btnPreamp->label("AGC");
+			btnPreamp->redraw_label();
+		}
+
+ 		switch (progStatus.UIsize) {
 			case small_ui :
 				btnPreamp->show();
 				break;
 			case wide_ui : case touch_ui : default :
 			btnPreamp->activate();
 		}
+
 		if (xcvr_name == rig_IC9700.name_) {
 			btnPreamp->tooltip("\
 Internal/External preamp\n\
@@ -1832,9 +1945,17 @@ P0/E1 off/on\n\
 P1/E1  on/on");
 			btnPreamp->label("P0/E0");
 			btnPreamp->redraw_label();
-		} else {
+		}
+
+	 else {
+
+	if (selrig->name_ == rig_PCR1000.name_) { 
+		   btnPreamp->tooltip("On/Off"); //Kludge necessary to get the tooltip verbiage for the PCR-1000 correct. Feel free to re-order the if-else statements
+	   }
+	 else
 			btnPreamp->tooltip("On/Off/Level");
 		}
+
 	} else {
 		switch (progStatus.UIsize) {
 			case small_ui :
@@ -1872,6 +1993,12 @@ void TRACED(init_noise_control)
 			btnNOISE->label("DNR");
 			btnNOISE->tooltip(_("DSP Noise Reduction On/Off.  See RX tab for DNR level."));
 		}
+		if (selrig->name_ == rig_PCR1000.name_) {
+			// The PCR-1000 has no Noise Blanker. This control is used to activate its UT-106 DSP
+			// Module, which has NR and Auto-Notch features.
+			btnNOISE->label("DSP");
+			btnNOISE->tooltip(_("DSP Noise Reduction On/Off. Set NR operation and level with NR section."));
+		}
 
 		btnNOISE->show();
 		btnNOISE->activate();
@@ -1958,8 +2085,8 @@ void TRACED(init_tune_control)
 void TRACED(init_ptt_control)
 
 	if (selrig->has_ptt_control ||
-		progStatus.comm_dtrptt == PTT_BOTH || progStatus.comm_dtrptt == PTT_SET ||
-		progStatus.comm_rtsptt == PTT_BOTH || progStatus.comm_rtsptt == PTT_SET ||
+		progStatus.serial_dtrptt == PTT_BOTH || progStatus.serial_dtrptt == PTT_SET ||
+		progStatus.serial_rtsptt == PTT_BOTH || progStatus.serial_rtsptt == PTT_SET ||
 		progStatus.sep_dtrptt  == PTT_BOTH || progStatus.sep_dtrptt  == PTT_SET ||
 		progStatus.sep_rtsptt  == PTT_BOTH || progStatus.sep_rtsptt  == PTT_SET) {
 		btnPTT->activate();
@@ -2095,7 +2222,18 @@ Slider controls TX monitor level");
 	}
 }
 
+static void cb_bw_A(Fl_Counter *, void *)
+{
+	selrig->set_bwA( opBW_A->value() );
+}
+
+static void cb_bw_B(Fl_Counter *, void *)
+{
+	selrig->set_bwB( opBW_B->value() );
+}
+
 void TRACED(init_K3_KX3_special)
+	if (!(xcvr_name == rig_K3.name_ || xcvr_name == rig_KX3.name_)) return;
 
 	if (xcvr_name == rig_K3.name_) {
 		btnB->hide();
@@ -2122,6 +2260,17 @@ void TRACED(init_K3_KX3_special)
 		btnA->show();
 		btnAswapB->show();
 	}
+
+	if (progStatus.UIsize == small_ui) {
+		opBW_A->resize(214, 103, 100, 18);
+		opBW_A->redraw();
+		opBW_B->resize(320, 103, 100, 18);
+		opBW_B->redraw();
+	}
+	opBW_A->callback((Fl_Callback*)cb_bw_A);
+	opBW_A->show();
+	opBW_B->callback((Fl_Callback*)cb_bw_B);
+	opBW_B->show();
 }
 
 extern void read_menus();
@@ -2178,8 +2327,6 @@ void TRACED(initRig)
 	} else {
 		sldrVoltage->hide();
 		scaleVoltage->hide();
-		sldrFwdPwr->show();
-		scalePower->show();
 	}
 
 	if (progStatus.use_tcpip) {
@@ -2376,26 +2523,27 @@ void TRACED(initConfigDialog)
 
 	if (!progStatus.loadXcvrState(xcvr_name) ) {
 		selectCommPort->index(0);
-		mnuBaudrate->index( srig->comm_baudrate );
+		mnuBaudrate->index( srig->serial_baudrate );
 		btnOneStopBit->value( srig->stopbits == 1 );
 		btnTwoStopBit->value( srig->stopbits == 2 );
-		cntRigCatRetries->value( srig->comm_retries );
-		cntRigCatTimeout->value( srig->comm_timeout );
-		cntRigCatWait->value( srig->comm_wait );
+		cntRigCatRetries->value( srig->serial_retries );
+		cntRigCatTimeout->value( srig->serial_timeout );
+		cntPostWriteDelay->value( srig->serial_post_write_delay );
+		cntWriteDelay->value( srig->serial_write_delay );
 		query_interval->value( srig->serloop_timing );
 
-		btnRigCatEcho->value( srig->comm_echo );
+		btnRigCatEcho->value( srig->serial_echo );
 
 
-		lbox_catptt->index( srig->comm_catptt );
-		lbox_rtsptt->index( srig->comm_rtsptt );
-		lbox_dtrptt->index( srig->comm_dtrptt );
+		lbox_catptt->index( srig->serial_catptt );
+		lbox_rtsptt->index( srig->serial_rtsptt );
+		lbox_dtrptt->index( srig->serial_dtrptt );
 
-		chkrtscts->value( srig->comm_rtscts );
-		btnrtsplus1->value( srig->comm_rtsplus );
-		btndtrplus1->value( srig->comm_dtrplus );
-		btnrtsplus2->value( srig->comm_rtsplus );
-		btndtrplus2->value( srig->comm_dtrplus );
+		chkrtscts->value( srig->serial_rtscts );
+		btnrtsplus1->value( srig->serial_rtsplus );
+		btndtrplus1->value( srig->serial_dtrplus );
+		btnrtsplus2->value( srig->serial_rtsplus );
+		btndtrplus2->value( srig->serial_dtrplus );
 
 		if (srig->CIV) {
 			char hexstr[8];
@@ -2431,7 +2579,7 @@ void TRACED(initStatusConfigDialog)
 
 	selectRig->value(xcvr_name.c_str());
 
-	mnuBaudrate->index( progStatus.comm_baudrate );
+	mnuBaudrate->index( progStatus.serial_baudrate );
 
 	selectCommPort->value( progStatus.xcvr_serial_port.c_str() );
 	selectAuxPort->value( progStatus.aux_serial_port.c_str() );
@@ -2439,22 +2587,22 @@ void TRACED(initStatusConfigDialog)
 	btnOneStopBit->value( progStatus.stopbits == 1 );
 	btnTwoStopBit->value( progStatus.stopbits == 2 );
 
-	cntRigCatRetries->value( progStatus.comm_retries );
-	cntRigCatTimeout->value( progStatus.comm_timeout );
-	cntRigCatWait->value( progStatus.comm_wait );
-	btnRigCatEcho->value( progStatus.comm_echo );
+	cntRigCatRetries->value( progStatus.serial_retries );
+	cntRigCatTimeout->value( progStatus.serial_timeout );
+	cntPostWriteDelay->value( progStatus.serial_post_write_delay );
+	btnRigCatEcho->value( progStatus.serial_echo );
 	query_interval->value( progStatus.serloop_timing );
-	byte_interval->value( progStatus.byte_interval );
+	cntWriteDelay->value( progStatus.serial_write_delay );
 
-	lbox_catptt->index( progStatus.comm_catptt );
-	lbox_rtsptt->index( progStatus.comm_rtsptt );
-	lbox_dtrptt->index( progStatus.comm_dtrptt );
+	lbox_catptt->index( progStatus.serial_catptt );
+	lbox_rtsptt->index( progStatus.serial_rtsptt );
+	lbox_dtrptt->index( progStatus.serial_dtrptt );
 
-	chkrtscts->value( progStatus.comm_rtscts );
-	btnrtsplus1->value( progStatus.comm_rtsplus );
-	btndtrplus1->value( progStatus.comm_dtrplus );
-	btnrtsplus2->value( progStatus.comm_rtsplus );
-	btndtrplus2->value( progStatus.comm_dtrplus );
+	chkrtscts->value( progStatus.serial_rtscts );
+	btnrtsplus1->value( progStatus.serial_rtsplus );
+	btndtrplus1->value( progStatus.serial_dtrplus );
+	btnrtsplus2->value( progStatus.serial_rtsplus );
+	btndtrplus2->value( progStatus.serial_dtrplus );
 
 	btnSepDTRplus->value(progStatus.sep_dtrplus);
 	lbox_sep_dtrptt->index(progStatus.sep_dtrptt);
